@@ -5,6 +5,8 @@
 # are permitted in any medium without royalty provided the copyright
 # notice and this notice are preserved.
 
+#set -x
+
 if test z"$srcdir" = 'z'; then
   srcdir='.'
 fi
@@ -12,8 +14,10 @@ fi
 #prove -I "$tpdir" -I "$srcdir"/lib "$srcdir"/t/*.t
 
 tpdir=$srcdir/../tp
-prove -I "$tpdir" -I "$tpdir"/maintain/lib/Unicode-EastAsianWidth/lib/ \
+# the last -I ../tp is here to find modules in the build directory, which should
+# be the case for Texinfo::ModulePath
+prove -w -I "$tpdir" -I "$tpdir"/maintain/lib/Unicode-EastAsianWidth/lib/ \
       -I "$tpdir"/maintain/lib/libintl-perl/lib \
       -I "$tpdir"/maintain/lib/Text-Unidecode/lib/ \
-      -I "$srcdir"/lib \
+      -I "$srcdir"/lib -I ../tp \
       "$srcdir"/t/*.t
