@@ -5,14 +5,19 @@ extern ELEMENT *Root;
 
 int init (int texinfo_uninstalled, char *srcdir_in);
 
-void parse_text (char *);
-void parse_string(char *);
 int parse_file (char *filename);
+void parse_piece (char *, int line_nr);
+void parse_string (char *, int line_nr);
+void parse_text (char *, int line_nr);
 void reset_parser (void);
 void reset_parser_except_conf (void);
 void set_debug (int);
 void wipe_values (void);
 void reset_context_stack (void);
+void set_documentlanguage_override (char *value);
+void set_DOC_ENCODING_FOR_INPUT_FILE_NAME (int i);
+void set_input_file_name_encoding (char *value);
+void set_locale_encoding (char *value);
 
 HV *build_texinfo_tree (void);
 AV *build_label_list (void);
@@ -21,6 +26,6 @@ HV *build_float_list (void);
 HV *build_index_data (void);
 HV *build_global_info (void);
 HV *build_global_info2 (void);
-
+AV *get_errors (void);
 
 #endif
