@@ -1,14 +1,20 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'conditional_not_closed'} = {
-  'contents' => [],
-  'type' => 'text_root'
+  'contents' => [
+    {
+      'parent' => {},
+      'type' => 'before_node_section'
+    }
+  ],
+  'type' => 'document_root'
 };
+$result_trees{'conditional_not_closed'}{'contents'}[0]{'parent'} = $result_trees{'conditional_not_closed'};
 
 $result_texis{'conditional_not_closed'} = '';
 
@@ -17,15 +23,18 @@ $result_texts{'conditional_not_closed'} = '';
 
 $result_errors{'conditional_not_closed'} = [
   {
-    'error_line' => ':2: No matching `@end ifhtml\'
+    'error_line' => 'no matching `@end ifhtml\'
 ',
     'file_name' => '',
     'line_nr' => 2,
     'macro' => '',
-    'text' => 'No matching `@end ifhtml\'',
+    'text' => 'no matching `@end ifhtml\'',
     'type' => 'error'
   }
 ];
 
 
+$result_floats{'conditional_not_closed'} = {};
+
+
 1;
