@@ -1,21 +1,28 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'empty_ifset_in_ifset_no_set'} = {
   'contents' => [
     {
-      'parent' => {},
-      'text' => '
+      'contents' => [
+        {
+          'parent' => {},
+          'text' => '
 ',
-      'type' => 'empty_line'
+          'type' => 'empty_line'
+        }
+      ],
+      'parent' => {},
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
+$result_trees{'empty_ifset_in_ifset_no_set'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'empty_ifset_in_ifset_no_set'}{'contents'}[0];
 $result_trees{'empty_ifset_in_ifset_no_set'}{'contents'}[0]{'parent'} = $result_trees{'empty_ifset_in_ifset_no_set'};
 
 $result_texis{'empty_ifset_in_ifset_no_set'} = '
@@ -27,15 +34,18 @@ $result_texts{'empty_ifset_in_ifset_no_set'} = '
 
 $result_errors{'empty_ifset_in_ifset_no_set'} = [
   {
-    'error_line' => ':6: No matching `@end ifset\'
+    'error_line' => 'no matching `@end ifset\'
 ',
     'file_name' => '',
     'line_nr' => 6,
     'macro' => '',
-    'text' => 'No matching `@end ifset\'',
+    'text' => 'no matching `@end ifset\'',
     'type' => 'error'
   }
 ];
 
 
+$result_floats{'empty_ifset_in_ifset_no_set'} = {};
+
+
 1;
