@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -10,17 +10,24 @@ $result_trees{'superfluous_argument_to_end'} = {
     {
       'contents' => [
         {
-          'parent' => {},
-          'text' => 'not html
+          'contents' => [
+            {
+              'parent' => {},
+              'text' => 'not html
 '
+            }
+          ],
+          'parent' => {},
+          'type' => 'paragraph'
         }
       ],
       'parent' => {},
-      'type' => 'paragraph'
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
+$result_trees{'superfluous_argument_to_end'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'superfluous_argument_to_end'}{'contents'}[0]{'contents'}[0];
 $result_trees{'superfluous_argument_to_end'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'superfluous_argument_to_end'}{'contents'}[0];
 $result_trees{'superfluous_argument_to_end'}{'contents'}[0]{'parent'} = $result_trees{'superfluous_argument_to_end'};
 
@@ -33,15 +40,18 @@ $result_texts{'superfluous_argument_to_end'} = 'not html
 
 $result_errors{'superfluous_argument_to_end'} = [
   {
-    'error_line' => ':3: Superfluous argument to @end ifnothtml:  superfluous
+    'error_line' => 'bad argument to @end: ifnothtml superfluous
 ',
     'file_name' => '',
     'line_nr' => 3,
     'macro' => '',
-    'text' => 'Superfluous argument to @end ifnothtml:  superfluous',
+    'text' => 'bad argument to @end: ifnothtml superfluous',
     'type' => 'error'
   }
 ];
 
 
+$result_floats{'superfluous_argument_to_end'} = {};
+
+
 1;
