@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -10,36 +10,41 @@ $result_trees{'test_today'} = {
     {
       'contents' => [
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [],
+              'args' => [
+                {
+                  'parent' => {},
+                  'type' => 'brace_command_arg'
+                }
+              ],
+              'cmdname' => 'today',
               'parent' => {},
-              'type' => 'brace_command_arg'
+              'source_info' => {
+                'file_name' => '',
+                'line_nr' => 1,
+                'macro' => ''
+              }
+            },
+            {
+              'parent' => {},
+              'text' => '.'
             }
           ],
-          'cmdname' => 'today',
-          'contents' => [],
-          'line_nr' => {
-            'file_name' => '',
-            'line_nr' => 1,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
           'parent' => {},
-          'text' => '.'
+          'type' => 'paragraph'
         }
       ],
       'parent' => {},
-      'type' => 'paragraph'
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
-$result_trees{'test_today'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'test_today'}{'contents'}[0]{'contents'}[0];
+$result_trees{'test_today'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'test_today'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
+$result_trees{'test_today'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'test_today'}{'contents'}[0]{'contents'}[0];
+$result_trees{'test_today'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'test_today'}{'contents'}[0]{'contents'}[0];
 $result_trees{'test_today'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'test_today'}{'contents'}[0];
-$result_trees{'test_today'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'test_today'}{'contents'}[0];
 $result_trees{'test_today'}{'contents'}[0]{'parent'} = $result_trees{'test_today'};
 
 $result_texis{'test_today'} = '@today{}.';
@@ -50,6 +55,9 @@ $result_texts{'test_today'} = 'a sunny day.';
 $result_errors{'test_today'} = [];
 
 
+$result_floats{'test_today'} = {};
+
+
 
 $result_converted{'plaintext'}->{'test_today'} = 'a sunny day.
 ';
@@ -61,6 +69,9 @@ $result_converted{'html_text'}->{'test_today'} = '<p>a sunny day.</p>';
 $result_converted{'xml'}->{'test_today'} = '<para><today/>.</para>';
 
 
+$result_converted{'latex_text'}->{'test_today'} = '\\today{}.';
+
+
 $result_converted{'docbook'}->{'test_today'} = '<para>a sunny day.</para>';
 
 1;
