@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -10,24 +10,31 @@ $result_trees{'unknown_commands'} = {
     {
       'contents' => [
         {
-          'parent' => {},
-          'text' => '
+          'contents' => [
+            {
+              'parent' => {},
+              'text' => '
 '
-        },
-        {
-          'parent' => {},
-          'text' => '#
+            },
+            {
+              'parent' => {},
+              'text' => '#
 '
+            }
+          ],
+          'parent' => {},
+          'type' => 'paragraph'
         }
       ],
       'parent' => {},
-      'type' => 'paragraph'
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
+$result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[0];
+$result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[0];
 $result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_commands'}{'contents'}[0];
-$result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'unknown_commands'}{'contents'}[0];
 $result_trees{'unknown_commands'}{'contents'}[0]{'parent'} = $result_trees{'unknown_commands'};
 
 $result_texis{'unknown_commands'} = '
@@ -41,7 +48,7 @@ $result_texts{'unknown_commands'} = '
 
 $result_errors{'unknown_commands'} = [
   {
-    'error_line' => ':1: unknown command `unknwon\'
+    'error_line' => 'unknown command `unknwon\'
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -50,7 +57,7 @@ $result_errors{'unknown_commands'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':2: unexpected @
+    'error_line' => 'unexpected @
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -61,4 +68,7 @@ $result_errors{'unknown_commands'} = [
 ];
 
 
+$result_floats{'unknown_commands'} = {};
+
+
 1;
