@@ -1,41 +1,53 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'empty_listoffloats'} = {
   'contents' => [
     {
-      'args' => [
+      'contents' => [
         {
           'contents' => [],
-          'extra' => {
-            'spaces_after_argument' => '
+          'parent' => {},
+          'type' => 'preamble_before_content'
+        },
+        {
+          'args' => [
+            {
+              'extra' => {
+                'spaces_after_argument' => '
 '
+              },
+              'parent' => {},
+              'type' => 'line_arg'
+            }
+          ],
+          'cmdname' => 'listoffloats',
+          'extra' => {
+            'type' => {
+              'normalized' => ''
+            }
           },
           'parent' => {},
-          'type' => 'line_arg'
+          'source_info' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          }
         }
       ],
-      'cmdname' => 'listoffloats',
-      'extra' => {
-        'type' => {
-          'normalized' => ''
-        }
-      },
-      'line_nr' => {
-        'file_name' => '',
-        'line_nr' => 1,
-        'macro' => ''
-      },
-      'parent' => {}
+      'parent' => {},
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
-$result_trees{'empty_listoffloats'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'empty_listoffloats'}{'contents'}[0];
+$result_trees{'empty_listoffloats'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'empty_listoffloats'}{'contents'}[0];
+$result_trees{'empty_listoffloats'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'empty_listoffloats'}{'contents'}[0]{'contents'}[1];
+$result_trees{'empty_listoffloats'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'empty_listoffloats'}{'contents'}[0];
 $result_trees{'empty_listoffloats'}{'contents'}[0]{'parent'} = $result_trees{'empty_listoffloats'};
 
 $result_texis{'empty_listoffloats'} = '@listoffloats
@@ -47,11 +59,14 @@ $result_texts{'empty_listoffloats'} = '';
 $result_errors{'empty_listoffloats'} = [];
 
 
+$result_floats{'empty_listoffloats'} = {};
+
+
 
 $result_converted{'plaintext'}->{'empty_listoffloats'} = '';
 
 
-$result_converted{'html'}->{'empty_listoffloats'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+$result_converted{'html'}->{'empty_listoffloats'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -62,24 +77,8 @@ $result_converted{'html'}->{'empty_listoffloats'} = '<!DOCTYPE html PUBLIC "-//W
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
-<style type="text/css">
-<!--
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-ul.no-bullet {list-style: none}
--->
-</style>
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 
 
 </head>
