@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,54 +17,60 @@ $result_trees{'cond'} = {
                   'parent' => {},
                   'text' => '\\input texinfo
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble'
+              'type' => 'preamble_before_beginning'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'cond.info'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'cond.info'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'cond.info'
               },
               'parent' => {},
-              'type' => 'line_arg'
+              'source_info' => {
+                'file_name' => 'cond.texi',
+                'line_nr' => 2,
+                'macro' => ''
+              }
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line'
             }
           ],
-          'cmdname' => 'setfilename',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'cond.info'
-          },
-          'line_nr' => {
-            'file_name' => 'cond.texi',
-            'line_nr' => 2,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
           'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
+          'type' => 'preamble_before_content'
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -92,17 +98,18 @@ $result_trees{'cond'} = {
           'type' => 'empty_line'
         },
         {
-          'cmdname' => 'html',
-          'contents' => [
+          'args' => [
             {
               'extra' => {
-                'command' => {}
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
+              'type' => 'block_line_arg'
+            }
+          ],
+          'cmdname' => 'html',
+          'contents' => [
             {
               'contents' => [
                 {
@@ -133,27 +140,23 @@ $result_trees{'cond'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'html',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'html'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'cond.texi',
                 'line_nr' => 8,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => 'cond.texi',
             'line_nr' => 6,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -220,19 +223,22 @@ $result_trees{'cond'} = {
           'type' => 'empty_line'
         },
         {
+          'args' => [
+            {
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
+              'parent' => {},
+              'type' => 'block_line_arg'
+            }
+          ],
           'cmdname' => 'tex',
           'contents' => [
             {
-              'contents' => [],
               'parent' => {},
               'type' => 'elided_block'
             },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
             {
               'args' => [
                 {
@@ -252,22 +258,23 @@ $result_trees{'cond'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'tex',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'tex'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'cond.texi',
                 'line_nr' => 30,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'parent' => {}
+          'parent' => {},
+          'source_info' => {
+            'file_name' => 'cond.texi',
+            'line_nr' => 28,
+            'macro' => ''
+          }
         },
         {
           'parent' => {},
@@ -305,19 +312,21 @@ $result_trees{'cond'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'cond.texi',
         'line_nr' => 4,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -337,22 +346,21 @@ $result_trees{'cond'} = {
 $result_trees{'cond'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'cond'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[0]{'contents'}[0];
 $result_trees{'cond'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[0];
-$result_trees{'cond'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'cond'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[0]{'contents'}[1];
+$result_trees{'cond'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
+$result_trees{'cond'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'cond'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[0]{'contents'}[1];
+$result_trees{'cond'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond'}{'contents'}[0]{'contents'}[1];
 $result_trees{'cond'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'cond'}{'contents'}[0];
-$result_trees{'cond'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'cond'}{'contents'}[0];
 $result_trees{'cond'}{'contents'}[0]{'parent'} = $result_trees{'cond'};
 $result_trees{'cond'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'args'}[0];
 $result_trees{'cond'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1];
-$result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1];
+$result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1];
+$result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
+$result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0];
+$result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
-$result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[3];
@@ -365,12 +373,11 @@ $result_trees{'cond'}{'contents'}[1]{'contents'}[7]{'parent'} = $result_trees{'c
 $result_trees{'cond'}{'contents'}[1]{'contents'}[8]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[10]{'parent'} = $result_trees{'cond'}{'contents'}[1];
+$result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[11];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[11];
+$result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0];
+$result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[11];
-$result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0];
-$result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[2];
-$result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'parent'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[11];
-$result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'extra'}{'end_command'} = $result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'contents'}[2];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[11]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[12]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[13]{'parent'} = $result_trees{'cond'}{'contents'}[1];
@@ -378,7 +385,7 @@ $result_trees{'cond'}{'contents'}[1]{'contents'}[14]{'contents'}[0]{'parent'} =
 $result_trees{'cond'}{'contents'}[1]{'contents'}[14]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[15]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'cond'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'cond'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'cond'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'cond'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'cond'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'cond'}{'contents'}[1]{'parent'} = $result_trees{'cond'};
 $result_trees{'cond'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[2];
 $result_trees{'cond'}{'contents'}[2]{'parent'} = $result_trees{'cond'};
@@ -427,41 +434,28 @@ This is ifnottex text.
 
 ';
 
-$result_sectioning{'cond'} = {};
-
 $result_nodes{'cond'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
+    'normalized' => 'Top'
   }
 };
-$result_nodes{'cond'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'cond'};
 
 $result_menus{'cond'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'cond'} = [];
 
 
+$result_floats{'cond'} = {};
 
-$result_converted{'html'}->{'cond'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+
+
+$result_converted{'html'}->{'cond'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -473,31 +467,11 @@ $result_converted{'html'}->{'cond'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
 <meta name="Generator" content="texi2any">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <style type="text/css">
 <!--
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-ul.no-bullet {list-style: none}
+span.program-in-footer {font-size: smaller}
 -->
 </style>
 
@@ -506,7 +480,7 @@ ul.no-bullet {list-style: none}
 
 <body lang="en">
 
-<span id="Top"></span>
+<a class="node" id="Top"></a>
 This is html text.
 
 <p>This is ifhtml text.
@@ -522,9 +496,9 @@ This is html text.
 <p>This is ifnottex text.
 </p>
 <hr>
-<p><font size="-1">
-  This document was generated on <em>a sunny day</em> using <a href="http://www.gnu.org/software/texinfo/"><em>texi2any</em></a>.
-</font></p>
+<p>
+  <span class="program-in-footer">This document was generated on <em class="emph">a sunny day</em> using <a class="uref" href="http://www.gnu.org/software/texinfo/"><em class="emph">texi2any</em></a>.</span>
+</p>
 
 
 </body>
@@ -533,8 +507,9 @@ This is html text.
 
 $result_converted_errors{'html'}->{'cond'} = [
   {
-    'error_line' => 'cond.texi: warning: must specify a title with a title command or @top
+    'error_line' => 'warning: must specify a title with a title command or @top
 ',
+    'file_name' => 'cond.texi',
     'text' => 'must specify a title with a title command or @top',
     'type' => 'warning'
   }
