@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,54 +17,60 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
                   'parent' => {},
                   'text' => '\\input texinfo
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble'
+              'type' => 'preamble_before_beginning'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'cond.info'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'cond.info'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'cond.info'
               },
               'parent' => {},
-              'type' => 'line_arg'
+              'source_info' => {
+                'file_name' => 'cond.texi',
+                'line_nr' => 2,
+                'macro' => ''
+              }
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line'
             }
           ],
-          'cmdname' => 'setfilename',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'cond.info'
-          },
-          'line_nr' => {
-            'file_name' => 'cond.texi',
-            'line_nr' => 2,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
           'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
+          'type' => 'preamble_before_content'
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -92,17 +98,18 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
           'type' => 'empty_line'
         },
         {
-          'cmdname' => 'html',
-          'contents' => [
+          'args' => [
             {
               'extra' => {
-                'command' => {}
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
+              'type' => 'block_line_arg'
+            }
+          ],
+          'cmdname' => 'html',
+          'contents' => [
             {
               'contents' => [
                 {
@@ -133,27 +140,23 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'html',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'html'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'cond.texi',
                 'line_nr' => 8,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => 'cond.texi',
             'line_nr' => 6,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -220,17 +223,18 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
           'type' => 'empty_line'
         },
         {
-          'cmdname' => 'tex',
-          'contents' => [
+          'args' => [
             {
               'extra' => {
-                'command' => {}
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
+              'type' => 'block_line_arg'
+            }
+          ],
+          'cmdname' => 'tex',
+          'contents' => [
             {
               'contents' => [
                 {
@@ -261,27 +265,23 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'tex',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'tex'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'cond.texi',
                 'line_nr' => 30,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => 'cond.texi',
             'line_nr' => 28,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -319,19 +319,21 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'cond.texi',
         'line_nr' => 4,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -351,22 +353,21 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'};
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'args'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[3];
@@ -379,14 +380,12 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[7]{'parent'
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[8]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[10]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[0]{'extra'}{'command'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'extra'}{'end_command'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[12]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[13]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[13];
@@ -394,7 +393,7 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[13]{'parent
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[14]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[15]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'};
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[2];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[2]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'};
@@ -444,29 +443,28 @@ This is iftex text.
 
 ';
 
-$result_sectioning{'cond_ifhtml_ifinfo_iftex'} = {};
-
 $result_nodes{'cond_ifhtml_ifinfo_iftex'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'cond_ifhtml_ifinfo_iftex'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'cond_ifhtml_ifinfo_iftex'} = [];
 
 
+$result_floats{'cond_ifhtml_ifinfo_iftex'} = {};
 
-$result_converted{'html'}->{'cond_ifhtml_ifinfo_iftex'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+
+
+$result_converted{'html'}->{'cond_ifhtml_ifinfo_iftex'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -478,22 +476,11 @@ $result_converted{'html'}->{'cond_ifhtml_ifinfo_iftex'} = '<!DOCTYPE html PUBLIC
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
 <meta name="Generator" content="texi2any">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <style type="text/css">
 <!--
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-ul.no-bullet {list-style: none}
+span.program-in-footer {font-size: smaller}
 -->
 </style>
 
@@ -502,7 +489,7 @@ ul.no-bullet {list-style: none}
 
 <body lang="en">
 
-<span id="Top"></span>
+<a class="node" id="Top"></a>
 This is html text.
 
 <p>This is ifhtml text.
@@ -519,9 +506,9 @@ This is tex text.
 </p>
 
 <hr>
-<p><font size="-1">
-  This document was generated on <em>a sunny day</em> using <a href="http://www.gnu.org/software/texinfo/"><em>texi2any</em></a>.
-</font></p>
+<p>
+  <span class="program-in-footer">This document was generated on <em class="emph">a sunny day</em> using <a class="uref" href="http://www.gnu.org/software/texinfo/"><em class="emph">texi2any</em></a>.</span>
+</p>
 
 
 </body>
@@ -530,13 +517,14 @@ This is tex text.
 
 $result_converted_errors{'html'}->{'cond_ifhtml_ifinfo_iftex'} = [
   {
-    'error_line' => 'cond.texi: warning: must specify a title with a title command or @top
+    'error_line' => 'warning: must specify a title with a title command or @top
 ',
+    'file_name' => 'cond.texi',
     'text' => 'must specify a title with a title command or @top',
     'type' => 'warning'
   },
   {
-    'error_line' => 'cond.texi:28: warning: raw format tex is not converted
+    'error_line' => 'warning: raw format tex is not converted
 ',
     'file_name' => 'cond.texi',
     'line_nr' => 28,
