@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,54 +17,60 @@ $result_trees{'cond_xml'} = {
                   'parent' => {},
                   'text' => '\\input texinfo
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble'
+              'type' => 'preamble_before_beginning'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'cond.info'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'cond.info'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'cond.info'
               },
               'parent' => {},
-              'type' => 'line_arg'
+              'source_info' => {
+                'file_name' => 'cond.texi',
+                'line_nr' => 2,
+                'macro' => ''
+              }
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line'
             }
           ],
-          'cmdname' => 'setfilename',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'cond.info'
-          },
-          'line_nr' => {
-            'file_name' => 'cond.texi',
-            'line_nr' => 2,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
           'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
+          'type' => 'preamble_before_content'
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -92,19 +98,22 @@ $result_trees{'cond_xml'} = {
           'type' => 'empty_line'
         },
         {
+          'args' => [
+            {
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
+              'parent' => {},
+              'type' => 'block_line_arg'
+            }
+          ],
           'cmdname' => 'html',
           'contents' => [
             {
-              'contents' => [],
               'parent' => {},
               'type' => 'elided_block'
             },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
             {
               'args' => [
                 {
@@ -124,22 +133,23 @@ $result_trees{'cond_xml'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'html',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'html'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'cond.texi',
                 'line_nr' => 8,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'parent' => {}
+          'parent' => {},
+          'source_info' => {
+            'file_name' => 'cond.texi',
+            'line_nr' => 6,
+            'macro' => ''
+          }
         },
         {
           'parent' => {},
@@ -206,19 +216,22 @@ $result_trees{'cond_xml'} = {
           'type' => 'empty_line'
         },
         {
+          'args' => [
+            {
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
+              'parent' => {},
+              'type' => 'block_line_arg'
+            }
+          ],
           'cmdname' => 'tex',
           'contents' => [
             {
-              'contents' => [],
               'parent' => {},
               'type' => 'elided_block'
             },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
             {
               'args' => [
                 {
@@ -238,22 +251,23 @@ $result_trees{'cond_xml'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'tex',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'tex'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'cond.texi',
                 'line_nr' => 30,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'parent' => {}
+          'parent' => {},
+          'source_info' => {
+            'file_name' => 'cond.texi',
+            'line_nr' => 28,
+            'macro' => ''
+          }
         },
         {
           'parent' => {},
@@ -291,19 +305,21 @@ $result_trees{'cond_xml'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'cond.texi',
         'line_nr' => 4,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -323,20 +339,20 @@ $result_trees{'cond_xml'} = {
 $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[0];
 $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0];
-$result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1];
+$result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
+$result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1];
+$result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0];
-$result_trees{'cond_xml'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'cond_xml'}{'contents'}[0];
 $result_trees{'cond_xml'}{'contents'}[0]{'parent'} = $result_trees{'cond_xml'};
 $result_trees{'cond_xml'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'args'}[0];
 $result_trees{'cond_xml'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
+$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1];
+$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0];
+$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
-$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
@@ -349,12 +365,11 @@ $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[8]{'contents'}[0]{'parent'}
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[8]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[10]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
+$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11];
+$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0];
+$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11];
-$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0];
-$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[2];
-$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11];
-$result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'extra'}{'end_command'} = $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'contents'}[2];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[11]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[12]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[13]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
@@ -362,7 +377,7 @@ $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[14]{'contents'}[0]{'parent'
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[14]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'contents'}[15]{'parent'} = $result_trees{'cond_xml'}{'contents'}[1];
 $result_trees{'cond_xml'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'cond_xml'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'cond_xml'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'cond_xml'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'cond_xml'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'cond_xml'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'cond_xml'}{'contents'}[1]{'parent'} = $result_trees{'cond_xml'};
 $result_trees{'cond_xml'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_xml'}{'contents'}[2];
 $result_trees{'cond_xml'}{'contents'}[2]{'parent'} = $result_trees{'cond_xml'};
@@ -410,30 +425,29 @@ This is ifnottex text.
 
 ';
 
-$result_sectioning{'cond_xml'} = {};
-
 $result_nodes{'cond_xml'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'cond_xml'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'cond_xml'} = [];
 
 
+$result_floats{'cond_xml'} = {};
 
-$result_converted{'xml'}->{'cond_xml'} = '<preamble>\\input texinfo
-</preamble><setfilename file="cond.info" spaces=" ">cond.info</setfilename>
+
+
+$result_converted{'xml'}->{'cond_xml'} = '<preamblebeforebeginning>\\input texinfo
+</preamblebeforebeginning><setfilename file="cond.info" spaces=" ">cond.info</setfilename>
 
 <node name="Top" spaces=" "><nodename>Top</nodename></node>
 
