@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,11 +17,11 @@ $result_trees{'documentlanguage_set_unknown'} = {
                   'parent' => {},
                   'text' => '\\input texinfo @c -*-texinfo-*-
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble'
+              'type' => 'preamble_before_beginning'
             },
             {
               'args' => [
@@ -46,108 +46,114 @@ $result_trees{'documentlanguage_set_unknown'} = {
           'type' => 'preamble_before_setfilename'
         },
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'documentlanguage_set.info'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'documentlanguage_set.info'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'documentlanguage_set.info'
               },
               'parent' => {},
-              'type' => 'line_arg'
-            }
-          ],
-          'cmdname' => 'setfilename',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'documentlanguage_set.info'
-          },
-          'line_nr' => {
-            'file_name' => 'documentlanguage_set.texi',
-            'line_nr' => 3,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
-          'args' => [
+              'source_info' => {
+                'file_name' => 'documentlanguage_set.texi',
+                'line_nr' => 3,
+                'macro' => ''
+              }
+            },
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'pt'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'pt'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'documentlanguage',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'pt'
               },
               'parent' => {},
-              'type' => 'line_arg'
-            }
-          ],
-          'cmdname' => 'documentlanguage',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'pt'
-          },
-          'line_nr' => {
-            'file_name' => 'documentlanguage_set.texi',
-            'line_nr' => 4,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
-          'args' => [
+              'source_info' => {
+                'file_name' => 'documentlanguage_set.texi',
+                'line_nr' => 4,
+                'macro' => ''
+              }
+            },
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'Test '
+                    },
+                    {
+                      'cmdname' => '@',
+                      'parent' => {}
+                    },
+                    {
+                      'parent' => {},
+                      'text' => 'documentlanguage set'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'Test '
-                },
-                {
-                  'cmdname' => '@',
-                  'parent' => {}
-                },
-                {
-                  'parent' => {},
-                  'text' => 'documentlanguage set'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'settitle',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' '
               },
               'parent' => {},
-              'type' => 'line_arg'
-            }
-          ],
-          'cmdname' => 'settitle',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'line_nr' => {
-            'file_name' => 'documentlanguage_set.texi',
-            'line_nr' => 5,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
-          'parent' => {},
-          'text' => '
+              'source_info' => {
+                'file_name' => 'documentlanguage_set.texi',
+                'line_nr' => 5,
+                'macro' => ''
+              }
+            },
+            {
+              'parent' => {},
+              'text' => '
 ',
-          'type' => 'empty_line'
+              'type' => 'empty_line'
+            }
+          ],
+          'parent' => {},
+          'type' => 'preamble_before_content'
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -167,26 +173,27 @@ $result_trees{'documentlanguage_set_unknown'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'documentlanguage_set.texi',
         'line_nr' => 7,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -238,13 +245,12 @@ $result_trees{'documentlanguage_set_unknown'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'documentlanguage_set.texi',
         'line_nr' => 8,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -266,23 +272,24 @@ $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[0]{'con
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[0]{'contents'}[1];
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[0];
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[1];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[2];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1];
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1];
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[2];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[3]{'args'}[0];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[3]{'args'}[0];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[3]{'args'}[0];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[3];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[0];
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'};
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[1]{'args'}[0];
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[1];
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'documentlanguage_set_unknown'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'documentlanguage_set_unknown'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'documentlanguage_set_unknown'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'documentlanguage_set_unknown'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[1]{'parent'} = $result_trees{'documentlanguage_set_unknown'};
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[2]{'args'}[0];
 $result_trees{'documentlanguage_set_unknown'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'documentlanguage_set_unknown'}{'contents'}[2]{'args'}[0];
@@ -319,51 +326,52 @@ Text.
 ';
 
 $result_sectioning{'documentlanguage_set_unknown'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {
-        'associated_node' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'Top',
-            'spaces_before_argument' => ' '
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {
+          'associated_node' => {
+            'cmdname' => 'node',
+            'extra' => {
+              'normalized' => 'Top'
+            }
           }
         },
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_up' => {}
-    }
-  ]
+        'structure' => {
+          'section_level' => 0,
+          'section_up' => {}
+        }
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'documentlanguage_set_unknown'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'documentlanguage_set_unknown'};
+$result_sectioning{'documentlanguage_set_unknown'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'documentlanguage_set_unknown'};
 
 $result_nodes{'documentlanguage_set_unknown'} = {
   'cmdname' => 'node',
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0
+      'extra' => {},
+      'structure' => {}
     },
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'documentlanguage_set_unknown'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'documentlanguage_set_unknown'} = [];
 
 
+$result_floats{'documentlanguage_set_unknown'} = {};
+
+
 1;
