@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,60 +17,66 @@ $result_trees{'split_for_format_not_split'} = {
                   'parent' => {},
                   'text' => '\\input texinfo @c -*-texinfo-*-
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 },
                 {
                   'parent' => {},
                   'text' => '
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble'
+              'type' => 'preamble_before_beginning'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'simplest.info'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'simplest.info'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'simplest.info'
               },
               'parent' => {},
-              'type' => 'line_arg'
+              'source_info' => {
+                'file_name' => 'simplest.texi',
+                'line_nr' => 3,
+                'macro' => ''
+              }
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line'
             }
           ],
-          'cmdname' => 'setfilename',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'simplest.info'
-          },
-          'line_nr' => {
-            'file_name' => 'simplest.texi',
-            'line_nr' => 3,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
           'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
+          'type' => 'preamble_before_content'
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -129,19 +135,21 @@ $result_trees{'split_for_format_not_split'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'simplest.texi',
         'line_nr' => 5,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -162,10 +170,11 @@ $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[0]{'conte
 $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[0];
 $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0];
-$result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1];
+$result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
+$result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1];
+$result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1];
 $result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0];
-$result_trees{'split_for_format_not_split'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[0];
 $result_trees{'split_for_format_not_split'}{'contents'}[0]{'parent'} = $result_trees{'split_for_format_not_split'};
 $result_trees{'split_for_format_not_split'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[1]{'args'}[0];
 $result_trees{'split_for_format_not_split'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[1];
@@ -176,7 +185,7 @@ $result_trees{'split_for_format_not_split'}{'contents'}[1]{'contents'}[1]{'conte
 $result_trees{'split_for_format_not_split'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[1];
 $result_trees{'split_for_format_not_split'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[1];
 $result_trees{'split_for_format_not_split'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'split_for_format_not_split'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'split_for_format_not_split'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_for_format_not_split'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'split_for_format_not_split'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_for_format_not_split'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'split_for_format_not_split'}{'contents'}[1]{'parent'} = $result_trees{'split_for_format_not_split'};
 $result_trees{'split_for_format_not_split'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[2];
 $result_trees{'split_for_format_not_split'}{'contents'}[2]{'parent'} = $result_trees{'split_for_format_not_split'};
@@ -199,25 +208,24 @@ This is a very simple texi manual   <>.
 
 ';
 
-$result_sectioning{'split_for_format_not_split'} = {};
-
 $result_nodes{'split_for_format_not_split'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'split_for_format_not_split'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'split_for_format_not_split'} = [];
 
 
+$result_floats{'split_for_format_not_split'} = {};
+
+
 1;
