@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,54 +17,60 @@ $result_trees{'split_nocopying_split'} = {
                   'parent' => {},
                   'text' => '\\input texinfo
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble'
+              'type' => 'preamble_before_beginning'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'split-nocopying.info'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'split-nocopying.info'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'split-nocopying.info'
               },
               'parent' => {},
-              'type' => 'line_arg'
+              'source_info' => {
+                'file_name' => 'split_nocopying.texi',
+                'line_nr' => 2,
+                'macro' => ''
+              }
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line'
             }
           ],
-          'cmdname' => 'setfilename',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'split-nocopying.info'
-          },
-          'line_nr' => {
-            'file_name' => 'split_nocopying.texi',
-            'line_nr' => 2,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
           'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
+          'type' => 'preamble_before_content'
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -84,26 +90,27 @@ $result_trees{'split_nocopying_split'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'split_nocopying.texi',
         'line_nr' => 4,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -148,17 +155,18 @@ $result_trees{'split_nocopying_split'} = {
           'type' => 'empty_line'
         },
         {
-          'cmdname' => 'menu',
-          'contents' => [
+          'args' => [
             {
               'extra' => {
-                'command' => {}
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
+              'type' => 'block_line_arg'
+            }
+          ],
+          'cmdname' => 'menu',
+          'contents' => [
             {
               'args' => [
                 {
@@ -208,12 +216,12 @@ $result_trees{'split_nocopying_split'} = {
                   'normalized' => 'Ch1'
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'split_nocopying.texi',
                 'line_nr' => 10,
                 'macro' => ''
               },
-              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -235,27 +243,23 @@ $result_trees{'split_nocopying_split'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'menu',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'split_nocopying.texi',
                 'line_nr' => 11,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => 'split_nocopying.texi',
             'line_nr' => 9,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -267,13 +271,12 @@ $result_trees{'split_nocopying_split'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'split_nocopying.texi',
         'line_nr' => 5,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -293,26 +296,27 @@ $result_trees{'split_nocopying_split'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Ch1'
           }
         ],
         'normalized' => 'Ch1',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'split_nocopying.texi',
         'line_nr' => 13,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -360,14 +364,12 @@ $result_trees{'split_nocopying_split'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'split_nocopying.texi',
         'line_nr' => 14,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -387,15 +389,16 @@ $result_trees{'split_nocopying_split'} = {
 $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0];
-$result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1];
+$result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
+$result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1];
+$result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1];
 $result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0];
-$result_trees{'split_nocopying_split'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'};
 $result_trees{'split_nocopying_split'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[1]{'args'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[1];
 $result_trees{'split_nocopying_split'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'split_nocopying_split'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'split_nocopying_split'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_nocopying_split'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'split_nocopying_split'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_nocopying_split'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[1]{'parent'} = $result_trees{'split_nocopying_split'};
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'args'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2];
@@ -403,29 +406,27 @@ $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[0]{'parent'} =
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[1];
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2];
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'command'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'contents'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3];
+$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[2];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3];
-$result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'contents'}[2];
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[3]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2];
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'contents'}[4]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[2];
 $result_trees{'split_nocopying_split'}{'contents'}[2]{'parent'} = $result_trees{'split_nocopying_split'};
 $result_trees{'split_nocopying_split'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[3]{'args'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[3];
 $result_trees{'split_nocopying_split'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'split_nocopying_split'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'split_nocopying_split'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_nocopying_split'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'split_nocopying_split'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_nocopying_split'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[3]{'parent'} = $result_trees{'split_nocopying_split'};
 $result_trees{'split_nocopying_split'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[4]{'args'}[0];
 $result_trees{'split_nocopying_split'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'split_nocopying_split'}{'contents'}[4];
@@ -474,122 +475,120 @@ First chapter.
 ';
 
 $result_sectioning{'split_nocopying_split'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {
-        'associated_node' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'Top',
-            'spaces_before_argument' => ' '
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {
+          'associated_node' => {
+            'cmdname' => 'node',
+            'extra' => {
+              'normalized' => 'Top'
+            },
+            'structure' => {}
           }
         },
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_childs' => [
-        {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'associated_node' => {
-              'cmdname' => 'node',
+        'structure' => {
+          'section_childs' => [
+            {
+              'cmdname' => 'chapter',
               'extra' => {
-                'normalized' => 'Ch1',
-                'spaces_before_argument' => ' '
+                'associated_node' => {
+                  'cmdname' => 'node',
+                  'extra' => {
+                    'normalized' => 'Ch1'
+                  },
+                  'structure' => {}
+                }
+              },
+              'structure' => {
+                'section_level' => 1,
+                'section_number' => 1,
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
               }
-            },
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 1,
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
+            }
+          ],
+          'section_level' => 0,
+          'section_up' => {}
         }
-      ],
-      'section_up' => {}
-    }
-  ]
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'split_nocopying_split'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'split_nocopying_split'}{'section_childs'}[0];
-$result_sectioning{'split_nocopying_split'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'split_nocopying_split'}{'section_childs'}[0];
-$result_sectioning{'split_nocopying_split'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'split_nocopying_split'}{'section_childs'}[0];
-$result_sectioning{'split_nocopying_split'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'split_nocopying_split'};
+$result_sectioning{'split_nocopying_split'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'split_nocopying_split'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'split_nocopying_split'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'split_nocopying_split'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'split_nocopying_split'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'split_nocopying_split'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'split_nocopying_split'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'split_nocopying_split'};
 
 $result_nodes{'split_nocopying_split'} = {
   'cmdname' => 'node',
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0
+      'extra' => {},
+      'structure' => {}
     },
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
-  },
-  'menu_child' => {
-    'cmdname' => 'node',
-    'extra' => {
-      'associated_section' => {
-        'cmdname' => 'chapter',
-        'extra' => {
-          'spaces_before_argument' => ' '
-        },
-        'level' => 1,
-        'number' => 1
-      },
-      'normalized' => 'Ch1',
-      'spaces_before_argument' => ' '
-    },
-    'node_prev' => {},
-    'node_up' => {}
-  },
-  'menus' => [
-    {
-      'cmdname' => 'menu',
-      'extra' => {
-        'end_command' => {
-          'cmdname' => 'end',
-          'extra' => {
-            'command_argument' => 'menu',
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'menu'
-          }
-        }
+    'menus' => [
+      {
+        'cmdname' => 'menu'
       }
-    }
-  ],
-  'node_next' => {}
+    ],
+    'normalized' => 'Top'
+  },
+  'structure' => {
+    'menu_child' => {
+      'cmdname' => 'node',
+      'extra' => {
+        'associated_section' => {
+          'cmdname' => 'chapter',
+          'extra' => {},
+          'structure' => {
+            'section_number' => 1
+          }
+        },
+        'normalized' => 'Ch1'
+      },
+      'structure' => {
+        'node_prev' => {},
+        'node_up' => {}
+      }
+    },
+    'node_next' => {}
+  }
 };
-$result_nodes{'split_nocopying_split'}{'menu_child'}{'node_prev'} = $result_nodes{'split_nocopying_split'};
-$result_nodes{'split_nocopying_split'}{'menu_child'}{'node_up'} = $result_nodes{'split_nocopying_split'};
-$result_nodes{'split_nocopying_split'}{'node_next'} = $result_nodes{'split_nocopying_split'}{'menu_child'};
+$result_nodes{'split_nocopying_split'}{'structure'}{'menu_child'}{'structure'}{'node_prev'} = $result_nodes{'split_nocopying_split'};
+$result_nodes{'split_nocopying_split'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'split_nocopying_split'};
+$result_nodes{'split_nocopying_split'}{'structure'}{'node_next'} = $result_nodes{'split_nocopying_split'}{'structure'}{'menu_child'};
 
 $result_menus{'split_nocopying_split'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   },
-  'menu_child' => {
-    'cmdname' => 'node',
-    'extra' => {
-      'normalized' => 'Ch1',
-      'spaces_before_argument' => ' '
-    },
-    'menu_up' => {},
-    'menu_up_hash' => {
-      'Top' => 1
+  'structure' => {
+    'menu_child' => {
+      'cmdname' => 'node',
+      'extra' => {
+        'normalized' => 'Ch1'
+      },
+      'structure' => {
+        'menu_up' => {},
+        'menu_up_hash' => {
+          'Top' => 1
+        }
+      }
     }
   }
 };
-$result_menus{'split_nocopying_split'}{'menu_child'}{'menu_up'} = $result_menus{'split_nocopying_split'};
+$result_menus{'split_nocopying_split'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'split_nocopying_split'};
 
 $result_errors{'split_nocopying_split'} = [];
 
 
+$result_floats{'split_nocopying_split'} = {};
+
+
 1;
