@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'shortcontents_no_top'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -41,14 +40,12 @@ $result_trees{'shortcontents_no_top'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -79,14 +76,12 @@ $result_trees{'shortcontents_no_top'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      },
-      'number' => 2,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -123,25 +118,23 @@ $result_trees{'shortcontents_no_top'} = {
             }
           ],
           'cmdname' => 'shortcontents',
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 7,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         }
       ],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 2,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      },
-      'number' => '2.1',
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -184,52 +177,57 @@ $result_texts{'shortcontents_no_top'} = '1 chap
 ';
 
 $result_sectioning{'shortcontents_no_top'} = {
-  'level' => 0,
-  'section_childs' => [
-    {
-      'cmdname' => 'chapter',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 1,
-      'number' => 1,
-      'section_up' => {}
-    },
-    {
-      'cmdname' => 'chapter',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 1,
-      'number' => 2,
-      'section_childs' => [
-        {
-          'cmdname' => 'section',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 2,
-          'number' => '2.1',
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'chapter',
+        'extra' => {},
+        'structure' => {
+          'section_level' => 1,
+          'section_number' => 1,
           'section_up' => {}
         }
-      ],
-      'section_prev' => {},
-      'section_up' => {},
-      'toplevel_prev' => {}
-    }
-  ]
+      },
+      {
+        'cmdname' => 'chapter',
+        'extra' => {},
+        'structure' => {
+          'section_childs' => [
+            {
+              'cmdname' => 'section',
+              'extra' => {},
+              'structure' => {
+                'section_level' => 2,
+                'section_number' => '2.1',
+                'section_up' => {}
+              }
+            }
+          ],
+          'section_level' => 1,
+          'section_number' => 2,
+          'section_prev' => {},
+          'section_up' => {},
+          'toplevel_prev' => {}
+        }
+      }
+    ],
+    'section_level' => 0
+  }
 };
-$result_sectioning{'shortcontents_no_top'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'shortcontents_no_top'};
-$result_sectioning{'shortcontents_no_top'}{'section_childs'}[1]{'section_childs'}[0]{'section_up'} = $result_sectioning{'shortcontents_no_top'}{'section_childs'}[1];
-$result_sectioning{'shortcontents_no_top'}{'section_childs'}[1]{'section_prev'} = $result_sectioning{'shortcontents_no_top'}{'section_childs'}[0];
-$result_sectioning{'shortcontents_no_top'}{'section_childs'}[1]{'section_up'} = $result_sectioning{'shortcontents_no_top'};
-$result_sectioning{'shortcontents_no_top'}{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'shortcontents_no_top'}{'section_childs'}[0];
+$result_sectioning{'shortcontents_no_top'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'shortcontents_no_top'};
+$result_sectioning{'shortcontents_no_top'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'shortcontents_no_top'}{'structure'}{'section_childs'}[1];
+$result_sectioning{'shortcontents_no_top'}{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'shortcontents_no_top'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'shortcontents_no_top'}{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'shortcontents_no_top'};
+$result_sectioning{'shortcontents_no_top'}{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_prev'} = $result_sectioning{'shortcontents_no_top'}{'structure'}{'section_childs'}[0];
 
 $result_errors{'shortcontents_no_top'} = [];
 
 
+$result_floats{'shortcontents_no_top'} = {};
 
-$result_converted{'html'}->{'shortcontents_no_top'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+
+
+$result_converted{'html'}->{'shortcontents_no_top'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -240,31 +238,11 @@ $result_converted{'html'}->{'shortcontents_no_top'} = '<!DOCTYPE html PUBLIC "-/
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <style type="text/css">
 <!--
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-ul.no-bullet {list-style: none}
+ul.toc-numbered-mark {list-style: none}
 -->
 </style>
 
@@ -272,24 +250,32 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<span id="chap"></span><h2 class="chapter">1 chap</h2>
+<div class="chapter-level-extent" id="chap">
+<h2 class="chapter">1 chap</h2>
 
-<span id="chap2"></span><h2 class="chapter">2 chap2</h2>
+</div>
+<div class="chapter-level-extent" id="chap2">
+<h2 class="chapter">2 chap2</h2>
 
-<span id="sec"></span><h3 class="section">2.1 sec</h3>
+<ul class="mini-toc">
+<li><a href="#sec" accesskey="1">sec</a></li>
+</ul>
+<div class="section-level-extent" id="sec">
+<h3 class="section">2.1 sec</h3>
 
-<span id="SEC_Overview"></span>
+<div class="element-shortcontents" id="SEC_Shortcontents">
 <h2 class="shortcontents-heading">Short Table of Contents</h2>
 
 <div class="shortcontents">
-<ul class="no-bullet">
-<li><a id="stoc-chap" href="#toc-chap">1 chap</a></li>
-<li><a id="stoc-chap2" href="#toc-chap2">2 chap2</a></li>
+<ul class="toc-numbered-mark">
+<li><a id="stoc-chap" href="#chap">1 chap</a></li>
+<li><a id="stoc-chap2" href="#chap2">2 chap2</a></li>
 
 </ul>
 </div>
-
-<hr>
+</div>
+</div>
+</div>
 
 
 
@@ -301,6 +287,7 @@ $result_converted_errors{'html'}->{'shortcontents_no_top'} = [
   {
     'error_line' => 'warning: must specify a title with a title command or @top
 ',
+    'file_name' => 'shortcontents_no_top.texi',
     'text' => 'must specify a title with a title command or @top',
     'type' => 'warning'
   }
