@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -31,12 +31,12 @@ $result_trees{'titles'} = {
             'spaces_before_argument' => ' ',
             'text_arg' => 'html-title.info'
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 1,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'args' => [
@@ -64,13 +64,12 @@ $result_trees{'titles'} = {
                     }
                   ],
                   'cmdname' => 'sc',
-                  'contents' => [],
-                  'line_nr' => {
+                  'parent' => {},
+                  'source_info' => {
                     'file_name' => '',
                     'line_nr' => 2,
                     'macro' => ''
-                  },
-                  'parent' => {}
+                  }
                 },
                 {
                   'parent' => {},
@@ -90,9 +89,12 @@ $result_trees{'titles'} = {
                     }
                   ],
                   'cmdname' => 'code',
-                  'contents' => [],
-                  'line_nr' => {},
-                  'parent' => {}
+                  'parent' => {},
+                  'source_info' => {
+                    'file_name' => '',
+                    'line_nr' => 2,
+                    'macro' => ''
+                  }
                 }
               ],
               'extra' => {
@@ -107,8 +109,12 @@ $result_trees{'titles'} = {
           'extra' => {
             'spaces_before_argument' => ' '
           },
-          'line_nr' => {},
-          'parent' => {}
+          'parent' => {},
+          'source_info' => {
+            'file_name' => '',
+            'line_nr' => 2,
+            'macro' => ''
+          }
         },
         {
           'parent' => {},
@@ -118,7 +124,7 @@ $result_trees{'titles'} = {
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -138,26 +144,27 @@ $result_trees{'titles'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -189,13 +196,12 @@ $result_trees{'titles'} = {
                 }
               ],
               'cmdname' => 'sc',
-              'contents' => [],
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 5,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -215,9 +221,12 @@ $result_trees{'titles'} = {
                 }
               ],
               'cmdname' => 'code',
-              'contents' => [],
-              'line_nr' => {},
-              'parent' => {}
+              'parent' => {},
+              'source_info' => {
+                'file_name' => '',
+                'line_nr' => 5,
+                'macro' => ''
+              }
             }
           ],
           'extra' => {
@@ -268,9 +277,12 @@ $result_trees{'titles'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {},
-      'parent' => {}
+      'parent' => {},
+      'source_info' => {
+        'file_name' => '',
+        'line_nr' => 5,
+        'macro' => ''
+      }
     }
   ],
   'type' => 'document_root'
@@ -286,17 +298,15 @@ $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{
 $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[3]{'parent'} = $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[4]{'args'}[0];
 $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[4];
-$result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[4]{'line_nr'} = $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'line_nr'};
 $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[4]{'parent'} = $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[0]{'contents'}[1];
-$result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'line_nr'} = $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'line_nr'};
 $result_trees{'titles'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'titles'}{'contents'}[0];
 $result_trees{'titles'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'titles'}{'contents'}[0];
 $result_trees{'titles'}{'contents'}[0]{'parent'} = $result_trees{'titles'};
 $result_trees{'titles'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[1]{'args'}[0];
 $result_trees{'titles'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[1];
 $result_trees{'titles'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'titles'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'titles'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'titles'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'titles'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'titles'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'titles'}{'contents'}[1]{'parent'} = $result_trees{'titles'};
 $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[2]{'args'}[0];
 $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'titles'}{'contents'}[2]{'args'}[0];
@@ -307,7 +317,6 @@ $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[3]{'parent'} = $re
 $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[4]{'parent'} = $result_trees{'titles'}{'contents'}[2]{'args'}[0];
 $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[5]{'args'}[0];
 $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[5];
-$result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[5]{'line_nr'} = $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[3]{'line_nr'};
 $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[5]{'parent'} = $result_trees{'titles'}{'contents'}[2]{'args'}[0];
 $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[2];
 $result_trees{'titles'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[2];
@@ -316,7 +325,6 @@ $result_trees{'titles'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{
 $result_trees{'titles'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'titles'}{'contents'}[2];
 $result_trees{'titles'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'titles'}{'contents'}[2]{'contents'}[3];
 $result_trees{'titles'}{'contents'}[2]{'contents'}[3]{'parent'} = $result_trees{'titles'}{'contents'}[2];
-$result_trees{'titles'}{'contents'}[2]{'line_nr'} = $result_trees{'titles'}{'contents'}[2]{'args'}[0]{'contents'}[3]{'line_nr'};
 $result_trees{'titles'}{'contents'}[2]{'parent'} = $result_trees{'titles'};
 
 $result_texis{'titles'} = '@setfilename html-title.info
@@ -341,55 +349,56 @@ Second paragraph.
 ';
 
 $result_sectioning{'titles'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {
-        'associated_node' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'Top',
-            'spaces_before_argument' => ' '
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {
+          'associated_node' => {
+            'cmdname' => 'node',
+            'extra' => {
+              'normalized' => 'Top'
+            }
           }
         },
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_up' => {}
-    }
-  ]
+        'structure' => {
+          'section_level' => 0,
+          'section_up' => {}
+        }
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'titles'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'titles'};
+$result_sectioning{'titles'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'titles'};
 
 $result_nodes{'titles'} = {
   'cmdname' => 'node',
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0
+      'extra' => {},
+      'structure' => {}
     },
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'titles'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'titles'} = [];
 
 
+$result_floats{'titles'} = {};
 
-$result_converted{'html'}->{'titles'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+
+
+$result_converted{'html'}->{'titles'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -400,23 +409,12 @@ $result_converted{'html'}->{'titles'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML
 <meta name="keywords" content="@title HTML test">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-ul.no-bullet {list-style: none}
+h1.settitle {text-align:center}
 -->
 </style>
 
@@ -424,14 +422,16 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<h1 class="settitle" align="center">@title <small>HTML</small> <code>test</code></h1>
+<h1 class="settitle">@title <small class="sc">HTML</small> <code class="code">test</code></h1>
+<hr>
 
-<span id="Top"></span><span id="Top-of-_0040title-HTML-test"></span><h1 class="top">Top of @title <small>HTML</small> <code>test</code></h1>
+<div class="top-level-extent" id="Top">
+<h1 class="top" id="Top-of-_0040title-HTML-test">Top of @title <small class="sc">HTML</small> <code class="code">test</code></h1>
 
 <p>Top.
 </p>
 <p>Second paragraph.
-</p><hr>
+</p></div>
 
 
 
