@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -143,7 +143,7 @@ $result_trees{'value_expansion_in_include'} = {
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -190,13 +190,12 @@ $result_trees{'value_expansion_in_include'} = {
                 }
               ],
               'cmdname' => 'emph',
-              'contents' => [],
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'incl-incl.txi',
                 'line_nr' => 1,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -242,15 +241,16 @@ $result_trees{'value_expansion_in_include'} = {
           ],
           'cmdname' => 'verbatiminclude',
           'extra' => {
+            'input_perl_encoding' => 'utf-8',
             'spaces_before_argument' => ' ',
             'text_arg' => 'incl-incl.txi'
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 14,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -284,13 +284,12 @@ $result_trees{'value_expansion_in_include'} = {
                 }
               ],
               'cmdname' => 'emph',
-              'contents' => [],
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'incl-incl.txi',
                 'line_nr' => 1,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -336,15 +335,16 @@ $result_trees{'value_expansion_in_include'} = {
           ],
           'cmdname' => 'verbatiminclude',
           'extra' => {
+            'input_perl_encoding' => 'utf-8',
             'spaces_before_argument' => ' ',
             'text_arg' => 'incl-incl.txi'
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 19,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -378,13 +378,12 @@ $result_trees{'value_expansion_in_include'} = {
                 }
               ],
               'cmdname' => 'emph',
-              'contents' => [],
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'incl-incl.txi',
                 'line_nr' => 1,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -430,15 +429,16 @@ $result_trees{'value_expansion_in_include'} = {
           ],
           'cmdname' => 'verbatiminclude',
           'extra' => {
+            'input_perl_encoding' => 'utf-8',
             'spaces_before_argument' => ' ',
             'text_arg' => 'incl-incl.txi'
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 24,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         }
       ],
       'extra' => {
@@ -447,19 +447,21 @@ $result_trees{'value_expansion_in_include'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 10,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -526,7 +528,7 @@ $result_trees{'value_expansion_in_include'}{'contents'}[1]{'contents'}[16]{'args
 $result_trees{'value_expansion_in_include'}{'contents'}[1]{'contents'}[16]{'args'}[0]{'parent'} = $result_trees{'value_expansion_in_include'}{'contents'}[1]{'contents'}[16];
 $result_trees{'value_expansion_in_include'}{'contents'}[1]{'contents'}[16]{'parent'} = $result_trees{'value_expansion_in_include'}{'contents'}[1];
 $result_trees{'value_expansion_in_include'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'value_expansion_in_include'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'value_expansion_in_include'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'value_expansion_in_include'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'value_expansion_in_include'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'value_expansion_in_include'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'value_expansion_in_include'}{'contents'}[1]{'parent'} = $result_trees{'value_expansion_in_include'};
 
 $result_texis{'value_expansion_in_include'} = '@set testvar incl-incl.txi
@@ -573,39 +575,23 @@ test_var include: This is the included file (include-value2.txi) <> --.
 
 test_var verbatiminclude: ';
 
-$result_sectioning{'value_expansion_in_include'} = {};
-
 $result_nodes{'value_expansion_in_include'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
+    'normalized' => 'Top'
   }
 };
-$result_nodes{'value_expansion_in_include'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'value_expansion_in_include'};
 
 $result_menus{'value_expansion_in_include'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'value_expansion_in_include'} = [
   {
-    'error_line' => ':12: warning: @include should only appear at the beginning of a line
+    'error_line' => 'warning: @include should only appear at the beginning of a line
 ',
     'file_name' => '',
     'line_nr' => 12,
@@ -614,7 +600,7 @@ $result_errors{'value_expansion_in_include'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => ':17: warning: @include should only appear at the beginning of a line
+    'error_line' => 'warning: @include should only appear at the beginning of a line
 ',
     'file_name' => '',
     'line_nr' => 17,
@@ -623,7 +609,7 @@ $result_errors{'value_expansion_in_include'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => ':22: warning: @include should only appear at the beginning of a line
+    'error_line' => 'warning: @include should only appear at the beginning of a line
 ',
     'file_name' => '',
     'line_nr' => 22,
@@ -634,4 +620,7 @@ $result_errors{'value_expansion_in_include'} = [
 ];
 
 
+$result_floats{'value_expansion_in_include'} = {};
+
+
 1;
