@@ -1,45 +1,52 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'def_existing_index'} = {
   'contents' => [
     {
-      'args' => [
+      'contents' => [
         {
-          'contents' => [
+          'args' => [
             {
+              'contents' => [
+                {
+                  'parent' => {},
+                  'text' => 'cp'
+                }
+              ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'text' => 'cp'
+              'type' => 'line_arg'
             }
           ],
+          'cmdname' => 'defcodeindex',
           'extra' => {
-            'spaces_after_argument' => '
-'
+            'spaces_before_argument' => ' '
           },
           'parent' => {},
-          'type' => 'line_arg'
+          'source_info' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          }
         }
       ],
-      'cmdname' => 'defcodeindex',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'line_nr' => {
-        'file_name' => '',
-        'line_nr' => 1,
-        'macro' => ''
-      },
-      'parent' => {}
+      'parent' => {},
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
-$result_trees{'def_existing_index'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'def_existing_index'}{'contents'}[0]{'args'}[0];
-$result_trees{'def_existing_index'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'def_existing_index'}{'contents'}[0];
+$result_trees{'def_existing_index'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'def_existing_index'}{'contents'}[0]{'contents'}[0]{'args'}[0];
+$result_trees{'def_existing_index'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'def_existing_index'}{'contents'}[0]{'contents'}[0];
+$result_trees{'def_existing_index'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'def_existing_index'}{'contents'}[0];
 $result_trees{'def_existing_index'}{'contents'}[0]{'parent'} = $result_trees{'def_existing_index'};
 
 $result_texis{'def_existing_index'} = '@defcodeindex cp
@@ -50,7 +57,7 @@ $result_texts{'def_existing_index'} = '';
 
 $result_errors{'def_existing_index'} = [
   {
-    'error_line' => ':1: reserved index name cp
+    'error_line' => 'reserved index name cp
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -61,6 +68,9 @@ $result_errors{'def_existing_index'} = [
 ];
 
 
+$result_floats{'def_existing_index'} = {};
+
+
 
 $result_converted{'info'}->{'def_existing_index'} = 'This is , produced from .
 
@@ -92,4 +102,8 @@ $result_converted{'plaintext'}->{'def_existing_index'} = '';
 
 $result_converted{'html_text'}->{'def_existing_index'} = '';
 
+
+$result_converted{'xml'}->{'def_existing_index'} = '<defcodeindex spaces=" " line="cp"></defcodeindex>
+';
+
 1;
