@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -10,10 +10,21 @@ $result_trees{'index_entry_before_first_node'} = {
     {
       'contents' => [
         {
-          'parent' => {},
-          'text' => '
+          'contents' => [
+            {
+              'parent' => {},
+              'text' => '
 ',
-          'type' => 'empty_line'
+              'type' => 'text_before_beginning'
+            }
+          ],
+          'parent' => {},
+          'type' => 'preamble_before_beginning'
+        },
+        {
+          'contents' => [],
+          'parent' => {},
+          'type' => 'preamble_before_content'
         },
         {
           'args' => [
@@ -35,24 +46,24 @@ $result_trees{'index_entry_before_first_node'} = {
           'cmdname' => 'cindex',
           'extra' => {
             'index_entry' => {
-              'command' => {},
-              'content' => [],
               'content_normalized' => [],
+              'entry_content' => [],
+              'entry_element' => {},
+              'entry_number' => 1,
               'in_code' => 0,
               'index_at_command' => 'cindex',
+              'index_ignore_chars' => {},
               'index_name' => 'cp',
-              'index_type_command' => 'cindex',
-              'key' => 'before nodes',
-              'number' => 1
+              'index_type_command' => 'cindex'
             },
             'spaces_before_argument' => ' '
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 2,
             'macro' => ''
           },
-          'parent' => {},
           'type' => 'index_entry_command'
         },
         {
@@ -63,7 +74,7 @@ $result_trees{'index_entry_before_first_node'} = {
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -114,12 +125,12 @@ $result_trees{'index_entry_before_first_node'} = {
             ],
             'spaces_before_argument' => ' '
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 6,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         }
       ],
       'extra' => {
@@ -129,31 +140,35 @@ $result_trees{'index_entry_before_first_node'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
 };
+$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[0];
 $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0];
-$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1];
-$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1]{'extra'}{'index_entry'}{'command'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1];
-$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1]{'extra'}{'index_entry'}{'content'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'};
-$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'};
 $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0];
+$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2]{'args'}[0];
+$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2];
+$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'};
+$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2]{'extra'}{'index_entry'}{'entry_content'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'};
+$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2]{'extra'}{'index_entry'}{'entry_element'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2];
 $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0];
+$result_trees{'index_entry_before_first_node'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[0];
 $result_trees{'index_entry_before_first_node'}{'contents'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'};
 $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'args'}[0];
 $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[1];
@@ -162,7 +177,7 @@ $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'contents'}[1]{'ar
 $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'contents'}[1];
 $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[1];
 $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'index_entry_before_first_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'index_entry_before_first_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'parent'} = $result_trees{'index_entry_before_first_node'};
 
 $result_texis{'index_entry_before_first_node'} = '
@@ -176,17 +191,13 @@ $result_texis{'index_entry_before_first_node'} = '
 
 $result_texts{'index_entry_before_first_node'} = '
 
-
 ';
 
-$result_sectioning{'index_entry_before_first_node'} = {};
-
 $result_nodes{'index_entry_before_first_node'} = {
   'cmdname' => 'node',
   'extra' => {
     'isindex' => 1,
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
@@ -194,14 +205,13 @@ $result_menus{'index_entry_before_first_node'} = {
   'cmdname' => 'node',
   'extra' => {
     'isindex' => 1,
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'index_entry_before_first_node'} = [
   {
-    'error_line' => ':2: warning: entry for index `cp\' outside of any node
+    'error_line' => 'warning: entry for index `cp\' outside of any node
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -212,6 +222,16 @@ $result_errors{'index_entry_before_first_node'} = [
 ];
 
 
+$result_floats{'index_entry_before_first_node'} = {};
+
+
+$result_indices_sort_strings{'index_entry_before_first_node'} = {
+  'cp' => [
+    'before nodes'
+  ]
+};
+
+
 
 $result_converted{'info'}->{'index_entry_before_first_node'} = 'This is , produced from .
 
@@ -238,7 +258,7 @@ End:
 
 $result_converted_errors{'info'}->{'index_entry_before_first_node'} = [
   {
-    'error_line' => ':2: warning: entry for index `cp\' outside of any node
+    'error_line' => 'warning: entry for index `cp\' outside of any node
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -258,7 +278,7 @@ $result_converted{'plaintext'}->{'index_entry_before_first_node'} = '* Menu:
 
 $result_converted_errors{'plaintext'}->{'index_entry_before_first_node'} = [
   {
-    'error_line' => ':2: warning: entry for index `cp\' outside of any node
+    'error_line' => 'warning: entry for index `cp\' outside of any node
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -270,25 +290,28 @@ $result_converted_errors{'plaintext'}->{'index_entry_before_first_node'} = [
 
 
 
-$result_converted{'html_text'}->{'index_entry_before_first_node'} = '
-<span id="index-before-nodes"></span>
+$result_converted{'html_text'}->{'index_entry_before_first_node'} = '<a class="index-entry-id" id="index-before-nodes"></a>
 
-<span id="Top"></span><h1 class="node-heading">Top</h1>
+<h1 class="node" id="Top">Top</h1>
 
-<table><tr><th valign="top">Jump to: &nbsp; </th><td><a class="summary-letter" href="#t_h_cp_letter-B"><b>B</b></a>
- &nbsp; 
-</td></tr></table>
-<table class="index-cp" border="0">
-<tr><td></td><th align="left">Index Entry</th><td>&nbsp;</td><th align="left"> Section</th></tr>
+<div class="printindex cp-printindex">
+<table class="cp-entries-printindex" border="0">
+<tr><td></td><th class="entries-header-printindex">Index Entry</th><td>&nbsp;</td><th class="sections-header-printindex"> Section</th></tr>
 <tr><td colspan="4"> <hr></td></tr>
-<tr><th id="t_h_cp_letter-B">B</th><td></td><td></td></tr>
-<tr><td></td><td valign="top"><a href="#index-before-nodes">before nodes</a>:</td><td>&nbsp;</td><td valign="top"><a href="#Top">Top</a></td></tr>
+<tr><th id="t_i_cp_letter-B">B</th><td></td><td></td></tr>
+<tr><td></td><td class="printindex-index-entry"><a href="#index-before-nodes">before nodes</a>:</td><td>&nbsp;</td><td class="printindex-index-section"><a href="#Top">Top</a></td></tr>
 <tr><td colspan="4"> <hr></td></tr>
 </table>
-<table><tr><th valign="top">Jump to: &nbsp; </th><td><a class="summary-letter" href="#t_h_cp_letter-B"><b>B</b></a>
- &nbsp; 
-</td></tr></table>
-<hr>
+</div>
+';
+
+
+$result_converted{'xml'}->{'index_entry_before_first_node'} = '<preamblebeforebeginning>
+</preamblebeforebeginning><cindex index="cp" spaces=" "><indexterm index="cp" number="1">before nodes</indexterm></cindex>
+
+<node name="Top" spaces=" "><nodename>Top</nodename></node>
+
+<printindex spaces=" " value="cp" line="cp"></printindex>
 ';
 
 1;
