@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -10,17 +10,24 @@ $result_trees{'unknown_index_entry'} = {
     {
       'contents' => [
         {
-          'parent' => {},
-          'text' => ' someindex entry.
+          'contents' => [
+            {
+              'parent' => {},
+              'text' => ' someindex entry.
 '
+            }
+          ],
+          'parent' => {},
+          'type' => 'paragraph'
         }
       ],
       'parent' => {},
-      'type' => 'paragraph'
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
+$result_trees{'unknown_index_entry'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_index_entry'}{'contents'}[0]{'contents'}[0];
 $result_trees{'unknown_index_entry'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_index_entry'}{'contents'}[0];
 $result_trees{'unknown_index_entry'}{'contents'}[0]{'parent'} = $result_trees{'unknown_index_entry'};
 
@@ -33,7 +40,7 @@ $result_texts{'unknown_index_entry'} = ' someindex entry.
 
 $result_errors{'unknown_index_entry'} = [
   {
-    'error_line' => ':1: unknown command `someindex\'
+    'error_line' => 'unknown command `someindex\'
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -44,4 +51,7 @@ $result_errors{'unknown_index_entry'} = [
 ];
 
 
+$result_floats{'unknown_index_entry'} = {};
+
+
 1;
