@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -39,12 +39,12 @@ $result_trees{'encoding_us_ascii'} = {
             'spaces_before_argument' => ' ',
             'text_arg' => 'US-ASCII'
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 2,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -54,7 +54,7 @@ $result_trees{'encoding_us_ascii'} = {
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -88,19 +88,21 @@ $result_trees{'encoding_us_ascii'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -115,7 +117,7 @@ $result_trees{'encoding_us_ascii'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'par
 $result_trees{'encoding_us_ascii'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'encoding_us_ascii'}{'contents'}[1];
 $result_trees{'encoding_us_ascii'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'encoding_us_ascii'}{'contents'}[1];
 $result_trees{'encoding_us_ascii'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'encoding_us_ascii'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'encoding_us_ascii'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'encoding_us_ascii'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'encoding_us_ascii'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'encoding_us_ascii'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'encoding_us_ascii'}{'contents'}[1]{'parent'} = $result_trees{'encoding_us_ascii'};
 
 $result_texis{'encoding_us_ascii'} = '
@@ -131,27 +133,26 @@ $result_texts{'encoding_us_ascii'} = '
 
 ';
 
-$result_sectioning{'encoding_us_ascii'} = {};
-
 $result_nodes{'encoding_us_ascii'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'encoding_us_ascii'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'encoding_us_ascii'} = [];
 
 
+$result_floats{'encoding_us_ascii'} = {};
+
+
 
 $result_converted{'info'}->{'encoding_us_ascii'} = 'This is , produced from .
 
