@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'image_and_punctuation'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -57,14 +56,15 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
-              'contents' => [],
-              'extra' => {},
-              'line_nr' => {
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 3,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -101,14 +101,15 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
-              'contents' => [],
-              'extra' => {},
-              'line_nr' => {
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 5,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -146,14 +147,15 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
-              'contents' => [],
-              'extra' => {},
-              'line_nr' => {
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 8,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -190,14 +192,15 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
-              'contents' => [],
-              'extra' => {},
-              'line_nr' => {
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 10,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -234,14 +237,15 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
-              'contents' => [],
-              'extra' => {},
-              'line_nr' => {
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 12,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -279,14 +283,15 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
-              'contents' => [],
-              'extra' => {},
-              'line_nr' => {
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 15,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -304,19 +309,21 @@ $result_trees{'image_and_punctuation'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -367,7 +374,7 @@ $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'image_and_punctuation'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'parent'} = $result_trees{'image_and_punctuation'};
 
 $result_texis{'image_and_punctuation'} = '@node Top
@@ -404,62 +411,54 @@ End line.
 words.
 ';
 
-$result_sectioning{'image_and_punctuation'} = {};
-
 $result_nodes{'image_and_punctuation'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
+    'normalized' => 'Top'
   }
 };
-$result_nodes{'image_and_punctuation'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'image_and_punctuation'};
 
 $result_menus{'image_and_punctuation'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'image_and_punctuation'} = [];
 
 
+$result_floats{'image_and_punctuation'} = {};
+
+
 
 $result_converted{'info'}->{'image_and_punctuation'} = 'This is , produced from .
 
 
 File: ,  Node: Top,  Up: (dir)
 
-One space.  [image src="f--ile.png" text="Image description\\"\\"\\\\." ].
+One space.   [image src="f--ile.png" text="Image description\\"\\"\\\\." ].
 
    Two spaces.   [image src="f--ile.png" text="Image description\\"\\"\\\\." ].
 
-   End line.  [image src="f--ile.png" text="Image description\\"\\"\\\\." ].
+   End line.   [image src="f--ile.png" text="Image description\\"\\"\\\\." ].
 
-   One space. This is an image words..
+   One space.  This is an image words..
 
    Two spaces.  This is an image words..
 
-   End line. This is an image words..
+   End line.  This is an image words..
 
 
 Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
