@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'image_in_paragraph'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -57,12 +56,10 @@ $result_trees{'image_in_paragraph'} = {
                   'type' => 'brace_command_arg'
                 },
                 {
-                  'contents' => [],
                   'parent' => {},
                   'type' => 'brace_command_arg'
                 },
                 {
-                  'contents' => [],
                   'parent' => {},
                   'type' => 'brace_command_arg'
                 },
@@ -78,16 +75,15 @@ $result_trees{'image_in_paragraph'} = {
                 }
               ],
               'cmdname' => 'image',
-              'contents' => [],
               'extra' => {
                 'input_perl_encoding' => 'utf-8'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 4,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -105,19 +101,21 @@ $result_trees{'image_in_paragraph'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -137,7 +135,7 @@ $result_trees{'image_in_paragraph'}{'contents'}[1]{'contents'}[1]{'contents'}[1]
 $result_trees{'image_in_paragraph'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'image_in_paragraph'}{'contents'}[1]{'contents'}[1];
 $result_trees{'image_in_paragraph'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'image_in_paragraph'}{'contents'}[1];
 $result_trees{'image_in_paragraph'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'image_in_paragraph'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'image_in_paragraph'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'image_in_paragraph'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'image_in_paragraph'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'image_in_paragraph'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_in_paragraph'}{'contents'}[1]{'parent'} = $result_trees{'image_in_paragraph'};
 
 $result_texis{'image_in_paragraph'} = '@node Top
@@ -152,34 +150,33 @@ Para.
 f--ile. End para.
 ';
 
-$result_sectioning{'image_in_paragraph'} = {};
-
 $result_nodes{'image_in_paragraph'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'image_in_paragraph'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'image_in_paragraph'} = [];
 
 
+$result_floats{'image_in_paragraph'} = {};
+
+
 
 $result_converted{'info'}->{'image_in_paragraph'} = 'This is , produced from .
 
 
 File: ,  Node: Top,  Up: (dir)
 
-Para.  [image src="f--ile.png" alt="alt\\"\\"\\\\" text="Image description\\"\\"\\\\." ].  End para.
+Para.   [image src="f--ile.png" alt="alt\\"\\"\\\\" text="Image description\\"\\"\\\\." ].  End para.
 
 
 Tag Table:
