@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'index_entry_at_end_node'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -30,26 +29,27 @@ $result_trees{'index_entry_at_end_node'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -83,17 +83,18 @@ $result_trees{'index_entry_at_end_node'} = {
           'type' => 'empty_line'
         },
         {
-          'cmdname' => 'menu',
-          'contents' => [
+          'args' => [
             {
               'extra' => {
-                'command' => {}
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
+              'type' => 'block_line_arg'
+            }
+          ],
+          'cmdname' => 'menu',
+          'contents' => [
             {
               'args' => [
                 {
@@ -143,12 +144,12 @@ $result_trees{'index_entry_at_end_node'} = {
                   'normalized' => 'chapter'
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 6,
                 'macro' => ''
               },
-              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -200,12 +201,12 @@ $result_trees{'index_entry_at_end_node'} = {
                   'normalized' => 'indices'
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 7,
                 'macro' => ''
               },
-              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -227,27 +228,23 @@ $result_trees{'index_entry_at_end_node'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'menu',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 8,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 5,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -259,13 +256,12 @@ $result_trees{'index_entry_at_end_node'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 2,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -285,26 +281,27 @@ $result_trees{'index_entry_at_end_node'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'chapter'
           }
         ],
         'normalized' => 'chapter',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 10,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -363,25 +360,25 @@ $result_trees{'index_entry_at_end_node'} = {
           'cmdname' => 'cindex',
           'extra' => {
             'index_entry' => {
-              'command' => {},
-              'content' => [],
               'content_normalized' => [],
+              'entry_content' => [],
+              'entry_element' => {},
+              'entry_node' => {},
+              'entry_number' => 1,
               'in_code' => 0,
               'index_at_command' => 'cindex',
+              'index_ignore_chars' => {},
               'index_name' => 'cp',
-              'index_type_command' => 'cindex',
-              'key' => 'index entry',
-              'node' => {},
-              'number' => 1
+              'index_type_command' => 'cindex'
             },
             'spaces_before_argument' => ' '
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 15,
             'macro' => ''
           },
-          'parent' => {},
           'type' => 'index_entry_command'
         },
         {
@@ -394,14 +391,12 @@ $result_trees{'index_entry_at_end_node'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 11,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -421,7 +416,6 @@ $result_trees{'index_entry_at_end_node'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'isindex' => 1,
         'node_content' => [
@@ -429,19 +423,21 @@ $result_trees{'index_entry_at_end_node'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'indices'
           }
         ],
         'normalized' => 'indices',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 17,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -492,25 +488,23 @@ $result_trees{'index_entry_at_end_node'} = {
             ],
             'spaces_before_argument' => ' '
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 20,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         }
       ],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 18,
         'macro' => ''
-      },
-      'number' => 'A',
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -519,13 +513,22 @@ $result_trees{'index_entry_at_end_node'}{'contents'}[0]{'parent'} = $result_tree
 $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[1];
 $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'index_entry_at_end_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'index_entry_at_end_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'parent'} = $result_trees{'index_entry_at_end_node'};
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'extra'}{'command'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[1];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[3]{'contents'}[0];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[3];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[3];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'args'}[1]{'contents'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[1];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[1]{'args'}[1];
@@ -537,27 +540,16 @@ $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[1]{'args'}[3];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2];
+$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[1];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[1]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[2]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[3]{'contents'}[0];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[3];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[3]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'extra'}{'menu_entry_description'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[3];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'args'}[1]{'contents'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[3]{'args'}[0];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[3];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[3]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2];
-$result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'extra'}{'end_command'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'contents'}[3];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'contents'}[3]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'parent'} = $result_trees{'index_entry_at_end_node'};
 $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[3];
 $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'index_entry_at_end_node'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'index_entry_at_end_node'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'parent'} = $result_trees{'index_entry_at_end_node'};
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4];
@@ -566,17 +558,17 @@ $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[1]{'parent'}
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[2]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4];
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3];
-$result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'extra'}{'index_entry'}{'command'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3];
-$result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'extra'}{'index_entry'}{'content'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'args'}[0]{'contents'};
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'args'}[0]{'contents'};
-$result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'extra'}{'index_entry'}{'node'} = $result_trees{'index_entry_at_end_node'}{'contents'}[3];
+$result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'extra'}{'index_entry'}{'entry_content'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'args'}[0]{'contents'};
+$result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'extra'}{'index_entry'}{'entry_element'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3];
+$result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'extra'}{'index_entry'}{'entry_node'} = $result_trees{'index_entry_at_end_node'}{'contents'}[3];
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[3]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4];
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'contents'}[4]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4];
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'parent'} = $result_trees{'index_entry_at_end_node'};
 $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[5];
 $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'args'}[0]{'contents'}[0];
-$result_trees{'index_entry_at_end_node'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'extra'}{'node_content'};
+$result_trees{'index_entry_at_end_node'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'parent'} = $result_trees{'index_entry_at_end_node'};
 $result_trees{'index_entry_at_end_node'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[6]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[6];
@@ -628,183 +620,190 @@ Appendix A indices
 ';
 
 $result_sectioning{'index_entry_at_end_node'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {
-        'associated_node' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'Top',
-            'spaces_before_argument' => ' '
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {
+          'associated_node' => {
+            'cmdname' => 'node',
+            'extra' => {
+              'normalized' => 'Top'
+            },
+            'structure' => {}
           }
         },
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_childs' => [
-        {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'associated_node' => {
-              'cmdname' => 'node',
+        'structure' => {
+          'section_childs' => [
+            {
+              'cmdname' => 'chapter',
               'extra' => {
-                'normalized' => 'chapter',
-                'spaces_before_argument' => ' '
+                'associated_node' => {
+                  'cmdname' => 'node',
+                  'extra' => {
+                    'normalized' => 'chapter'
+                  },
+                  'structure' => {}
+                }
+              },
+              'structure' => {
+                'section_level' => 1,
+                'section_number' => 1,
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
               }
             },
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 1,
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
-        },
-        {
-          'cmdname' => 'appendix',
-          'extra' => {
-            'associated_node' => {
-              'cmdname' => 'node',
+            {
+              'cmdname' => 'appendix',
               'extra' => {
-                'isindex' => 1,
-                'normalized' => 'indices',
-                'spaces_before_argument' => ' '
+                'associated_node' => {
+                  'cmdname' => 'node',
+                  'extra' => {
+                    'isindex' => 1,
+                    'normalized' => 'indices'
+                  },
+                  'structure' => {}
+                }
+              },
+              'structure' => {
+                'section_level' => 1,
+                'section_number' => 'A',
+                'section_prev' => {},
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
               }
-            },
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 'A',
-          'section_prev' => {},
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
+            }
+          ],
+          'section_level' => 0,
+          'section_up' => {}
         }
-      ],
-      'section_up' => {}
-    }
-  ]
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0];
-$result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0];
-$result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0];
-$result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0]{'section_childs'}[1]{'section_prev'} = $result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0]{'section_childs'}[1]{'section_up'} = $result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0];
-$result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0]{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0]{'section_childs'}[1]{'toplevel_up'} = $result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0];
-$result_sectioning{'index_entry_at_end_node'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'index_entry_at_end_node'};
+$result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_prev'} = $result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_up'} = $result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'index_entry_at_end_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'index_entry_at_end_node'};
 
 $result_nodes{'index_entry_at_end_node'} = {
   'cmdname' => 'node',
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0
+      'extra' => {},
+      'structure' => {}
     },
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'menus' => [
+      {
+        'cmdname' => 'menu'
+      }
+    ],
+    'normalized' => 'Top'
   },
-  'menu_child' => {
-    'cmdname' => 'node',
-    'extra' => {
-      'associated_section' => {
-        'cmdname' => 'chapter',
-        'extra' => {
-          'spaces_before_argument' => ' '
-        },
-        'level' => 1,
-        'number' => 1
-      },
-      'normalized' => 'chapter',
-      'spaces_before_argument' => ' '
-    },
-    'node_next' => {
+  'structure' => {
+    'menu_child' => {
       'cmdname' => 'node',
       'extra' => {
         'associated_section' => {
-          'cmdname' => 'appendix',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 'A'
-        },
-        'isindex' => 1,
-        'normalized' => 'indices',
-        'spaces_before_argument' => ' '
-      },
-      'node_prev' => {},
-      'node_up' => {}
-    },
-    'node_prev' => {},
-    'node_up' => {}
-  },
-  'menus' => [
-    {
-      'cmdname' => 'menu',
-      'extra' => {
-        'end_command' => {
-          'cmdname' => 'end',
-          'extra' => {
-            'command_argument' => 'menu',
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'menu'
+          'cmdname' => 'chapter',
+          'extra' => {},
+          'structure' => {
+            'section_number' => 1
           }
-        }
+        },
+        'normalized' => 'chapter'
+      },
+      'structure' => {
+        'node_next' => {
+          'cmdname' => 'node',
+          'extra' => {
+            'associated_section' => {
+              'cmdname' => 'appendix',
+              'extra' => {},
+              'structure' => {
+                'section_number' => 'A'
+              }
+            },
+            'isindex' => 1,
+            'normalized' => 'indices'
+          },
+          'structure' => {
+            'node_prev' => {},
+            'node_up' => {}
+          }
+        },
+        'node_prev' => {},
+        'node_up' => {}
       }
-    }
-  ],
-  'node_next' => {}
+    },
+    'node_next' => {}
+  }
 };
-$result_nodes{'index_entry_at_end_node'}{'menu_child'}{'node_next'}{'node_prev'} = $result_nodes{'index_entry_at_end_node'}{'menu_child'};
-$result_nodes{'index_entry_at_end_node'}{'menu_child'}{'node_next'}{'node_up'} = $result_nodes{'index_entry_at_end_node'};
-$result_nodes{'index_entry_at_end_node'}{'menu_child'}{'node_prev'} = $result_nodes{'index_entry_at_end_node'};
-$result_nodes{'index_entry_at_end_node'}{'menu_child'}{'node_up'} = $result_nodes{'index_entry_at_end_node'};
-$result_nodes{'index_entry_at_end_node'}{'node_next'} = $result_nodes{'index_entry_at_end_node'}{'menu_child'};
+$result_nodes{'index_entry_at_end_node'}{'structure'}{'menu_child'}{'structure'}{'node_next'}{'structure'}{'node_prev'} = $result_nodes{'index_entry_at_end_node'}{'structure'}{'menu_child'};
+$result_nodes{'index_entry_at_end_node'}{'structure'}{'menu_child'}{'structure'}{'node_next'}{'structure'}{'node_up'} = $result_nodes{'index_entry_at_end_node'};
+$result_nodes{'index_entry_at_end_node'}{'structure'}{'menu_child'}{'structure'}{'node_prev'} = $result_nodes{'index_entry_at_end_node'};
+$result_nodes{'index_entry_at_end_node'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'index_entry_at_end_node'};
+$result_nodes{'index_entry_at_end_node'}{'structure'}{'node_next'} = $result_nodes{'index_entry_at_end_node'}{'structure'}{'menu_child'};
 
 $result_menus{'index_entry_at_end_node'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   },
-  'menu_child' => {
-    'cmdname' => 'node',
-    'extra' => {
-      'normalized' => 'chapter',
-      'spaces_before_argument' => ' '
-    },
-    'menu_next' => {
+  'structure' => {
+    'menu_child' => {
       'cmdname' => 'node',
       'extra' => {
-        'isindex' => 1,
-        'normalized' => 'indices',
-        'spaces_before_argument' => ' '
+        'normalized' => 'chapter'
       },
-      'menu_prev' => {},
-      'menu_up' => {},
-      'menu_up_hash' => {
-        'Top' => 1
+      'structure' => {
+        'menu_next' => {
+          'cmdname' => 'node',
+          'extra' => {
+            'isindex' => 1,
+            'normalized' => 'indices'
+          },
+          'structure' => {
+            'menu_prev' => {},
+            'menu_up' => {},
+            'menu_up_hash' => {
+              'Top' => 1
+            }
+          }
+        },
+        'menu_up' => {},
+        'menu_up_hash' => {
+          'Top' => 1
+        }
       }
-    },
-    'menu_up' => {},
-    'menu_up_hash' => {
-      'Top' => 1
     }
   }
 };
-$result_menus{'index_entry_at_end_node'}{'menu_child'}{'menu_next'}{'menu_prev'} = $result_menus{'index_entry_at_end_node'}{'menu_child'};
-$result_menus{'index_entry_at_end_node'}{'menu_child'}{'menu_next'}{'menu_up'} = $result_menus{'index_entry_at_end_node'};
-$result_menus{'index_entry_at_end_node'}{'menu_child'}{'menu_up'} = $result_menus{'index_entry_at_end_node'};
+$result_menus{'index_entry_at_end_node'}{'structure'}{'menu_child'}{'structure'}{'menu_next'}{'structure'}{'menu_prev'} = $result_menus{'index_entry_at_end_node'}{'structure'}{'menu_child'};
+$result_menus{'index_entry_at_end_node'}{'structure'}{'menu_child'}{'structure'}{'menu_next'}{'structure'}{'menu_up'} = $result_menus{'index_entry_at_end_node'};
+$result_menus{'index_entry_at_end_node'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'index_entry_at_end_node'};
 
 $result_errors{'index_entry_at_end_node'} = [];
 
 
+$result_floats{'index_entry_at_end_node'} = {};
+
+
+$result_indices_sort_strings{'index_entry_at_end_node'} = {
+  'cp' => [
+    'index entry'
+  ]
+};
+
+
 
 $result_converted{'info'}->{'index_entry_at_end_node'} = 'This is , produced from .
 
