@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -10,16 +10,23 @@ $result_trees{'no_nodes'} = {
     {
       'contents' => [
         {
+          'contents' => [
+            {
+              'parent' => {},
+              'text' => 'Text.'
+            }
+          ],
           'parent' => {},
-          'text' => 'Text.'
+          'type' => 'paragraph'
         }
       ],
       'parent' => {},
-      'type' => 'paragraph'
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
+$result_trees{'no_nodes'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_nodes'}{'contents'}[0]{'contents'}[0];
 $result_trees{'no_nodes'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_nodes'}{'contents'}[0];
 $result_trees{'no_nodes'}{'contents'}[0]{'parent'} = $result_trees{'no_nodes'};
 
@@ -31,6 +38,9 @@ $result_texts{'no_nodes'} = 'Text.';
 $result_errors{'no_nodes'} = [];
 
 
+$result_floats{'no_nodes'} = {};
+
+
 
 $result_converted{'info'}->{'no_nodes'} = 'This is , produced from .
 
