@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'note_in_strong_end_of_line'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -57,13 +56,12 @@ $result_trees{'note_in_strong_end_of_line'} = {
                 }
               ],
               'cmdname' => 'strong',
-              'contents' => [],
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 3,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -105,13 +103,12 @@ $result_trees{'note_in_strong_end_of_line'} = {
                 }
               ],
               'cmdname' => 'strong',
-              'contents' => [],
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 5,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -129,19 +126,21 @@ $result_trees{'note_in_strong_end_of_line'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -165,7 +164,7 @@ $result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'contents'}[3]{'conte
 $result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'contents'}[3];
 $result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'note_in_strong_end_of_line'}{'contents'}[1];
 $result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'note_in_strong_end_of_line'}{'contents'}[1]{'parent'} = $result_trees{'note_in_strong_end_of_line'};
 
 $result_texis{'note_in_strong_end_of_line'} = '@node Top
@@ -184,27 +183,26 @@ bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb vvvvvvvvvvvvvvvv note
 a
 ';
 
-$result_sectioning{'note_in_strong_end_of_line'} = {};
-
 $result_nodes{'note_in_strong_end_of_line'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'note_in_strong_end_of_line'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'note_in_strong_end_of_line'} = [];
 
 
+$result_floats{'note_in_strong_end_of_line'} = {};
+
+
 
 $result_converted{'info'}->{'note_in_strong_end_of_line'} = 'This is , produced from .
 
@@ -231,7 +229,7 @@ End:
 
 $result_converted_errors{'info'}->{'note_in_strong_end_of_line'} = [
   {
-    'error_line' => ':3: warning: @strong{Note...} produces a spurious cross-reference in Info; reword to avoid that
+    'error_line' => 'warning: @strong{Note...} produces a spurious cross-reference in Info; reword to avoid that
 ',
     'file_name' => '',
     'line_nr' => 3,
@@ -240,7 +238,7 @@ $result_converted_errors{'info'}->{'note_in_strong_end_of_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => ':5: warning: @strong{Note...} produces a spurious cross-reference in Info; reword to avoid that
+    'error_line' => 'warning: @strong{Note...} produces a spurious cross-reference in Info; reword to avoid that
 ',
     'file_name' => '',
     'line_nr' => 5,
