@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -42,12 +42,12 @@ $result_trees{'split_no_copying'} = {
             'spaces_before_argument' => ' ',
             'text_arg' => 'split-nocopying.info'
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 2,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -57,7 +57,7 @@ $result_trees{'split_no_copying'} = {
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -77,26 +77,27 @@ $result_trees{'split_no_copying'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -141,17 +142,18 @@ $result_trees{'split_no_copying'} = {
           'type' => 'empty_line'
         },
         {
-          'cmdname' => 'menu',
-          'contents' => [
+          'args' => [
             {
               'extra' => {
-                'command' => {}
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
+              'type' => 'block_line_arg'
+            }
+          ],
+          'cmdname' => 'menu',
+          'contents' => [
             {
               'args' => [
                 {
@@ -201,12 +203,12 @@ $result_trees{'split_no_copying'} = {
                   'normalized' => 'Ch1'
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 10,
                 'macro' => ''
               },
-              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -228,27 +230,23 @@ $result_trees{'split_no_copying'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'menu',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 11,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 9,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -260,13 +258,12 @@ $result_trees{'split_no_copying'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -286,26 +283,27 @@ $result_trees{'split_no_copying'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Ch1'
           }
         ],
         'normalized' => 'Ch1',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 13,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -353,14 +351,12 @@ $result_trees{'split_no_copying'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 14,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -387,7 +383,7 @@ $result_trees{'split_no_copying'}{'contents'}[0]{'parent'} = $result_trees{'spli
 $result_trees{'split_no_copying'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[1]{'args'}[0];
 $result_trees{'split_no_copying'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[1];
 $result_trees{'split_no_copying'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'split_no_copying'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'split_no_copying'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_no_copying'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'split_no_copying'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_no_copying'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'split_no_copying'}{'contents'}[1]{'parent'} = $result_trees{'split_no_copying'};
 $result_trees{'split_no_copying'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'args'}[0];
 $result_trees{'split_no_copying'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2];
@@ -395,29 +391,27 @@ $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[0]{'parent'} = $res
 $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[1];
 $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2];
 $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'command'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'contents'}[0];
 $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3];
+$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0];
 $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[2];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3];
-$result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'contents'}[2];
 $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[3]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2];
 $result_trees{'split_no_copying'}{'contents'}[2]{'contents'}[4]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[2];
 $result_trees{'split_no_copying'}{'contents'}[2]{'parent'} = $result_trees{'split_no_copying'};
 $result_trees{'split_no_copying'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[3]{'args'}[0];
 $result_trees{'split_no_copying'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[3];
 $result_trees{'split_no_copying'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'split_no_copying'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'split_no_copying'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_no_copying'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'split_no_copying'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_no_copying'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'split_no_copying'}{'contents'}[3]{'parent'} = $result_trees{'split_no_copying'};
 $result_trees{'split_no_copying'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[4]{'args'}[0];
 $result_trees{'split_no_copying'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'split_no_copying'}{'contents'}[4];
@@ -467,136 +461,122 @@ First chapter.
 ';
 
 $result_sectioning{'split_no_copying'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {
-        'associated_node' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'Top',
-            'spaces_before_argument' => ' '
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {
+          'associated_node' => {
+            'cmdname' => 'node',
+            'extra' => {
+              'normalized' => 'Top'
+            },
+            'structure' => {}
           }
         },
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_childs' => [
-        {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'associated_node' => {
-              'cmdname' => 'node',
+        'structure' => {
+          'section_childs' => [
+            {
+              'cmdname' => 'chapter',
               'extra' => {
-                'normalized' => 'Ch1',
-                'spaces_before_argument' => ' '
+                'associated_node' => {
+                  'cmdname' => 'node',
+                  'extra' => {
+                    'normalized' => 'Ch1'
+                  },
+                  'structure' => {}
+                }
+              },
+              'structure' => {
+                'section_level' => 1,
+                'section_number' => 1,
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
               }
-            },
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 1,
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
+            }
+          ],
+          'section_level' => 0,
+          'section_up' => {}
         }
-      ],
-      'section_up' => {}
-    }
-  ]
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'split_no_copying'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'split_no_copying'}{'section_childs'}[0];
-$result_sectioning{'split_no_copying'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'split_no_copying'}{'section_childs'}[0];
-$result_sectioning{'split_no_copying'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'split_no_copying'}{'section_childs'}[0];
-$result_sectioning{'split_no_copying'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'split_no_copying'};
+$result_sectioning{'split_no_copying'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'split_no_copying'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'split_no_copying'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'split_no_copying'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'split_no_copying'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'split_no_copying'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'split_no_copying'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'split_no_copying'};
 
 $result_nodes{'split_no_copying'} = {
   'cmdname' => 'node',
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0
+      'extra' => {},
+      'structure' => {}
     },
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'menus' => [
+      {
+        'cmdname' => 'menu'
+      }
+    ],
+    'normalized' => 'Top'
   },
-  'menu_child' => {
-    'cmdname' => 'node',
-    'extra' => {
-      'associated_section' => {
-        'cmdname' => 'chapter',
-        'extra' => {
-          'spaces_before_argument' => ' '
+  'structure' => {
+    'menu_child' => {
+      'cmdname' => 'node',
+      'extra' => {
+        'associated_section' => {
+          'cmdname' => 'chapter',
+          'extra' => {},
+          'structure' => {
+            'section_number' => 1
+          }
         },
-        'level' => 1,
-        'number' => 1
+        'normalized' => 'Ch1'
       },
-      'normalized' => 'Ch1',
-      'spaces_before_argument' => ' '
-    },
-    'node_prev' => {},
-    'node_up' => {}
-  },
-  'menus' => [
-    {
-      'cmdname' => 'menu',
-      'extra' => {
-        'end_command' => {
-          'cmdname' => 'end',
-          'extra' => {
-            'command_argument' => 'menu',
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'menu'
-          }
-        }
+      'structure' => {
+        'node_prev' => {},
+        'node_up' => {}
       }
-    }
-  ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
     },
-    'type' => 'top_node_up'
+    'node_next' => {}
   }
 };
-$result_nodes{'split_no_copying'}{'menu_child'}{'node_prev'} = $result_nodes{'split_no_copying'};
-$result_nodes{'split_no_copying'}{'menu_child'}{'node_up'} = $result_nodes{'split_no_copying'};
-$result_nodes{'split_no_copying'}{'node_next'} = $result_nodes{'split_no_copying'}{'menu_child'};
-$result_nodes{'split_no_copying'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'split_no_copying'};
+$result_nodes{'split_no_copying'}{'structure'}{'menu_child'}{'structure'}{'node_prev'} = $result_nodes{'split_no_copying'};
+$result_nodes{'split_no_copying'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'split_no_copying'};
+$result_nodes{'split_no_copying'}{'structure'}{'node_next'} = $result_nodes{'split_no_copying'}{'structure'}{'menu_child'};
 
 $result_menus{'split_no_copying'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   },
-  'menu_child' => {
-    'cmdname' => 'node',
-    'extra' => {
-      'normalized' => 'Ch1',
-      'spaces_before_argument' => ' '
-    },
-    'menu_up' => {},
-    'menu_up_hash' => {
-      'Top' => 1
+  'structure' => {
+    'menu_child' => {
+      'cmdname' => 'node',
+      'extra' => {
+        'normalized' => 'Ch1'
+      },
+      'structure' => {
+        'menu_up' => {},
+        'menu_up_hash' => {
+          'Top' => 1
+        }
+      }
     }
   }
 };
-$result_menus{'split_no_copying'}{'menu_child'}{'menu_up'} = $result_menus{'split_no_copying'};
+$result_menus{'split_no_copying'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'split_no_copying'};
 
 $result_errors{'split_no_copying'} = [];
 
 
+$result_floats{'split_no_copying'} = {};
+
+
 
 $result_converted{'info'}->{'split_no_copying'} = 'This is split-nocopying.info, produced from .
 
@@ -629,6 +609,11 @@ Node: Top63
 Node: Ch1179
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
