@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,7 +17,7 @@ $result_trees{'xref_test'} = {
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -72,7 +72,6 @@ $result_trees{'xref_test'} = {
                 }
               ],
               'cmdname' => 'xref',
-              'contents' => [],
               'extra' => {
                 'node_argument' => {
                   'manual_content' => [
@@ -83,12 +82,12 @@ $result_trees{'xref_test'} = {
                   ]
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 4,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -120,7 +119,6 @@ $result_trees{'xref_test'} = {
                 }
               ],
               'cmdname' => 'xref',
-              'contents' => [],
               'extra' => {
                 'node_argument' => {
                   'manual_content' => [
@@ -131,8 +129,12 @@ $result_trees{'xref_test'} = {
                   ]
                 }
               },
-              'line_nr' => {},
-              'parent' => {}
+              'parent' => {},
+              'source_info' => {
+                'file_name' => '',
+                'line_nr' => 4,
+                'macro' => ''
+              }
             },
             {
               'parent' => {},
@@ -169,7 +171,6 @@ $result_trees{'xref_test'} = {
                         }
                       ],
                       'cmdname' => 'xref',
-                      'contents' => [],
                       'extra' => {
                         'node_argument' => {
                           'manual_content' => [
@@ -180,12 +181,12 @@ $result_trees{'xref_test'} = {
                           ]
                         }
                       },
-                      'line_nr' => {
+                      'parent' => {},
+                      'source_info' => {
                         'file_name' => '',
                         'line_nr' => 5,
                         'macro' => ''
-                      },
-                      'parent' => {}
+                      }
                     }
                   ],
                   'parent' => {},
@@ -193,9 +194,12 @@ $result_trees{'xref_test'} = {
                 }
               ],
               'cmdname' => 'code',
-              'contents' => [],
-              'line_nr' => {},
-              'parent' => {}
+              'parent' => {},
+              'source_info' => {
+                'file_name' => '',
+                'line_nr' => 5,
+                'macro' => ''
+              }
             },
             {
               'parent' => {},
@@ -241,7 +245,6 @@ $result_trees{'xref_test'} = {
                 }
               ],
               'cmdname' => 'xref',
-              'contents' => [],
               'extra' => {
                 'node_argument' => {
                   'manual_content' => [
@@ -252,12 +255,12 @@ $result_trees{'xref_test'} = {
                   ]
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 6,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -290,7 +293,6 @@ $result_trees{'xref_test'} = {
                 }
               ],
               'cmdname' => 'xref',
-              'contents' => [],
               'extra' => {
                 'node_argument' => {
                   'manual_content' => [
@@ -301,12 +303,12 @@ $result_trees{'xref_test'} = {
                   ]
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 7,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -324,19 +326,21 @@ $result_trees{'xref_test'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 2,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -362,7 +366,6 @@ $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'node_argument'}{'manual_content'}[0] = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1];
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'node_argument'}{'node_content'}[0] = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[3];
-$result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'line_nr'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1];
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1];
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'args'}[0];
@@ -374,7 +377,6 @@ $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'extra'}{'node_argument'}{'node_content'}[0] = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[3];
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4];
-$result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'line_nr'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1];
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1];
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[6]{'args'}[0];
@@ -399,7 +401,7 @@ $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[8]{'parent'
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1];
 $result_trees{'xref_test'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'xref_test'}{'contents'}[1];
 $result_trees{'xref_test'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'xref_test'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'xref_test'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'xref_test'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'xref_test'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'xref_test'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'xref_test'}{'contents'}[1]{'parent'} = $result_trees{'xref_test'};
 
 $result_texis{'xref_test'} = '
@@ -420,35 +422,34 @@ $result_texts{'xref_test'} = '
 (m)in ref followed by symbol# g.
 ';
 
-$result_sectioning{'xref_test'} = {};
-
 $result_nodes{'xref_test'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'xref_test'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'xref_test'} = [];
 
 
+$result_floats{'xref_test'} = {};
+
+
 
 $result_converted{'info'}->{'xref_test'} = 'This is , produced from .
 
 
 File: ,  Node: Top,  Up: (dir)
 
-*Note (m)in xref::.  *Note (m)bad xref:: after xref.  \'*Note (m)bad
-nested xref::\'.  *Note name: (m)in ref ending with a dot.. !  after xref
+*Note (m)in xref::.  *Note (m)bad xref:: after xref.  ‘*Note (m)bad
+nested xref::’.  *Note name: (m)in ref ending with a dot.. !  after xref
 and dot inside.  *Note (m)in ref followed by symbol::# g.
 
 
@@ -465,7 +466,7 @@ End:
 
 $result_converted_errors{'info'}->{'xref_test'} = [
   {
-    'error_line' => ':6: warning: @xref node name should not contain `.\'
+    'error_line' => 'warning: @xref node name should not contain `.\'
 ',
     'file_name' => '',
     'line_nr' => 6,
@@ -474,7 +475,7 @@ $result_converted_errors{'info'}->{'xref_test'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => ':6: warning: `.\' or `,\' must follow @xref, not !
+    'error_line' => 'warning: `.\' or `,\' must follow @xref, not !
 ',
     'file_name' => '',
     'line_nr' => 6,
