@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'ignored_text'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -26,16 +25,15 @@ $result_trees{'ignored_text'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -50,11 +48,9 @@ $result_texis{'ignored_text'} = '@node before ignore ';
 
 $result_texts{'ignored_text'} = '';
 
-$result_sectioning{'ignored_text'} = {};
-
 $result_errors{'ignored_text'} = [
   {
-    'error_line' => ':1: warning: @ifinfo should only appear at the beginning of a line
+    'error_line' => 'warning: @ifinfo should only appear at the beginning of a line
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -63,7 +59,7 @@ $result_errors{'ignored_text'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => ':3: warning: superfluous argument to @end ifinfo:  on the node line
+    'error_line' => 'warning: superfluous argument to @end ifinfo:  on the node line
 ',
     'file_name' => '',
     'line_nr' => 3,
@@ -74,4 +70,7 @@ $result_errors{'ignored_text'} = [
 ];
 
 
+$result_floats{'ignored_text'} = {};
+
+
 1;
