@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'ref_in_anchor'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -53,7 +52,6 @@ $result_trees{'ref_in_anchor'} = {
                     }
                   ],
                   'cmdname' => 'ref',
-                  'contents' => [],
                   'extra' => {
                     'label' => {},
                     'node_argument' => {
@@ -63,12 +61,12 @@ $result_trees{'ref_in_anchor'} = {
                       'normalized' => 'Top'
                     }
                   },
-                  'line_nr' => {
+                  'parent' => {},
+                  'source_info' => {
                     'file_name' => '',
                     'line_nr' => 2,
                     'macro' => ''
-                  },
-                  'parent' => {}
+                  }
                 }
               ],
               'parent' => {},
@@ -76,7 +74,6 @@ $result_trees{'ref_in_anchor'} = {
             }
           ],
           'cmdname' => 'anchor',
-          'contents' => [],
           'extra' => {
             'node_content' => [
               {},
@@ -84,13 +81,17 @@ $result_trees{'ref_in_anchor'} = {
             ],
             'normalized' => 'TOP-Top'
           },
-          'line_nr' => {},
-          'parent' => {}
+          'parent' => {},
+          'source_info' => {
+            'file_name' => '',
+            'line_nr' => 2,
+            'macro' => ''
+          }
         },
         {
           'parent' => {},
           'text' => '',
-          'type' => 'empty_spaces_after_close_brace'
+          'type' => 'spaces_after_close_brace'
         }
       ],
       'extra' => {
@@ -99,19 +100,21 @@ $result_trees{'ref_in_anchor'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -128,11 +131,10 @@ $result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[0]{'args'}[0]{'content
 $result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[0];
 $result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[0]{'extra'}{'node_content'}[0] = $result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[0]{'extra'}{'node_content'}[1] = $result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[0]{'line_nr'} = $result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'ref_in_anchor'}{'contents'}[1];
 $result_trees{'ref_in_anchor'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'ref_in_anchor'}{'contents'}[1];
 $result_trees{'ref_in_anchor'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'ref_in_anchor'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'ref_in_anchor'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'ref_in_anchor'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'ref_in_anchor'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'ref_in_anchor'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'ref_in_anchor'}{'contents'}[1]{'parent'} = $result_trees{'ref_in_anchor'};
 
 $result_texis{'ref_in_anchor'} = '@node Top
@@ -141,27 +143,23 @@ $result_texis{'ref_in_anchor'} = '@node Top
 
 $result_texts{'ref_in_anchor'} = '';
 
-$result_sectioning{'ref_in_anchor'} = {};
-
 $result_nodes{'ref_in_anchor'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'ref_in_anchor'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'ref_in_anchor'} = [
   {
-    'error_line' => ':2: warning: @ref should not appear in @anchor
+    'error_line' => 'warning: @ref should not appear in @anchor
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -172,4 +170,7 @@ $result_errors{'ref_in_anchor'} = [
 ];
 
 
+$result_floats{'ref_in_anchor'} = {};
+
+
 1;
