@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'ref_in_ref'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -51,7 +50,6 @@ $result_trees{'ref_in_ref'} = {
                         }
                       ],
                       'cmdname' => 'ref',
-                      'contents' => [],
                       'extra' => {
                         'label' => {},
                         'node_argument' => {
@@ -61,12 +59,12 @@ $result_trees{'ref_in_ref'} = {
                           'normalized' => 'Top'
                         }
                       },
-                      'line_nr' => {
+                      'parent' => {},
+                      'source_info' => {
                         'file_name' => '',
                         'line_nr' => 2,
                         'macro' => ''
-                      },
-                      'parent' => {}
+                      }
                     }
                   ],
                   'parent' => {},
@@ -74,7 +72,6 @@ $result_trees{'ref_in_ref'} = {
                 }
               ],
               'cmdname' => 'ref',
-              'contents' => [],
               'extra' => {
                 'label' => {},
                 'node_argument' => {
@@ -84,8 +81,12 @@ $result_trees{'ref_in_ref'} = {
                   'normalized' => 'Top'
                 }
               },
-              'line_nr' => {},
-              'parent' => {}
+              'parent' => {},
+              'source_info' => {
+                'file_name' => '',
+                'line_nr' => 2,
+                'macro' => ''
+              }
             }
           ],
           'parent' => {},
@@ -98,19 +99,21 @@ $result_trees{'ref_in_ref'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -126,11 +129,10 @@ $result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}
 $result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0]{'contents'}[0];
 $result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'extra'}{'label'} = $result_trees{'ref_in_ref'}{'contents'}[1];
 $result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'extra'}{'node_argument'}{'node_content'}[0] = $result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0];
 $result_trees{'ref_in_ref'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'ref_in_ref'}{'contents'}[1];
 $result_trees{'ref_in_ref'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'ref_in_ref'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'ref_in_ref'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'ref_in_ref'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'ref_in_ref'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'ref_in_ref'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'ref_in_ref'}{'contents'}[1]{'parent'} = $result_trees{'ref_in_ref'};
 
 $result_texis{'ref_in_ref'} = '@node Top
@@ -139,27 +141,23 @@ $result_texis{'ref_in_ref'} = '@node Top
 
 $result_texts{'ref_in_ref'} = 'Top';
 
-$result_sectioning{'ref_in_ref'} = {};
-
 $result_nodes{'ref_in_ref'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'ref_in_ref'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'ref_in_ref'} = [
   {
-    'error_line' => ':2: warning: @ref should not appear in @ref
+    'error_line' => 'warning: @ref should not appear in @ref
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -168,7 +166,7 @@ $result_errors{'ref_in_ref'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => ':2: warning: @ref to `@ref{Top}\', different from node name `Top\'
+    'error_line' => 'warning: @ref to `@ref{Top}\', different from node name `Top\'
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -179,4 +177,7 @@ $result_errors{'ref_in_ref'} = [
 ];
 
 
+$result_floats{'ref_in_ref'} = {};
+
+
 1;
