@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -28,12 +28,6 @@ $result_trees{'section_in_footnote'} = {
                     {
                       'parent' => {},
                       'text' => '
-',
-                      'type' => 'empty_spaces_before_argument'
-                    },
-                    {
-                      'parent' => {},
-                      'text' => '
 ',
                       'type' => 'empty_line'
                     }
@@ -43,16 +37,16 @@ $result_trees{'section_in_footnote'} = {
                 }
               ],
               'cmdname' => 'footnote',
-              'contents' => [],
               'extra' => {
-                'spaces_before_argument' => {}
+                'spaces_before_argument' => '
+'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 2,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
           'parent' => {},
@@ -60,51 +54,35 @@ $result_trees{'section_in_footnote'} = {
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'a section'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'section',
-      'contents' => [],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
-      'level' => 2,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -112,19 +90,12 @@ $result_trees{'section_in_footnote'} = {
 $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[0];
 $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1];
 $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'contents'}[1];
-$result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'extra'}{'spaces_before_argument'} = $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1];
 $result_trees{'section_in_footnote'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[0];
 $result_trees{'section_in_footnote'}{'contents'}[0]{'parent'} = $result_trees{'section_in_footnote'};
-$result_trees{'section_in_footnote'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'section_in_footnote'}{'contents'}[1];
 $result_trees{'section_in_footnote'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[1]{'args'}[0];
-$result_trees{'section_in_footnote'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[1]{'args'}[0];
-$result_trees{'section_in_footnote'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[1]{'args'}[0];
 $result_trees{'section_in_footnote'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'section_in_footnote'}{'contents'}[1];
-$result_trees{'section_in_footnote'}{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'section_in_footnote'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'section_in_footnote'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'section_in_footnote'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'section_in_footnote'}{'contents'}[1]{'parent'} = $result_trees{'section_in_footnote'};
 
 $result_texis{'section_in_footnote'} = '
@@ -140,30 +111,37 @@ Text1 a section
 ';
 
 $result_sectioning{'section_in_footnote'} = {
-  'level' => 1,
-  'section_childs' => [
-    {
-      'cmdname' => 'section',
-      'extra' => {},
-      'level' => 2,
-      'number' => 1,
-      'section_up' => {}
-    }
-  ]
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'section',
+        'extra' => {},
+        'structure' => {
+          'section_level' => 2,
+          'section_number' => 1,
+          'section_up' => {}
+        }
+      }
+    ],
+    'section_level' => 1
+  }
 };
-$result_sectioning{'section_in_footnote'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'section_in_footnote'};
+$result_sectioning{'section_in_footnote'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'section_in_footnote'};
 
 $result_errors{'section_in_footnote'} = [
   {
-    'error_line' => ':2: @footnote missing close brace
+    'error_line' => '@section seen before @footnote closing brace
 ',
     'file_name' => '',
     'line_nr' => 2,
     'macro' => '',
-    'text' => '@footnote missing close brace',
+    'text' => '@section seen before @footnote closing brace',
     'type' => 'error'
   }
 ];
 
 
+$result_floats{'section_in_footnote'} = {};
+
+
 1;
