@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -10,12 +10,18 @@ $result_trees{'text_before_and_after_bye'} = {
     {
       'contents' => [
         {
+          'contents' => [
+            {
+              'parent' => {},
+              'text' => 'Before bye '
+            }
+          ],
           'parent' => {},
-          'text' => 'Before bye '
+          'type' => 'paragraph'
         }
       ],
       'parent' => {},
-      'type' => 'paragraph'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -30,8 +36,9 @@ $result_trees{'text_before_and_after_bye'} = {
       'parent' => {}
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
+$result_trees{'text_before_and_after_bye'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'text_before_and_after_bye'}{'contents'}[0]{'contents'}[0];
 $result_trees{'text_before_and_after_bye'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'text_before_and_after_bye'}{'contents'}[0];
 $result_trees{'text_before_and_after_bye'}{'contents'}[0]{'parent'} = $result_trees{'text_before_and_after_bye'};
 $result_trees{'text_before_and_after_bye'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'text_before_and_after_bye'}{'contents'}[1];
@@ -45,15 +52,18 @@ $result_texts{'text_before_and_after_bye'} = 'Before bye ';
 
 $result_errors{'text_before_and_after_bye'} = [
   {
-    'error_line' => ':1: warning: @bye should only appear at a line beginning
+    'error_line' => 'warning: @bye should only appear at the beginning of a line
 ',
     'file_name' => '',
     'line_nr' => 1,
     'macro' => '',
-    'text' => '@bye should only appear at a line beginning',
+    'text' => '@bye should only appear at the beginning of a line',
     'type' => 'warning'
   }
 ];
 
 
+$result_floats{'text_before_and_after_bye'} = {};
+
+
 1;
