@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,66 +17,72 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
                   'parent' => {},
                   'text' => '\\input texinfo @c -*-texinfo-*-
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 },
                 {
                   'parent' => {},
                   'text' => '
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble'
+              'type' => 'preamble_before_beginning'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'nodes_after_top_before_section.info'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'nodes_after_top_before_section.info'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'nodes_after_top_before_section.info'
               },
               'parent' => {},
-              'type' => 'line_arg'
+              'source_info' => {
+                'file_name' => 'nodes_after_top_before_section.texi',
+                'line_nr' => 3,
+                'macro' => ''
+              }
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line'
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line'
             }
           ],
-          'cmdname' => 'setfilename',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'nodes_after_top_before_section.info'
-          },
-          'line_nr' => {
-            'file_name' => 'nodes_after_top_before_section.texi',
-            'line_nr' => 3,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
           'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
-        },
-        {
-          'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
+          'type' => 'preamble_before_content'
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -109,17 +115,18 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
           'type' => 'paragraph'
         },
         {
-          'cmdname' => 'menu',
-          'contents' => [
+          'args' => [
             {
               'extra' => {
-                'command' => {}
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
+              'type' => 'block_line_arg'
+            }
+          ],
+          'cmdname' => 'menu',
+          'contents' => [
             {
               'args' => [
                 {
@@ -169,12 +176,12 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
                   'normalized' => 'second-node'
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'nodes_after_top_before_section.texi',
                 'line_nr' => 9,
                 'macro' => ''
               },
-              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -226,12 +233,12 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
                   'normalized' => 'third-node'
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'nodes_after_top_before_section.texi',
                 'line_nr' => 10,
                 'macro' => ''
               },
-              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -253,27 +260,23 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'menu',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'nodes_after_top_before_section.texi',
                 'line_nr' => 11,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => 'nodes_after_top_before_section.texi',
             'line_nr' => 8,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -288,19 +291,21 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'nodes_after_top_before_section.texi',
         'line_nr' => 6,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -384,7 +389,9 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'second-node'
           },
           {
@@ -409,12 +416,12 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
         'normalized' => 'second-node',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'nodes_after_top_before_section.texi',
         'line_nr' => 13,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -429,7 +436,6 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
           'type' => 'line_arg'
         },
         {
-          'contents' => [],
           'parent' => {},
           'type' => 'line_arg'
         },
@@ -459,14 +465,15 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'third-node'
           },
           undef,
@@ -486,12 +493,12 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
         'normalized' => 'third-node',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'nodes_after_top_before_section.texi',
         'line_nr' => 17,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -528,14 +535,12 @@ $result_trees{'nodes_after_top_before_section_use_nodes'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 3,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'nodes_after_top_before_section.texi',
         'line_nr' => 18,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -556,17 +561,27 @@ $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'conten
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'};
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'args'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3]{'contents'}[0];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[1];
@@ -578,24 +593,13 @@ $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'conten
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[3];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1];
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_description'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[3];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'contents'}[3];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'};
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'args'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2];
@@ -610,7 +614,7 @@ $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'conten
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'args'}[0]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'extra'}{'node_content'};
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'extra'}{'nodes_manuals'}[1]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'args'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'args'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[2]{'args'}[3]{'contents'}[0];
@@ -623,7 +627,7 @@ $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'args'}
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'args'}[3];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'args'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'args'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'args'}[3]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_use_nodes'}{'contents'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section_use_nodes'};
@@ -675,124 +679,126 @@ second node
 ';
 
 $result_sectioning{'nodes_after_top_before_section_use_nodes'} = {
-  'level' => 2,
-  'section_childs' => [
-    {
-      'cmdname' => 'subsection',
-      'extra' => {
-        'associated_node' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'third-node',
-            'spaces_before_argument' => ' '
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'subsection',
+        'extra' => {
+          'associated_node' => {
+            'cmdname' => 'node',
+            'extra' => {
+              'normalized' => 'third-node'
+            },
+            'structure' => {}
           }
         },
-        'spaces_before_argument' => ' '
-      },
-      'level' => 3,
-      'number' => 1,
-      'section_up' => {}
-    }
-  ]
+        'structure' => {
+          'section_level' => 3,
+          'section_number' => 1,
+          'section_up' => {}
+        }
+      }
+    ],
+    'section_level' => 2
+  }
 };
-$result_sectioning{'nodes_after_top_before_section_use_nodes'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'nodes_after_top_before_section_use_nodes'};
+$result_sectioning{'nodes_after_top_before_section_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'nodes_after_top_before_section_use_nodes'};
 
 $result_nodes{'nodes_after_top_before_section_use_nodes'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'menus' => [
+      {
+        'cmdname' => 'menu'
+      }
+    ],
+    'normalized' => 'Top'
   },
-  'menu_child' => {
-    'cmdname' => 'node',
-    'extra' => {
-      'normalized' => 'second-node',
-      'spaces_before_argument' => ' '
-    },
-    'node_next' => {
+  'structure' => {
+    'menu_child' => {
       'cmdname' => 'node',
       'extra' => {
-        'associated_section' => {
-          'cmdname' => 'subsection',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 3,
-          'number' => 1
-        },
-        'normalized' => 'third-node',
-        'spaces_before_argument' => ' '
+        'normalized' => 'second-node'
       },
-      'node_prev' => {},
-      'node_up' => {}
-    },
-    'node_prev' => {},
-    'node_up' => {}
-  },
-  'menus' => [
-    {
-      'cmdname' => 'menu',
-      'extra' => {
-        'end_command' => {
-          'cmdname' => 'end',
+      'structure' => {
+        'node_next' => {
+          'cmdname' => 'node',
           'extra' => {
-            'command_argument' => 'menu',
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'menu'
+            'associated_section' => {
+              'cmdname' => 'subsection',
+              'extra' => {},
+              'structure' => {
+                'section_number' => 1
+              }
+            },
+            'normalized' => 'third-node'
+          },
+          'structure' => {
+            'node_prev' => {},
+            'node_up' => {}
           }
-        }
+        },
+        'node_prev' => {},
+        'node_up' => {}
       }
-    }
-  ],
-  'node_next' => {}
+    },
+    'node_next' => {}
+  }
 };
-$result_nodes{'nodes_after_top_before_section_use_nodes'}{'menu_child'}{'node_next'}{'node_prev'} = $result_nodes{'nodes_after_top_before_section_use_nodes'}{'menu_child'};
-$result_nodes{'nodes_after_top_before_section_use_nodes'}{'menu_child'}{'node_next'}{'node_up'} = $result_nodes{'nodes_after_top_before_section_use_nodes'};
-$result_nodes{'nodes_after_top_before_section_use_nodes'}{'menu_child'}{'node_prev'} = $result_nodes{'nodes_after_top_before_section_use_nodes'};
-$result_nodes{'nodes_after_top_before_section_use_nodes'}{'menu_child'}{'node_up'} = $result_nodes{'nodes_after_top_before_section_use_nodes'};
-$result_nodes{'nodes_after_top_before_section_use_nodes'}{'node_next'} = $result_nodes{'nodes_after_top_before_section_use_nodes'}{'menu_child'};
+$result_nodes{'nodes_after_top_before_section_use_nodes'}{'structure'}{'menu_child'}{'structure'}{'node_next'}{'structure'}{'node_prev'} = $result_nodes{'nodes_after_top_before_section_use_nodes'}{'structure'}{'menu_child'};
+$result_nodes{'nodes_after_top_before_section_use_nodes'}{'structure'}{'menu_child'}{'structure'}{'node_next'}{'structure'}{'node_up'} = $result_nodes{'nodes_after_top_before_section_use_nodes'};
+$result_nodes{'nodes_after_top_before_section_use_nodes'}{'structure'}{'menu_child'}{'structure'}{'node_prev'} = $result_nodes{'nodes_after_top_before_section_use_nodes'};
+$result_nodes{'nodes_after_top_before_section_use_nodes'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'nodes_after_top_before_section_use_nodes'};
+$result_nodes{'nodes_after_top_before_section_use_nodes'}{'structure'}{'node_next'} = $result_nodes{'nodes_after_top_before_section_use_nodes'}{'structure'}{'menu_child'};
 
 $result_menus{'nodes_after_top_before_section_use_nodes'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   },
-  'menu_child' => {
-    'cmdname' => 'node',
-    'extra' => {
-      'normalized' => 'second-node',
-      'spaces_before_argument' => ' '
-    },
-    'menu_next' => {
+  'structure' => {
+    'menu_child' => {
       'cmdname' => 'node',
       'extra' => {
-        'normalized' => 'third-node',
-        'spaces_before_argument' => ' '
+        'normalized' => 'second-node'
       },
-      'menu_prev' => {},
-      'menu_up' => {},
-      'menu_up_hash' => {
-        'Top' => 1
+      'structure' => {
+        'menu_next' => {
+          'cmdname' => 'node',
+          'extra' => {
+            'normalized' => 'third-node'
+          },
+          'structure' => {
+            'menu_prev' => {},
+            'menu_up' => {},
+            'menu_up_hash' => {
+              'Top' => 1
+            }
+          }
+        },
+        'menu_up' => {},
+        'menu_up_hash' => {
+          'Top' => 1
+        }
       }
-    },
-    'menu_up' => {},
-    'menu_up_hash' => {
-      'Top' => 1
     }
   }
 };
-$result_menus{'nodes_after_top_before_section_use_nodes'}{'menu_child'}{'menu_next'}{'menu_prev'} = $result_menus{'nodes_after_top_before_section_use_nodes'}{'menu_child'};
-$result_menus{'nodes_after_top_before_section_use_nodes'}{'menu_child'}{'menu_next'}{'menu_up'} = $result_menus{'nodes_after_top_before_section_use_nodes'};
-$result_menus{'nodes_after_top_before_section_use_nodes'}{'menu_child'}{'menu_up'} = $result_menus{'nodes_after_top_before_section_use_nodes'};
+$result_menus{'nodes_after_top_before_section_use_nodes'}{'structure'}{'menu_child'}{'structure'}{'menu_next'}{'structure'}{'menu_prev'} = $result_menus{'nodes_after_top_before_section_use_nodes'}{'structure'}{'menu_child'};
+$result_menus{'nodes_after_top_before_section_use_nodes'}{'structure'}{'menu_child'}{'structure'}{'menu_next'}{'structure'}{'menu_up'} = $result_menus{'nodes_after_top_before_section_use_nodes'};
+$result_menus{'nodes_after_top_before_section_use_nodes'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'nodes_after_top_before_section_use_nodes'};
 
 $result_errors{'nodes_after_top_before_section_use_nodes'} = [];
 
 
+$result_floats{'nodes_after_top_before_section_use_nodes'} = {};
+
+
 $result_converted_errors{'file_html'}->{'nodes_after_top_before_section_use_nodes'} = [
   {
-    'error_line' => 'nodes_after_top_before_section.texi: warning: must specify a title with a title command or @top
+    'error_line' => 'warning: must specify a title with a title command or @top
 ',
+    'file_name' => 'nodes_after_top_before_section.texi',
     'text' => 'must specify a title with a title command or @top',
     'type' => 'warning'
   }
