@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,96 +17,102 @@ $result_trees{'top_node_up_explicit'} = {
                   'parent' => {},
                   'text' => '\\input texinfo  @c public domain
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble'
+              'type' => 'preamble_before_beginning'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'top_node_up_explicit'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'top_node_up_explicit'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'top_node_up_explicit'
               },
               'parent' => {},
-              'type' => 'line_arg'
-            }
-          ],
-          'cmdname' => 'setfilename',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'top_node_up_explicit'
-          },
-          'line_nr' => {
-            'file_name' => 'top_node_up_explicit.texi',
-            'line_nr' => 2,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
-          'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
-        },
-        {
-          'args' => [
+              'source_info' => {
+                'file_name' => 'top_node_up_explicit.texi',
+                'line_nr' => 2,
+                'macro' => ''
+              }
+            },
             {
               'parent' => {},
-              'text' => ' should replace all explicit (dir) pointers, but not
+              'text' => '
 ',
-              'type' => 'misc_arg'
-            }
-          ],
-          'cmdname' => 'c',
-          'extra' => {
-            'misc_args' => [
-              ' should replace all explicit (dir) pointers, but not
+              'type' => 'empty_line'
+            },
+            {
+              'args' => [
+                {
+                  'parent' => {},
+                  'text' => ' should replace all explicit (dir) pointers, but not
+',
+                  'type' => 'misc_arg'
+                }
+              ],
+              'cmdname' => 'c',
+              'extra' => {
+                'misc_args' => [
+                  ' should replace all explicit (dir) pointers, but not
 '
-            ]
-          },
-          'parent' => {}
-        },
-        {
-          'args' => [
+                ]
+              },
+              'parent' => {}
+            },
+            {
+              'args' => [
+                {
+                  'parent' => {},
+                  'text' => ' pointers to other files.
+',
+                  'type' => 'misc_arg'
+                }
+              ],
+              'cmdname' => 'c',
+              'extra' => {
+                'misc_args' => [
+                  ' pointers to other files.
+'
+                ]
+              },
+              'parent' => {}
+            },
             {
               'parent' => {},
-              'text' => ' pointers to other files.
+              'text' => '
 ',
-              'type' => 'misc_arg'
+              'type' => 'empty_line'
             }
           ],
-          'cmdname' => 'c',
-          'extra' => {
-            'misc_args' => [
-              ' pointers to other files.
-'
-            ]
-          },
-          'parent' => {}
-        },
-        {
           'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
+          'type' => 'preamble_before_content'
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -187,14 +193,15 @@ $result_trees{'top_node_up_explicit'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           },
           {
@@ -210,19 +217,18 @@ $result_trees{'top_node_up_explicit'} = {
           {
             'manual_content' => [
               {}
-            ],
-            'top_node_up' => {}
+            ]
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'top_node_up_explicit.texi',
         'line_nr' => 7,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -267,17 +273,18 @@ $result_trees{'top_node_up_explicit'} = {
           'type' => 'empty_line'
         },
         {
-          'cmdname' => 'menu',
-          'contents' => [
+          'args' => [
             {
               'extra' => {
-                'command' => {}
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            },
+              'type' => 'block_line_arg'
+            }
+          ],
+          'cmdname' => 'menu',
+          'contents' => [
             {
               'args' => [
                 {
@@ -327,12 +334,12 @@ $result_trees{'top_node_up_explicit'} = {
                   'normalized' => 'Chap'
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'top_node_up_explicit.texi',
                 'line_nr' => 13,
                 'macro' => ''
               },
-              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -354,27 +361,23 @@ $result_trees{'top_node_up_explicit'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'menu',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'top_node_up_explicit.texi',
                 'line_nr' => 14,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
-          'extra' => {
-            'end_command' => {}
-          },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => 'top_node_up_explicit.texi',
             'line_nr' => 12,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -386,13 +389,12 @@ $result_trees{'top_node_up_explicit'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'top_node_up_explicit.texi',
         'line_nr' => 8,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -412,26 +414,27 @@ $result_trees{'top_node_up_explicit'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Chap'
           }
         ],
         'normalized' => 'Chap',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'top_node_up_explicit.texi',
         'line_nr' => 16,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -479,14 +482,12 @@ $result_trees{'top_node_up_explicit'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'top_node_up_explicit.texi',
         'line_nr' => 17,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -506,15 +507,16 @@ $result_trees{'top_node_up_explicit'} = {
 $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1];
+$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
+$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1];
+$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1];
+$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[2];
+$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1];
+$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[3];
+$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1];
+$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1];
 $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[3];
-$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[4];
-$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[0]{'contents'}[5]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'};
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[1];
@@ -531,11 +533,10 @@ $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[3]{'contents'}[1]{'
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[3]{'contents'}[2]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[3];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[1];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[1]{'manual_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[1]{'contents'}[1];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[2]{'manual_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[2]{'contents'}[1];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[3]{'manual_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[3]{'contents'}[1];
-$result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[3]{'top_node_up'} = $result_trees{'top_node_up_explicit'}{'contents'}[1];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'parent'} = $result_trees{'top_node_up_explicit'};
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'args'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2];
@@ -543,29 +544,27 @@ $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[0]{'parent'} =
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[1];
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2];
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'command'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'contents'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3];
+$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[2];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3];
-$result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'contents'}[2];
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[3]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2];
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'contents'}[4]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[2];
 $result_trees{'top_node_up_explicit'}{'contents'}[2]{'parent'} = $result_trees{'top_node_up_explicit'};
 $result_trees{'top_node_up_explicit'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[3]{'args'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[3];
 $result_trees{'top_node_up_explicit'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'top_node_up_explicit'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'top_node_up_explicit'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[3]{'parent'} = $result_trees{'top_node_up_explicit'};
 $result_trees{'top_node_up_explicit'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[4]{'args'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[4];
@@ -618,147 +617,143 @@ Without the chapter, no up node from top is generated.
 ';
 
 $result_sectioning{'top_node_up_explicit'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {
-        'associated_node' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'Top',
-            'spaces_before_argument' => ' '
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {
+          'associated_node' => {
+            'cmdname' => 'node',
+            'extra' => {
+              'normalized' => 'Top'
+            },
+            'structure' => {}
           }
         },
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_childs' => [
-        {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'associated_node' => {
-              'cmdname' => 'node',
+        'structure' => {
+          'section_childs' => [
+            {
+              'cmdname' => 'chapter',
               'extra' => {
-                'normalized' => 'Chap',
-                'spaces_before_argument' => ' '
+                'associated_node' => {
+                  'cmdname' => 'node',
+                  'extra' => {
+                    'normalized' => 'Chap'
+                  },
+                  'structure' => {}
+                }
+              },
+              'structure' => {
+                'section_level' => 1,
+                'section_number' => 1,
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
               }
-            },
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 1,
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
+            }
+          ],
+          'section_level' => 0,
+          'section_up' => {}
         }
-      ],
-      'section_up' => {}
-    }
-  ]
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'top_node_up_explicit'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'top_node_up_explicit'}{'section_childs'}[0];
-$result_sectioning{'top_node_up_explicit'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'top_node_up_explicit'}{'section_childs'}[0];
-$result_sectioning{'top_node_up_explicit'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'top_node_up_explicit'}{'section_childs'}[0];
-$result_sectioning{'top_node_up_explicit'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'top_node_up_explicit'};
+$result_sectioning{'top_node_up_explicit'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'top_node_up_explicit'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'top_node_up_explicit'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'top_node_up_explicit'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'top_node_up_explicit'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'top_node_up_explicit'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'top_node_up_explicit'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'top_node_up_explicit'};
 
 $result_nodes{'top_node_up_explicit'} = {
   'cmdname' => 'node',
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0
+      'extra' => {},
+      'structure' => {}
     },
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
-  },
-  'menu_child' => {
-    'cmdname' => 'node',
-    'extra' => {
-      'associated_section' => {
-        'cmdname' => 'chapter',
-        'extra' => {
-          'spaces_before_argument' => ' '
-        },
-        'level' => 1,
-        'number' => 1
-      },
-      'normalized' => 'Chap',
-      'spaces_before_argument' => ' '
-    },
-    'node_up' => {}
-  },
-  'menus' => [
-    {
-      'cmdname' => 'menu',
-      'extra' => {
-        'end_command' => {
-          'cmdname' => 'end',
-          'extra' => {
-            'command_argument' => 'menu',
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'menu'
-          }
-        }
+    'menus' => [
+      {
+        'cmdname' => 'menu'
       }
-    }
-  ],
-  'node_next' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ]
-    }
+    ],
+    'normalized' => 'Top'
   },
-  'node_prev' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'weird'
-        }
-      ]
-    }
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
+  'structure' => {
+    'menu_child' => {
+      'cmdname' => 'node',
+      'extra' => {
+        'associated_section' => {
+          'cmdname' => 'chapter',
+          'extra' => {},
+          'structure' => {
+            'section_number' => 1
+          }
+        },
+        'normalized' => 'Chap'
+      },
+      'structure' => {
+        'node_up' => {}
+      }
+    },
+    'node_next' => {
+      'extra' => {
+        'manual_content' => [
+          {
+            'text' => 'dir'
+          }
+        ]
+      }
+    },
+    'node_prev' => {
+      'extra' => {
+        'manual_content' => [
+          {
+            'text' => 'weird'
+          }
+        ]
+      }
+    },
+    'node_up' => {
+      'extra' => {
+        'manual_content' => [
+          {
+            'text' => 'dir'
+          }
+        ]
+      }
     }
   }
 };
-$result_nodes{'top_node_up_explicit'}{'menu_child'}{'node_up'} = $result_nodes{'top_node_up_explicit'};
-$result_nodes{'top_node_up_explicit'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'top_node_up_explicit'};
+$result_nodes{'top_node_up_explicit'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'top_node_up_explicit'};
 
 $result_menus{'top_node_up_explicit'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   },
-  'menu_child' => {
-    'cmdname' => 'node',
-    'extra' => {
-      'normalized' => 'Chap',
-      'spaces_before_argument' => ' '
-    },
-    'menu_up' => {},
-    'menu_up_hash' => {
-      'Top' => 1
+  'structure' => {
+    'menu_child' => {
+      'cmdname' => 'node',
+      'extra' => {
+        'normalized' => 'Chap'
+      },
+      'structure' => {
+        'menu_up' => {},
+        'menu_up_hash' => {
+          'Top' => 1
+        }
+      }
     }
   }
 };
-$result_menus{'top_node_up_explicit'}{'menu_child'}{'menu_up'} = $result_menus{'top_node_up_explicit'};
+$result_menus{'top_node_up_explicit'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'top_node_up_explicit'};
 
 $result_errors{'top_node_up_explicit'} = [];
 
 
+$result_floats{'top_node_up_explicit'} = {};
+
+
 1;
