@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,11 +17,11 @@ $result_trees{'chinese_mixed_with_en'} = {
                   'parent' => {},
                   'text' => '\\input texinfo
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble'
+              'type' => 'preamble_before_beginning'
             },
             {
               'args' => [
@@ -47,83 +47,89 @@ $result_trees{'chinese_mixed_with_en'} = {
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'utf-8'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => 'chinese_mixed_with_en.texi',
                 'line_nr' => 2,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'chinese_mixed_with_en.info'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'chinese_mixed_with_en.info'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'chinese_mixed_with_en.info'
               },
               'parent' => {},
-              'type' => 'line_arg'
-            }
-          ],
-          'cmdname' => 'setfilename',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'chinese_mixed_with_en.info'
-          },
-          'line_nr' => {
-            'file_name' => 'chinese_mixed_with_en.texi',
-            'line_nr' => 3,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
-          'args' => [
+              'source_info' => {
+                'file_name' => 'chinese_mixed_with_en.texi',
+                'line_nr' => 3,
+                'macro' => ''
+              }
+            },
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'chinese mixed with english'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'chinese mixed with english'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'settitle',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' '
               },
               'parent' => {},
-              'type' => 'line_arg'
-            }
-          ],
-          'cmdname' => 'settitle',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'line_nr' => {
-            'file_name' => 'chinese_mixed_with_en.texi',
-            'line_nr' => 4,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
-          'parent' => {},
-          'text' => '
+              'source_info' => {
+                'file_name' => 'chinese_mixed_with_en.texi',
+                'line_nr' => 4,
+                'macro' => ''
+              }
+            },
+            {
+              'parent' => {},
+              'text' => '
 ',
-          'type' => 'empty_line'
+              'type' => 'empty_line'
+            }
+          ],
+          'parent' => {},
+          'type' => 'preamble_before_content'
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -353,12 +359,12 @@ $result_trees{'chinese_mixed_with_en'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'chinese_mixed_with_en.texi',
         'line_nr' => 6,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -381,13 +387,14 @@ $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[0]{'contents'}
 $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[0]{'contents'}[1];
 $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[0];
 $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0];
-$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1];
+$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
+$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1];
+$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0];
+$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[1];
+$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1];
+$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1];
 $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0];
-$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[2];
-$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0];
-$result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[0];
 $result_trees{'chinese_mixed_with_en'}{'contents'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'};
 $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'args'}[0];
 $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[1];
@@ -499,21 +506,17 @@ overlap。
 
 ';
 
-$result_sectioning{'chinese_mixed_with_en'} = {};
-
 $result_nodes{'chinese_mixed_with_en'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'chinese_mixed_with_en'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
