@@ -1,16 +1,22 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'contents'} = {
   'contents' => [
     {
-      'contents' => [],
+      'contents' => [
+        {
+          'contents' => [],
+          'parent' => {},
+          'type' => 'preamble_before_content'
+        }
+      ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -41,13 +47,12 @@ $result_trees{'contents'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -78,14 +83,12 @@ $result_trees{'contents'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -116,14 +119,12 @@ $result_trees{'contents'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 2,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      },
-      'number' => '1.1',
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -154,14 +155,12 @@ $result_trees{'contents'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 3,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 7,
         'macro' => ''
-      },
-      'number' => '1.1.1',
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -192,14 +191,12 @@ $result_trees{'contents'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 4,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 9,
         'macro' => ''
-      },
-      'number' => '1.1.1.1',
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -230,13 +227,12 @@ $result_trees{'contents'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 11,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -268,14 +264,12 @@ $result_trees{'contents'} = {
         'associated_part' => {},
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 13,
         'macro' => ''
-      },
-      'number' => 2,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -306,14 +300,12 @@ $result_trees{'contents'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 15,
         'macro' => ''
-      },
-      'number' => 3,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -344,13 +336,12 @@ $result_trees{'contents'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 17,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -381,14 +372,12 @@ $result_trees{'contents'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 19,
         'macro' => ''
-      },
-      'number' => 'A',
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -425,29 +414,28 @@ $result_trees{'contents'} = {
             }
           ],
           'cmdname' => 'contents',
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 23,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         }
       ],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 2,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 21,
         'macro' => ''
-      },
-      'number' => 'A.1',
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
 };
+$result_trees{'contents'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[0];
 $result_trees{'contents'}{'contents'}[0]{'parent'} = $result_trees{'contents'};
 $result_trees{'contents'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[1]{'args'}[0];
 $result_trees{'contents'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'contents'}{'contents'}[1];
@@ -559,165 +547,172 @@ A.1 appendixsec
 ';
 
 $result_sectioning{'contents'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_childs' => [
-        {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 1,
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {},
+        'structure' => {
           'section_childs' => [
             {
-              'cmdname' => 'section',
-              'extra' => {
-                'spaces_before_argument' => ' '
-              },
-              'level' => 2,
-              'number' => '1.1',
-              'section_childs' => [
-                {
-                  'cmdname' => 'subsection',
-                  'extra' => {
-                    'spaces_before_argument' => ' '
-                  },
-                  'level' => 3,
-                  'number' => '1.1.1',
-                  'section_childs' => [
-                    {
-                      'cmdname' => 'subsubsection',
-                      'extra' => {
-                        'spaces_before_argument' => ' '
-                      },
-                      'level' => 4,
-                      'number' => '1.1.1.1',
+              'cmdname' => 'chapter',
+              'extra' => {},
+              'structure' => {
+                'section_childs' => [
+                  {
+                    'cmdname' => 'section',
+                    'extra' => {},
+                    'structure' => {
+                      'section_childs' => [
+                        {
+                          'cmdname' => 'subsection',
+                          'extra' => {},
+                          'structure' => {
+                            'section_childs' => [
+                              {
+                                'cmdname' => 'subsubsection',
+                                'extra' => {},
+                                'structure' => {
+                                  'section_level' => 4,
+                                  'section_number' => '1.1.1.1',
+                                  'section_up' => {}
+                                }
+                              }
+                            ],
+                            'section_level' => 3,
+                            'section_number' => '1.1.1',
+                            'section_up' => {}
+                          }
+                        }
+                      ],
+                      'section_level' => 2,
+                      'section_number' => '1.1',
                       'section_up' => {}
                     }
-                  ],
-                  'section_up' => {}
-                }
-              ],
-              'section_up' => {}
+                  }
+                ],
+                'section_level' => 1,
+                'section_number' => 1,
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
+              }
             }
           ],
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
-        }
-      ],
-      'section_up' => {}
-    },
-    {
-      'cmdname' => 'part',
-      'extra' => {
-        'part_associated_section' => {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'associated_part' => {},
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 2,
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
-        },
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_childs' => [
-        {},
-        {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 3,
-          'section_prev' => {},
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
-        },
-        {
-          'cmdname' => 'unnumbered',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'section_prev' => {},
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
-        }
-      ],
-      'section_prev' => {},
-      'section_up' => {}
-    },
-    {
-      'cmdname' => 'appendix',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 1,
-      'number' => 'A',
-      'section_childs' => [
-        {
-          'cmdname' => 'appendixsec',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 2,
-          'number' => 'A.1',
+          'section_level' => 0,
           'section_up' => {}
         }
-      ],
-      'section_prev' => {},
-      'section_up' => {},
-      'toplevel_prev' => {},
-      'toplevel_up' => {}
-    }
-  ]
+      },
+      {
+        'cmdname' => 'part',
+        'extra' => {
+          'part_associated_section' => {
+            'cmdname' => 'chapter',
+            'extra' => {
+              'associated_part' => {}
+            },
+            'structure' => {
+              'section_level' => 1,
+              'section_number' => 2,
+              'section_up' => {},
+              'toplevel_prev' => {},
+              'toplevel_up' => {}
+            }
+          }
+        },
+        'structure' => {
+          'section_childs' => [
+            {},
+            {
+              'cmdname' => 'chapter',
+              'extra' => {},
+              'structure' => {
+                'section_level' => 1,
+                'section_number' => 3,
+                'section_prev' => {},
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
+              }
+            },
+            {
+              'cmdname' => 'unnumbered',
+              'extra' => {},
+              'structure' => {
+                'section_level' => 1,
+                'section_prev' => {},
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
+              }
+            }
+          ],
+          'section_level' => 0,
+          'section_prev' => {},
+          'section_up' => {}
+        }
+      },
+      {
+        'cmdname' => 'appendix',
+        'extra' => {},
+        'structure' => {
+          'section_childs' => [
+            {
+              'cmdname' => 'appendixsec',
+              'extra' => {},
+              'structure' => {
+                'section_level' => 2,
+                'section_number' => 'A.1',
+                'section_up' => {}
+              }
+            }
+          ],
+          'section_level' => 1,
+          'section_number' => 'A',
+          'section_prev' => {},
+          'section_up' => {},
+          'toplevel_prev' => {},
+          'toplevel_up' => {}
+        }
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'contents'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents'}{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents'}{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'contents'}{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'contents'}{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents'};
-$result_sectioning{'contents'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'extra'}{'associated_part'} = $result_sectioning{'contents'}{'section_childs'}[1];
-$result_sectioning{'contents'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'section_up'} = $result_sectioning{'contents'}{'section_childs'}[1];
-$result_sectioning{'contents'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'toplevel_prev'} = $result_sectioning{'contents'}{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'toplevel_up'} = $result_sectioning{'contents'}{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[0] = $result_sectioning{'contents'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[1]{'section_prev'} = $result_sectioning{'contents'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[1]{'section_up'} = $result_sectioning{'contents'}{'section_childs'}[1];
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'contents'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[1]{'toplevel_up'} = $result_sectioning{'contents'}{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[2]{'section_prev'} = $result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[1];
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[2]{'section_up'} = $result_sectioning{'contents'}{'section_childs'}[1];
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[2]{'toplevel_prev'} = $result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[1];
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[2]{'toplevel_up'} = $result_sectioning{'contents'}{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_prev'} = $result_sectioning{'contents'}{'section_childs'}[0];
-$result_sectioning{'contents'}{'section_childs'}[1]{'section_up'} = $result_sectioning{'contents'};
-$result_sectioning{'contents'}{'section_childs'}[2]{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents'}{'section_childs'}[2];
-$result_sectioning{'contents'}{'section_childs'}[2]{'section_prev'} = $result_sectioning{'contents'}{'section_childs'}[1];
-$result_sectioning{'contents'}{'section_childs'}[2]{'section_up'} = $result_sectioning{'contents'};
-$result_sectioning{'contents'}{'section_childs'}[2]{'toplevel_prev'} = $result_sectioning{'contents'}{'section_childs'}[1]{'section_childs'}[2];
-$result_sectioning{'contents'}{'section_childs'}[2]{'toplevel_up'} = $result_sectioning{'contents'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents'};
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'extra'}{'associated_part'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'structure'}{'section_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'structure'}{'toplevel_prev'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'structure'}{'toplevel_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[0] = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_prev'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[2]{'structure'}{'section_prev'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[2]{'structure'}{'section_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[2]{'structure'}{'toplevel_prev'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[2]{'structure'}{'toplevel_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'contents'};
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[2]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[2];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[2]{'structure'}{'section_prev'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[2]{'structure'}{'section_up'} = $result_sectioning{'contents'};
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[2]{'structure'}{'toplevel_prev'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[2];
+$result_sectioning{'contents'}{'structure'}{'section_childs'}[2]{'structure'}{'toplevel_up'} = $result_sectioning{'contents'}{'structure'}{'section_childs'}[0];
 
 $result_errors{'contents'} = [];
 
 
+$result_floats{'contents'} = {};
+
+
 
 $result_converted{'plaintext'}->{'contents'} = 'top
 ***
@@ -763,7 +758,7 @@ Appendix A appendix
 ';
 
 
-$result_converted{'html'}->{'contents'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+$result_converted{'html'}->{'contents'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -774,23 +769,12 @@ $result_converted{'html'}->{'contents'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HT
 <meta name="keywords" content="top">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#SEC_Contents" rel="contents" title="Table of Contents">
 <style type="text/css">
 <!--
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-ul.no-bullet {list-style: none}
+ul.toc-numbered-mark {list-style: none}
 -->
 </style>
 
@@ -798,63 +782,101 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<span id="top"></span><h1 class="top">top</h1>
+<div class="top-level-extent" id="top">
+<h1 class="top">top</h1>
 
-<span id="chapter"></span><h2 class="chapter">1 chapter</h2>
-
-<span id="section"></span><h3 class="section">1.1 section</h3>
-
-<span id="subsection"></span><h4 class="subsection">1.1.1 subsection</h4>
-
-<span id="subsubsection"></span><h4 class="subsubsection">1.1.1.1 subsubsection</h4>
-
-<span id="part"></span><h1 class="part">part</h1>
-<hr>
-
-<span id="chapter-in-part"></span><h2 class="chapter">2 chapter in part</h2>
-
-<span id="second-chapter-in-part"></span><h2 class="chapter">3 second chapter in part</h2>
-
-<span id="unnumbered"></span><h2 class="unnumbered">unnumbered</h2>
-
-<span id="appendix"></span><h2 class="appendix">Appendix A appendix</h2>
-
-<span id="appendixsec"></span><h3 class="appendixsec">A.1 appendixsec</h3>
-
-<span id="SEC_Contents"></span>
+<div class="element-contents" id="SEC_Contents">
 <h2 class="contents-heading">Table of Contents</h2>
 
 <div class="contents">
-<ul class="no-bullet">
+<ul class="toc-numbered-mark">
 <li>
-<ul class="no-bullet">
+<ul class="toc-numbered-mark">
   <li><a id="toc-chapter" href="#chapter">1 chapter</a>
-  <ul class="no-bullet">
+  <ul class="toc-numbered-mark">
     <li><a id="toc-section" href="#section">1.1 section</a>
-    <ul class="no-bullet">
+    <ul class="toc-numbered-mark">
       <li><a id="toc-subsection" href="#subsection">1.1.1 subsection</a>
-      <ul class="no-bullet">
+      <ul class="toc-numbered-mark">
         <li><a id="toc-subsubsection" href="#subsubsection">1.1.1.1 subsubsection</a></li>
       </ul></li>
     </ul></li>
   </ul></li>
 </ul></li>
 <li><a id="toc-part" href="#part">part</a>
-<ul class="no-bullet">
+<ul class="toc-numbered-mark">
   <li><a id="toc-chapter-in-part" href="#chapter-in-part">2 chapter in part</a></li>
   <li><a id="toc-second-chapter-in-part" href="#second-chapter-in-part">3 second chapter in part</a></li>
   <li><a id="toc-unnumbered" href="#unnumbered">unnumbered</a></li>
 </ul></li>
   <li><a id="toc-appendix" href="#appendix">Appendix A appendix</a>
-  <ul class="no-bullet">
+  <ul class="toc-numbered-mark">
     <li><a id="toc-appendixsec" href="#appendixsec">A.1 appendixsec</a></li>
   </ul></li>
 
 </ul>
 </div>
+</div>
+<div class="chapter-level-extent" id="chapter">
+<h2 class="chapter">1 chapter</h2>
 
+<ul class="mini-toc">
+<li><a href="#section" accesskey="1">section</a></li>
+</ul>
+<div class="section-level-extent" id="section">
+<h3 class="section">1.1 section</h3>
+
+<ul class="mini-toc">
+<li><a href="#subsection" accesskey="1">subsection</a></li>
+</ul>
+<div class="subsection-level-extent" id="subsection">
+<h4 class="subsection">1.1.1 subsection</h4>
+
+<ul class="mini-toc">
+<li><a href="#subsubsection" accesskey="1">subsubsection</a></li>
+</ul>
+<div class="subsubsection-level-extent" id="subsubsection">
+<h4 class="subsubsection">1.1.1.1 subsubsection</h4>
+
+</div>
+</div>
+</div>
+</div>
+</div>
+<div class="part-level-extent" id="part">
+<h1 class="part">part</h1>
 <hr>
 
+<ul class="mini-toc">
+<li><a href="#chapter-in-part" accesskey="1">chapter in part</a></li>
+<li><a href="#second-chapter-in-part" accesskey="2">second chapter in part</a></li>
+<li><a href="#unnumbered" accesskey="3">unnumbered</a></li>
+</ul>
+<div class="chapter-level-extent" id="chapter-in-part">
+<h2 class="chapter">2 chapter in part</h2>
+
+</div>
+<div class="chapter-level-extent" id="second-chapter-in-part">
+<h2 class="chapter">3 second chapter in part</h2>
+
+</div>
+<div class="unnumbered-level-extent" id="unnumbered">
+<h2 class="unnumbered">unnumbered</h2>
+
+</div>
+<div class="appendix-level-extent" id="appendix">
+<h2 class="appendix">Appendix A appendix</h2>
+
+<ul class="mini-toc">
+<li><a href="#appendixsec" accesskey="1">appendixsec</a></li>
+</ul>
+<div class="appendixsec-level-extent" id="appendixsec">
+<h3 class="appendixsec">A.1 appendixsec</h3>
+
+</div>
+</div>
+</div>
+
 
 
 </body>
