@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,83 +17,89 @@ $result_trees{'contents_at_document_begin'} = {
                   'parent' => {},
                   'text' => '\\input texinfo @c -*-texinfo-*-
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 },
                 {
                   'parent' => {},
                   'text' => '
 ',
-                  'type' => 'preamble_text'
+                  'type' => 'text_before_beginning'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble'
+              'type' => 'preamble_before_beginning'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'args' => [
+          'contents' => [
             {
-              'contents' => [
+              'args' => [
                 {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'contents_at_document_begin.info'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'text' => 'contents_at_document_begin.info'
+                  'type' => 'line_arg'
                 }
               ],
+              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_after_argument' => '
-'
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'contents_at_document_begin.info'
               },
               'parent' => {},
-              'type' => 'line_arg'
-            }
-          ],
-          'cmdname' => 'setfilename',
-          'extra' => {
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'contents_at_document_begin.info'
-          },
-          'line_nr' => {
-            'file_name' => 'contents_at_document_begin.texi',
-            'line_nr' => 3,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
-          'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
-        },
-        {
-          'args' => [
+              'source_info' => {
+                'file_name' => 'contents_at_document_begin.texi',
+                'line_nr' => 3,
+                'macro' => ''
+              }
+            },
             {
               'parent' => {},
               'text' => '
 ',
-              'type' => 'misc_arg'
+              'type' => 'empty_line'
+            },
+            {
+              'args' => [
+                {
+                  'parent' => {},
+                  'text' => '
+',
+                  'type' => 'misc_arg'
+                }
+              ],
+              'cmdname' => 'contents',
+              'parent' => {},
+              'source_info' => {
+                'file_name' => 'contents_at_document_begin.texi',
+                'line_nr' => 5,
+                'macro' => ''
+              }
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line'
             }
           ],
-          'cmdname' => 'contents',
-          'line_nr' => {
-            'file_name' => 'contents_at_document_begin.texi',
-            'line_nr' => 5,
-            'macro' => ''
-          },
-          'parent' => {}
-        },
-        {
           'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line'
+          'type' => 'preamble_before_content'
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -113,26 +119,27 @@ $result_trees{'contents_at_document_begin'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'contents_at_document_begin.texi',
         'line_nr' => 7,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -163,13 +170,12 @@ $result_trees{'contents_at_document_begin'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'contents_at_document_begin.texi',
         'line_nr' => 8,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -200,14 +206,12 @@ $result_trees{'contents_at_document_begin'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => 'contents_at_document_begin.texi',
         'line_nr' => 10,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -228,18 +232,19 @@ $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[0]{'conte
 $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[0];
 $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0];
-$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1];
+$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
+$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1];
+$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1];
+$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'contents'}[2];
+$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1];
+$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1];
 $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0];
-$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0];
-$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[3];
-$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0];
-$result_trees{'contents_at_document_begin'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[0];
 $result_trees{'contents_at_document_begin'}{'contents'}[0]{'parent'} = $result_trees{'contents_at_document_begin'};
 $result_trees{'contents_at_document_begin'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[1]{'args'}[0];
 $result_trees{'contents_at_document_begin'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[1];
 $result_trees{'contents_at_document_begin'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'contents_at_document_begin'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'contents_at_document_begin'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'contents_at_document_begin'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'contents_at_document_begin'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'contents_at_document_begin'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'contents_at_document_begin'}{'contents'}[1]{'parent'} = $result_trees{'contents_at_document_begin'};
 $result_trees{'contents_at_document_begin'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[2]{'args'}[0];
 $result_trees{'contents_at_document_begin'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'contents_at_document_begin'}{'contents'}[2];
@@ -278,67 +283,68 @@ top
 ';
 
 $result_sectioning{'contents_at_document_begin'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {
-        'associated_node' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'Top',
-            'spaces_before_argument' => ' '
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {
+          'associated_node' => {
+            'cmdname' => 'node',
+            'extra' => {
+              'normalized' => 'Top'
+            }
           }
         },
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_childs' => [
-        {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 1,
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
+        'structure' => {
+          'section_childs' => [
+            {
+              'cmdname' => 'chapter',
+              'extra' => {},
+              'structure' => {
+                'section_level' => 1,
+                'section_number' => 1,
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
+              }
+            }
+          ],
+          'section_level' => 0,
+          'section_up' => {}
         }
-      ],
-      'section_up' => {}
-    }
-  ]
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'contents_at_document_begin'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents_at_document_begin'}{'section_childs'}[0];
-$result_sectioning{'contents_at_document_begin'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'contents_at_document_begin'}{'section_childs'}[0];
-$result_sectioning{'contents_at_document_begin'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'contents_at_document_begin'}{'section_childs'}[0];
-$result_sectioning{'contents_at_document_begin'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents_at_document_begin'};
+$result_sectioning{'contents_at_document_begin'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents_at_document_begin'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_at_document_begin'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'contents_at_document_begin'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_at_document_begin'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'contents_at_document_begin'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_at_document_begin'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents_at_document_begin'};
 
 $result_nodes{'contents_at_document_begin'} = {
   'cmdname' => 'node',
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0
+      'extra' => {},
+      'structure' => {}
     },
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_menus{'contents_at_document_begin'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   }
 };
 
 $result_errors{'contents_at_document_begin'} = [];
 
 
+$result_floats{'contents_at_document_begin'} = {};
+
+
 1;
