@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'contents_in_html_text'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -41,13 +40,12 @@ $result_trees{'contents_in_html_text'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -78,14 +76,12 @@ $result_trees{'contents_in_html_text'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -116,14 +112,12 @@ $result_trees{'contents_in_html_text'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 2,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      },
-      'number' => '1.1',
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -160,12 +154,12 @@ $result_trees{'contents_in_html_text'} = {
             }
           ],
           'cmdname' => 'shortcontents',
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 9,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'args' => [
@@ -177,25 +171,23 @@ $result_trees{'contents_in_html_text'} = {
             }
           ],
           'cmdname' => 'contents',
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 10,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         }
       ],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 7,
         'macro' => ''
-      },
-      'number' => 2,
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -250,99 +242,120 @@ $result_texts{'contents_in_html_text'} = 'top
 ';
 
 $result_sectioning{'contents_in_html_text'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_childs' => [
-        {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 1,
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {},
+        'structure' => {
           'section_childs' => [
             {
-              'cmdname' => 'section',
-              'extra' => {
-                'spaces_before_argument' => ' '
-              },
-              'level' => 2,
-              'number' => '1.1',
-              'section_up' => {}
+              'cmdname' => 'chapter',
+              'extra' => {},
+              'structure' => {
+                'section_childs' => [
+                  {
+                    'cmdname' => 'section',
+                    'extra' => {},
+                    'structure' => {
+                      'section_level' => 2,
+                      'section_number' => '1.1',
+                      'section_up' => {}
+                    }
+                  }
+                ],
+                'section_level' => 1,
+                'section_number' => 1,
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
+              }
+            },
+            {
+              'cmdname' => 'chapter',
+              'extra' => {},
+              'structure' => {
+                'section_level' => 1,
+                'section_number' => 2,
+                'section_prev' => {},
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
+              }
             }
           ],
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
-        },
-        {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 2,
-          'section_prev' => {},
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
+          'section_level' => 0,
+          'section_up' => {}
         }
-      ],
-      'section_up' => {}
-    }
-  ]
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents_in_html_text'}{'section_childs'}[0];
-$result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'contents_in_html_text'}{'section_childs'}[0];
-$result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'contents_in_html_text'}{'section_childs'}[0];
-$result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[1]{'section_prev'} = $result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[1]{'section_up'} = $result_sectioning{'contents_in_html_text'}{'section_childs'}[0];
-$result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_childs'}[1]{'toplevel_up'} = $result_sectioning{'contents_in_html_text'}{'section_childs'}[0];
-$result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'contents_in_html_text'};
+$result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_prev'} = $result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_up'} = $result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'contents_in_html_text'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'contents_in_html_text'};
 
 $result_errors{'contents_in_html_text'} = [];
 
 
+$result_floats{'contents_in_html_text'} = {};
 
-$result_converted{'html_text'}->{'contents_in_html_text'} = '<span id="top"></span><h1 class="top">top</h1>
 
-<span id="Chap1"></span><h2 class="chapter">1 Chap1</h2>
 
-<span id="Sec-1"></span><h3 class="section">1.1 Sec 1</h3>
+$result_converted{'html_text'}->{'contents_in_html_text'} = '<div class="top-level-extent" id="top">
+<h1 class="top">top</h1>
 
-<span id="Chap2"></span><h2 class="chapter">2 Chap2</h2>
+<ul class="mini-toc">
+<li><a href="#Chap1" accesskey="1">Chap1</a></li>
+<li><a href="#Chap2" accesskey="2">Chap2</a></li>
+</ul>
+<div class="chapter-level-extent" id="Chap1">
+<h2 class="chapter">1 Chap1</h2>
 
+<ul class="mini-toc">
+<li><a href="#Sec-1" accesskey="1">Sec 1</a></li>
+</ul>
+<div class="section-level-extent" id="Sec-1">
+<h3 class="section">1.1 Sec 1</h3>
+
+</div>
+</div>
+<div class="chapter-level-extent" id="Chap2">
+<h2 class="chapter">2 Chap2</h2>
+
+<div class="element-shortcontents">
 <h2 class="shortcontents-heading">Short Table of Contents</h2>
 
 <div class="shortcontents">
-<ul class="no-bullet">
-<li><a name="stoc-Chap1" href="#toc-Chap1">1 Chap1</a></li>
-<li><a name="stoc-Chap2" href="#toc-Chap2">2 Chap2</a></li>
+<ul class="toc-numbered-mark">
+<li><a id="stoc-Chap1" href="#toc-Chap1">1 Chap1</a></li>
+<li><a id="stoc-Chap2" href="#toc-Chap2">2 Chap2</a></li>
 </ul>
 </div>
-
+</div>
+<div class="element-contents">
 <h2 class="contents-heading">Table of Contents</h2>
 
 <div class="contents">
 
-<ul class="no-bullet">
-  <li><a name="toc-Chap1" href="#Chap1">1 Chap1</a>
-  <ul class="no-bullet">
-    <li><a name="toc-Sec-1" href="#Sec-1">1.1 Sec 1</a></li>
+<ul class="toc-numbered-mark">
+  <li><a id="toc-Chap1" href="#Chap1">1 Chap1</a>
+  <ul class="toc-numbered-mark">
+    <li><a id="toc-Sec-1" href="#Sec-1">1.1 Sec 1</a></li>
   </ul></li>
-  <li><a name="toc-Chap2" href="#Chap2">2 Chap2</a></li>
+  <li><a id="toc-Chap2" href="#Chap2">2 Chap2</a></li>
 </ul>
 </div>
-
-<hr>
+</div>
+</div>
+</div>
 ';
 
 1;
