@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'double_node_anchor_float'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -44,19 +43,21 @@ $result_trees{'double_node_anchor_float'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'node1'
           }
         ],
         'normalized' => 'node1',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -97,20 +98,19 @@ $result_trees{'double_node_anchor_float'} = {
             }
           ],
           'cmdname' => 'anchor',
-          'contents' => [],
           'extra' => {},
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 5,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
           'text' => '
 ',
-          'type' => 'empty_spaces_after_close_brace'
+          'type' => 'spaces_after_close_brace'
         },
         {
           'parent' => {},
@@ -132,25 +132,24 @@ $result_trees{'double_node_anchor_float'} = {
             }
           ],
           'cmdname' => 'anchor',
-          'contents' => [],
           'extra' => {
             'node_content' => [
               {}
             ],
             'normalized' => 'anchor1'
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 7,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
           'text' => '
 ',
-          'type' => 'empty_spaces_after_close_brace'
+          'type' => 'spaces_after_close_brace'
         },
         {
           'parent' => {},
@@ -170,12 +169,12 @@ $result_trees{'double_node_anchor_float'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -251,32 +250,32 @@ $result_trees{'double_node_anchor_float'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'float',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'float'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 12,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
           'extra' => {
-            'end_command' => {},
             'spaces_before_argument' => ' ',
             'type' => {
-              'content' => [],
+              'content' => [
+                {}
+              ],
               'normalized' => 'Text'
             }
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 11,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -333,32 +332,32 @@ $result_trees{'double_node_anchor_float'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'float',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'float'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 15,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
           'extra' => {
-            'end_command' => {},
             'spaces_before_argument' => ' ',
             'type' => {
-              'content' => [],
+              'content' => [
+                {}
+              ],
               'normalized' => 'Text'
             }
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 14,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -415,37 +414,36 @@ $result_trees{'double_node_anchor_float'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
-                'command_argument' => 'float',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'float'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 18,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
           'extra' => {
-            'end_command' => {},
             'node_content' => [
               {}
             ],
             'normalized' => 'float1',
             'spaces_before_argument' => ' ',
             'type' => {
-              'content' => [],
+              'content' => [
+                {}
+              ],
               'normalized' => 'Text'
             }
           },
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 17,
             'macro' => ''
-          },
-          'number' => 1,
-          'parent' => {}
+          }
         },
         {
           'parent' => {},
@@ -465,12 +463,12 @@ $result_trees{'double_node_anchor_float'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 9,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -490,7 +488,6 @@ $result_trees{'double_node_anchor_float'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'nodes_manuals' => [
           {
@@ -502,12 +499,12 @@ $result_trees{'double_node_anchor_float'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 20,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -517,7 +514,7 @@ $result_trees{'double_node_anchor_float'}{'contents'}[1]{'args'}[0]{'contents'}[
 $result_trees{'double_node_anchor_float'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[1];
 $result_trees{'double_node_anchor_float'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[1];
 $result_trees{'double_node_anchor_float'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'double_node_anchor_float'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'double_node_anchor_float'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'double_node_anchor_float'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'double_node_anchor_float'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'double_node_anchor_float'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[1]{'parent'} = $result_trees{'double_node_anchor_float'};
 $result_trees{'double_node_anchor_float'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[2]{'args'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[2];
@@ -545,8 +542,7 @@ $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'args'}[
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'contents'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1];
-$result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'contents'}[0];
-$result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'extra'}{'type'}{'content'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'};
+$result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'extra'}{'type'}{'content'}[0] = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'args'}[0];
@@ -556,8 +552,7 @@ $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'args'}[
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'contents'}[0]{'args'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'contents'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3];
-$result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'contents'}[0];
-$result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'extra'}{'type'}{'content'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'args'}[0]{'contents'};
+$result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'extra'}{'type'}{'content'}[0] = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[3]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[4]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'args'}[0];
@@ -567,9 +562,8 @@ $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'args'}[
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'contents'}[0]{'args'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'contents'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'contents'}[0]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5];
-$result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'extra'}{'end_command'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'contents'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'args'}[1]{'contents'}[0];
-$result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'extra'}{'type'}{'content'} = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'args'}[0]{'contents'};
+$result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'extra'}{'type'}{'content'}[0] = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[5]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'contents'}[6]{'parent'} = $result_trees{'double_node_anchor_float'}{'contents'}[3];
 $result_trees{'double_node_anchor_float'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'double_node_anchor_float'}{'contents'}[3]{'args'}[0]{'contents'}[0];
@@ -615,27 +609,23 @@ Text, float1
 
 ';
 
-$result_sectioning{'double_node_anchor_float'} = {};
-
 $result_nodes{'double_node_anchor_float'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'node1',
-    'spaces_before_argument' => ' '
+    'normalized' => 'node1'
   }
 };
 
 $result_menus{'double_node_anchor_float'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'node1',
-    'spaces_before_argument' => ' '
+    'normalized' => 'node1'
   }
 };
 
 $result_errors{'double_node_anchor_float'} = [
   {
-    'error_line' => ':3: @node `node1\' previously defined
+    'error_line' => '@node `node1\' previously defined
 ',
     'file_name' => '',
     'line_nr' => 3,
@@ -644,7 +634,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':1: here is the previous definition as @node
+    'error_line' => 'here is the previous definition as @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -653,7 +643,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':5: @anchor `node1\' previously defined
+    'error_line' => '@anchor `node1\' previously defined
 ',
     'file_name' => '',
     'line_nr' => 5,
@@ -662,7 +652,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':1: here is the previous definition as @node
+    'error_line' => 'here is the previous definition as @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -671,7 +661,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':9: @node `anchor1\' previously defined
+    'error_line' => '@node `anchor1\' previously defined
 ',
     'file_name' => '',
     'line_nr' => 9,
@@ -680,7 +670,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':7: here is the previous definition as @anchor
+    'error_line' => 'here is the previous definition as @anchor
 ',
     'file_name' => '',
     'line_nr' => 7,
@@ -689,7 +679,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':11: @float `node1\' previously defined
+    'error_line' => '@float `node1\' previously defined
 ',
     'file_name' => '',
     'line_nr' => 11,
@@ -698,7 +688,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':1: here is the previous definition as @node
+    'error_line' => 'here is the previous definition as @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -707,7 +697,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':14: @float `anchor1\' previously defined
+    'error_line' => '@float `anchor1\' previously defined
 ',
     'file_name' => '',
     'line_nr' => 14,
@@ -716,7 +706,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':7: here is the previous definition as @anchor
+    'error_line' => 'here is the previous definition as @anchor
 ',
     'file_name' => '',
     'line_nr' => 7,
@@ -725,7 +715,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':20: @node `float1\' previously defined
+    'error_line' => '@node `float1\' previously defined
 ',
     'file_name' => '',
     'line_nr' => 20,
@@ -734,7 +724,7 @@ $result_errors{'double_node_anchor_float'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':17: here is the previous definition as @float
+    'error_line' => 'here is the previous definition as @float
 ',
     'file_name' => '',
     'line_nr' => 17,
@@ -750,15 +740,6 @@ $result_floats{'double_node_anchor_float'} = {
     {
       'cmdname' => 'float',
       'extra' => {
-        'end_command' => {
-          'cmdname' => 'end',
-          'extra' => {
-            'command_argument' => 'float',
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'float'
-          }
-        },
-        'spaces_before_argument' => ' ',
         'type' => {
           'content' => [
             {
@@ -772,15 +753,6 @@ $result_floats{'double_node_anchor_float'} = {
     {
       'cmdname' => 'float',
       'extra' => {
-        'end_command' => {
-          'cmdname' => 'end',
-          'extra' => {
-            'command_argument' => 'float',
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'float'
-          }
-        },
-        'spaces_before_argument' => ' ',
         'type' => {
           'content' => [
             {
@@ -794,16 +766,7 @@ $result_floats{'double_node_anchor_float'} = {
     {
       'cmdname' => 'float',
       'extra' => {
-        'end_command' => {
-          'cmdname' => 'end',
-          'extra' => {
-            'command_argument' => 'float',
-            'spaces_before_argument' => ' ',
-            'text_arg' => 'float'
-          }
-        },
         'normalized' => 'float1',
-        'spaces_before_argument' => ' ',
         'type' => {
           'content' => [
             {
@@ -813,7 +776,9 @@ $result_floats{'double_node_anchor_float'} = {
           'normalized' => 'Text'
         }
       },
-      'number' => 1
+      'structure' => {
+        'float_number' => 1
+      }
     }
   ]
 };
@@ -857,7 +822,7 @@ $result_converted_errors{'info'}->{'double_node_anchor_float'} = [
 
 
 
-$result_converted{'html'}->{'double_node_anchor_float'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+$result_converted{'html'}->{'double_node_anchor_float'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -868,65 +833,48 @@ $result_converted{'html'}->{'double_node_anchor_float'} = '<!DOCTYPE html PUBLIC
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#node1" rel="start" title="node1">
-<style type="text/css">
-<!--
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-ul.no-bullet {list-style: none}
--->
-</style>
 
 
 </head>
 
 <body lang="en">
-<span id="node1"></span><div class="header">
+<a class="node-id" id="node1"></a><div class="nav-panel">
 <p>
  &nbsp; </p>
 </div>
-<h4 class="node-heading">node1</h4>
+<h4 class="node">node1</h4>
 
 <hr>
-<div class="header">
+<div class="nav-panel">
 <p>
  &nbsp; </p>
 </div>
 
 
-<span id="anchor1"></span>
+<a class="anchor" id="anchor1"></a>
 <hr>
-<div class="header">
+<div class="nav-panel">
 <p>
  &nbsp; </p>
 </div>
 
 <div class="float">
-<div class="float-caption"><p><strong>Text
+<div class="type-number-float"><p><strong class="strong">Text
 </strong></p></div></div>
 <div class="float">
-<div class="float-caption"><p><strong>Text
+<div class="type-number-float"><p><strong class="strong">Text
 </strong></p></div></div>
-<div class="float"><span id="float1"></span>
-<div class="float-caption"><p><strong>Text 1
+<div class="float" id="float1">
+<div class="type-number-float"><p><strong class="strong">Text 1
 </strong></p></div></div>
 <hr>
-<div class="header">
+<div class="nav-panel">
 <p>
  &nbsp; </p>
 </div>
-<hr>
 
 
 
