@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'double_top'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -55,7 +54,9 @@ $result_trees{'double_top'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           },
           {
@@ -68,12 +69,12 @@ $result_trees{'double_top'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -88,7 +89,6 @@ $result_trees{'double_top'} = {
           'type' => 'line_arg'
         },
         {
-          'contents' => [],
           'parent' => {},
           'type' => 'line_arg'
         },
@@ -139,14 +139,13 @@ $result_trees{'double_top'} = {
             }
           ],
           'cmdname' => 'anchor',
-          'contents' => [],
           'extra' => {},
-          'line_nr' => {
+          'parent' => {},
+          'source_info' => {
             'file_name' => '',
             'line_nr' => 5,
             'macro' => ''
-          },
-          'parent' => {}
+          }
         },
         {
           'contents' => [
@@ -184,12 +183,12 @@ $result_trees{'double_top'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -201,7 +200,7 @@ $result_trees{'double_top'}{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} =
 $result_trees{'double_top'}{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'double_top'}{'contents'}[1];
 $result_trees{'double_top'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'double_top'}{'contents'}[1];
 $result_trees{'double_top'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'double_top'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'double_top'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'double_top'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'double_top'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'double_top'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'double_top'}{'contents'}[1]{'extra'}{'nodes_manuals'}[1]{'node_content'}[0] = $result_trees{'double_top'}{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'double_top'}{'contents'}[1]{'parent'} = $result_trees{'double_top'};
 $result_trees{'double_top'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'double_top'}{'contents'}[2]{'args'}[0];
@@ -235,29 +234,28 @@ $result_texts{'double_top'} = '
 .
 ';
 
-$result_sectioning{'double_top'} = {};
-
 $result_nodes{'double_top'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
+    'normalized' => 'Top'
   },
-  'node_next' => {}
+  'structure' => {
+    'node_next' => {}
+  }
 };
-$result_nodes{'double_top'}{'node_next'} = $result_nodes{'double_top'};
+$result_nodes{'double_top'}{'structure'}{'node_next'} = $result_nodes{'double_top'};
 
 $result_menus{'double_top'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top',
-    'spaces_before_argument' => ' '
-  }
+    'normalized' => 'Top'
+  },
+  'structure' => {}
 };
 
 $result_errors{'double_top'} = [
   {
-    'error_line' => ':3: @node `top\' previously defined
+    'error_line' => '@node `top\' previously defined
 ',
     'file_name' => '',
     'line_nr' => 3,
@@ -266,7 +264,7 @@ $result_errors{'double_top'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':1: here is the previous definition as @node
+    'error_line' => 'here is the previous definition as @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -275,7 +273,7 @@ $result_errors{'double_top'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':5: @anchor `TOP\' previously defined
+    'error_line' => '@anchor `TOP\' previously defined
 ',
     'file_name' => '',
     'line_nr' => 5,
@@ -284,7 +282,7 @@ $result_errors{'double_top'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':1: here is the previous definition as @node
+    'error_line' => 'here is the previous definition as @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -293,7 +291,7 @@ $result_errors{'double_top'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':1: warning: Next pointer `top\' (for node `ToP\') different from node name `ToP\'
+    'error_line' => 'warning: Next pointer `top\' (for node `ToP\') different from node name `ToP\'
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -304,6 +302,9 @@ $result_errors{'double_top'} = [
 ];
 
 
+$result_floats{'double_top'} = {};
+
+
 
 $result_converted{'info'}->{'double_top'} = 'This is , produced from .
 
@@ -325,7 +326,7 @@ End:
 ';
 
 
-$result_converted{'html'}->{'double_top'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+$result_converted{'html'}->{'double_top'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -336,45 +337,28 @@ $result_converted{'html'}->{'double_top'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#Top" rel="start" title="ToP">
-<style type="text/css">
-<!--
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-ul.no-bullet {list-style: none}
--->
-</style>
 
 
 </head>
 
 <body lang="en">
-<span id="Top"></span><div class="header">
+<a class="node-id" id="Top"></a><div class="nav-panel">
 <p>
 Next: <a href="#Top" accesskey="n" rel="next">ToP</a> &nbsp; </p>
 </div>
-<h1 class="node-heading">ToP</h1>
+<h1 class="node">ToP</h1>
 
 <hr>
-<div class="header">
+<div class="nav-panel">
 <p>
  &nbsp; </p>
 </div>
 
 <p>.
-</p><hr>
-
+</p>
 
 
 </body>
