@@ -1,42 +1,31 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'double_top_section'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'First top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'top',
@@ -66,44 +55,30 @@ $result_trees{'double_top_section'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Second top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'top',
@@ -127,45 +102,31 @@ $result_trees{'double_top_section'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
 };
 $result_trees{'double_top_section'}{'contents'}[0]{'parent'} = $result_trees{'double_top_section'};
-$result_trees{'double_top_section'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'double_top_section'}{'contents'}[1];
 $result_trees{'double_top_section'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'double_top_section'}{'contents'}[1]{'args'}[0];
-$result_trees{'double_top_section'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'double_top_section'}{'contents'}[1]{'args'}[0];
-$result_trees{'double_top_section'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'double_top_section'}{'contents'}[1]{'args'}[0];
 $result_trees{'double_top_section'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'double_top_section'}{'contents'}[1];
 $result_trees{'double_top_section'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'double_top_section'}{'contents'}[1];
 $result_trees{'double_top_section'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'double_top_section'}{'contents'}[1]{'contents'}[1];
 $result_trees{'double_top_section'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'double_top_section'}{'contents'}[1];
 $result_trees{'double_top_section'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'double_top_section'}{'contents'}[1];
-$result_trees{'double_top_section'}{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'double_top_section'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'double_top_section'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'double_top_section'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'double_top_section'}{'contents'}[1]{'parent'} = $result_trees{'double_top_section'};
-$result_trees{'double_top_section'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'double_top_section'}{'contents'}[2];
 $result_trees{'double_top_section'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'double_top_section'}{'contents'}[2]{'args'}[0];
-$result_trees{'double_top_section'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'double_top_section'}{'contents'}[2]{'args'}[0];
-$result_trees{'double_top_section'}{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'double_top_section'}{'contents'}[2]{'args'}[0];
 $result_trees{'double_top_section'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'double_top_section'}{'contents'}[2];
 $result_trees{'double_top_section'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'double_top_section'}{'contents'}[2];
 $result_trees{'double_top_section'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'double_top_section'}{'contents'}[2]{'contents'}[1];
 $result_trees{'double_top_section'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'double_top_section'}{'contents'}[2];
-$result_trees{'double_top_section'}{'contents'}[2]{'extra'}{'misc_content'}[0] = $result_trees{'double_top_section'}{'contents'}[2]{'args'}[0]{'contents'}[1];
-$result_trees{'double_top_section'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'double_top_section'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'double_top_section'}{'contents'}[2]{'parent'} = $result_trees{'double_top_section'};
 
 $result_texis{'double_top_section'} = '@top First top
@@ -190,42 +151,51 @@ Second top.
 ';
 
 $result_sectioning{'double_top_section'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {},
-      'level' => 0,
-      'section_up' => {}
-    },
-    {
-      'cmdname' => 'top',
-      'extra' => {},
-      'level' => 0,
-      'section_prev' => {},
-      'section_up' => {},
-      'toplevel_prev' => {},
-      'toplevel_up' => {}
-    }
-  ]
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {},
+        'structure' => {
+          'section_level' => 0,
+          'section_up' => {}
+        }
+      },
+      {
+        'cmdname' => 'top',
+        'extra' => {},
+        'structure' => {
+          'section_level' => 0,
+          'section_prev' => {},
+          'section_up' => {},
+          'toplevel_prev' => {},
+          'toplevel_up' => {}
+        }
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'double_top_section'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'double_top_section'};
-$result_sectioning{'double_top_section'}{'section_childs'}[1]{'section_prev'} = $result_sectioning{'double_top_section'}{'section_childs'}[0];
-$result_sectioning{'double_top_section'}{'section_childs'}[1]{'section_up'} = $result_sectioning{'double_top_section'};
-$result_sectioning{'double_top_section'}{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'double_top_section'}{'section_childs'}[0];
-$result_sectioning{'double_top_section'}{'section_childs'}[1]{'toplevel_up'} = $result_sectioning{'double_top_section'}{'section_childs'}[0];
+$result_sectioning{'double_top_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'double_top_section'};
+$result_sectioning{'double_top_section'}{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'double_top_section'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'double_top_section'}{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'double_top_section'};
+$result_sectioning{'double_top_section'}{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_prev'} = $result_sectioning{'double_top_section'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'double_top_section'}{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_up'} = $result_sectioning{'double_top_section'}{'structure'}{'section_childs'}[0];
 
 $result_errors{'double_top_section'} = [
   {
-    'error_line' => ':5: warning: Multiple @top
+    'error_line' => 'warning: multiple @top
 ',
     'file_name' => '',
     'line_nr' => 5,
     'macro' => '',
-    'text' => 'Multiple @top',
+    'text' => 'multiple @top',
     'type' => 'warning'
   }
 ];
 
 
+$result_floats{'double_top_section'} = {};
+
+
 1;
