@@ -1,21 +1,19 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'empty_node'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
         {
-          'contents' => [],
           'extra' => {
             'spaces_after_argument' => '
 '
@@ -38,17 +36,16 @@ $result_trees{'empty_node'} = {
           undef
         ]
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
         {
-          'contents' => [],
           'parent' => {},
           'type' => 'line_arg'
         },
@@ -95,7 +92,6 @@ $result_trees{'empty_node'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'nodes_manuals' => [
           undef,
@@ -120,12 +116,12 @@ $result_trees{'empty_node'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -155,11 +151,9 @@ $result_texis{'empty_node'} = '@node
 $result_texts{'empty_node'} = '
 ';
 
-$result_sectioning{'empty_node'} = {};
-
 $result_errors{'empty_node'} = [
   {
-    'error_line' => ':1: empty argument in @node
+    'error_line' => 'empty argument in @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -168,7 +162,7 @@ $result_errors{'empty_node'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':3: empty argument in @node
+    'error_line' => 'empty argument in @node
 ',
     'file_name' => '',
     'line_nr' => 3,
@@ -179,4 +173,7 @@ $result_errors{'empty_node'} = [
 ];
 
 
+$result_floats{'empty_node'} = {};
+
+
 1;
