@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
@@ -17,12 +17,11 @@ $result_trees{'empty_nodes_with_commands'} = {
         }
       ],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
         {
-          'contents' => [],
           'extra' => {
             'comment_at_end' => {
               'args' => [
@@ -62,12 +61,12 @@ $result_trees{'empty_nodes_with_commands'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 2,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -84,7 +83,6 @@ $result_trees{'empty_nodes_with_commands'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'nodes_manuals' => [
           {
@@ -96,12 +94,12 @@ $result_trees{'empty_nodes_with_commands'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -121,7 +119,6 @@ $result_trees{'empty_nodes_with_commands'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'nodes_manuals' => [
           {
@@ -133,12 +130,12 @@ $result_trees{'empty_nodes_with_commands'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -158,13 +155,12 @@ $result_trees{'empty_nodes_with_commands'} = {
                 }
               ],
               'cmdname' => 'asis',
-              'contents' => [],
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 6,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             }
           ],
           'extra' => {
@@ -176,7 +172,6 @@ $result_trees{'empty_nodes_with_commands'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'nodes_manuals' => [
           {
@@ -188,8 +183,12 @@ $result_trees{'empty_nodes_with_commands'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
-      'parent' => {}
+      'parent' => {},
+      'source_info' => {
+        'file_name' => '',
+        'line_nr' => 6,
+        'macro' => ''
+      }
     }
   ],
   'type' => 'document_root'
@@ -214,7 +213,6 @@ $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'contents'}
 $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0];
 $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[4];
 $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0];
-$result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'line_nr'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'parent'} = $result_trees{'empty_nodes_with_commands'};
 
 $result_texis{'empty_nodes_with_commands'} = '
@@ -230,11 +228,9 @@ $result_texts{'empty_nodes_with_commands'} = '
 
 ';
 
-$result_sectioning{'empty_nodes_with_commands'} = {};
-
 $result_errors{'empty_nodes_with_commands'} = [
   {
-    'error_line' => ':2: empty argument in @node
+    'error_line' => 'empty argument in @node
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -243,7 +239,7 @@ $result_errors{'empty_nodes_with_commands'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':4: empty node name after expansion `@
+    'error_line' => 'empty node name after expansion `@
 \'
 ',
     'file_name' => '',
@@ -254,7 +250,7 @@ $result_errors{'empty_nodes_with_commands'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':5: empty node name after expansion `@:\'
+    'error_line' => 'empty node name after expansion `@:\'
 ',
     'file_name' => '',
     'line_nr' => 5,
@@ -263,7 +259,7 @@ $result_errors{'empty_nodes_with_commands'} = [
     'type' => 'error'
   },
   {
-    'error_line' => ':6: empty node name after expansion `@asis{ }\'
+    'error_line' => 'empty node name after expansion `@asis{ }\'
 ',
     'file_name' => '',
     'line_nr' => 6,
@@ -274,4 +270,7 @@ $result_errors{'empty_nodes_with_commands'} = [
 ];
 
 
+$result_floats{'empty_nodes_with_commands'} = {};
+
+
 1;
