@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'hole_in_sectioning'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -41,13 +40,12 @@ $result_trees{'hole_in_sectioning'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 0,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -78,14 +76,12 @@ $result_trees{'hole_in_sectioning'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 1,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -116,14 +112,12 @@ $result_trees{'hole_in_sectioning'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 2,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      },
-      'number' => '1.1',
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -154,14 +148,12 @@ $result_trees{'hole_in_sectioning'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 3,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 7,
         'macro' => ''
-      },
-      'number' => '1.1.1',
-      'parent' => {}
+      }
     },
     {
       'args' => [
@@ -181,18 +173,15 @@ $result_trees{'hole_in_sectioning'} = {
         }
       ],
       'cmdname' => 'subsection',
-      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 3,
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 9,
         'macro' => ''
-      },
-      'number' => '1.1.2',
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -247,75 +236,77 @@ $result_texts{'hole_in_sectioning'} = 'Top
 ';
 
 $result_sectioning{'hole_in_sectioning'} = {
-  'level' => -1,
-  'section_childs' => [
-    {
-      'cmdname' => 'top',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 0,
-      'section_childs' => [
-        {
-          'cmdname' => 'chapter',
-          'extra' => {
-            'spaces_before_argument' => ' '
-          },
-          'level' => 1,
-          'number' => 1,
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'top',
+        'extra' => {},
+        'structure' => {
           'section_childs' => [
             {
-              'cmdname' => 'section',
-              'extra' => {
-                'spaces_before_argument' => ' '
-              },
-              'level' => 2,
-              'number' => '1.1',
-              'section_childs' => [
-                {
-                  'cmdname' => 'subsubsection',
-                  'extra' => {
-                    'spaces_before_argument' => ' '
-                  },
-                  'level' => 3,
-                  'number' => '1.1.1',
-                  'section_up' => {}
-                },
-                {
-                  'cmdname' => 'subsection',
-                  'extra' => {
-                    'spaces_before_argument' => ' '
-                  },
-                  'level' => 3,
-                  'number' => '1.1.2',
-                  'section_prev' => {},
-                  'section_up' => {}
-                }
-              ],
-              'section_up' => {}
+              'cmdname' => 'chapter',
+              'extra' => {},
+              'structure' => {
+                'section_childs' => [
+                  {
+                    'cmdname' => 'section',
+                    'extra' => {},
+                    'structure' => {
+                      'section_childs' => [
+                        {
+                          'cmdname' => 'subsubsection',
+                          'extra' => {},
+                          'structure' => {
+                            'section_level' => 3,
+                            'section_number' => '1.1.1',
+                            'section_up' => {}
+                          }
+                        },
+                        {
+                          'cmdname' => 'subsection',
+                          'extra' => {},
+                          'structure' => {
+                            'section_level' => 3,
+                            'section_number' => '1.1.2',
+                            'section_prev' => {},
+                            'section_up' => {}
+                          }
+                        }
+                      ],
+                      'section_level' => 2,
+                      'section_number' => '1.1',
+                      'section_up' => {}
+                    }
+                  }
+                ],
+                'section_level' => 1,
+                'section_number' => 1,
+                'section_up' => {},
+                'toplevel_prev' => {},
+                'toplevel_up' => {}
+              }
             }
           ],
-          'section_up' => {},
-          'toplevel_prev' => {},
-          'toplevel_up' => {}
+          'section_level' => 0,
+          'section_up' => {}
         }
-      ],
-      'section_up' => {}
-    }
-  ]
+      }
+    ],
+    'section_level' => -1
+  }
 };
-$result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[1]{'section_prev'} = $result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[1]{'section_up'} = $result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0];
-$result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'hole_in_sectioning'}{'section_childs'}[0];
-$result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'hole_in_sectioning'}{'section_childs'}[0];
-$result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'hole_in_sectioning'}{'section_childs'}[0];
-$result_sectioning{'hole_in_sectioning'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'hole_in_sectioning'};
+$result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
+$result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'hole_in_sectioning'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'hole_in_sectioning'};
 
 $result_errors{'hole_in_sectioning'} = [
   {
-    'error_line' => ':7: raising the section level of @subsubsection which is too low
+    'error_line' => 'raising the section level of @subsubsection which is too low
 ',
     'file_name' => '',
     'line_nr' => 7,
@@ -326,4 +317,29 @@ $result_errors{'hole_in_sectioning'} = [
 ];
 
 
+$result_floats{'hole_in_sectioning'} = {};
+
+
+
+$result_converted{'docbook'}->{'hole_in_sectioning'} = '<chapter label="">
+<title>Top</title>
+
+</chapter>
+<chapter label="1">
+<title>Chapter</title>
+
+<sect1 label="1.1">
+<title>section</title>
+
+<sect2 label="1.1.1">
+<title>subsubsection with no subsection above</title>
+
+</sect2>
+<sect2 label="1.1.2">
+<title>the subsection</title>
+</sect2>
+</sect1>
+</chapter>
+';
+
 1;
