@@ -1,33 +1,47 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'lone_contents'} = {
   'contents' => [
     {
-      'args' => [
+      'contents' => [
         {
-          'parent' => {},
-          'text' => '
+          'contents' => [
+            {
+              'args' => [
+                {
+                  'parent' => {},
+                  'text' => '
 ',
-          'type' => 'misc_arg'
+                  'type' => 'misc_arg'
+                }
+              ],
+              'cmdname' => 'contents',
+              'parent' => {},
+              'source_info' => {
+                'file_name' => '',
+                'line_nr' => 1,
+                'macro' => ''
+              }
+            }
+          ],
+          'parent' => {},
+          'type' => 'preamble_before_content'
         }
       ],
-      'cmdname' => 'contents',
-      'line_nr' => {
-        'file_name' => '',
-        'line_nr' => 1,
-        'macro' => ''
-      },
-      'parent' => {}
+      'parent' => {},
+      'type' => 'before_node_section'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
-$result_trees{'lone_contents'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'lone_contents'}{'contents'}[0];
+$result_trees{'lone_contents'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'lone_contents'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
+$result_trees{'lone_contents'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'lone_contents'}{'contents'}[0]{'contents'}[0];
+$result_trees{'lone_contents'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'lone_contents'}{'contents'}[0];
 $result_trees{'lone_contents'}{'contents'}[0]{'parent'} = $result_trees{'lone_contents'};
 
 $result_texis{'lone_contents'} = '@contents
@@ -39,11 +53,14 @@ $result_texts{'lone_contents'} = '';
 $result_errors{'lone_contents'} = [];
 
 
+$result_floats{'lone_contents'} = {};
+
+
 
 $result_converted{'plaintext'}->{'lone_contents'} = '';
 
 
-$result_converted{'html'}->{'lone_contents'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+$result_converted{'html'}->{'lone_contents'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -54,24 +71,8 @@ $result_converted{'html'}->{'lone_contents'} = '<!DOCTYPE html PUBLIC "-//W3C//D
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
-<style type="text/css">
-<!--
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-ul.no-bullet {list-style: none}
--->
-</style>
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 
 
 </head>
