@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'node_empty_direction'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -25,7 +24,6 @@ $result_trees{'node_empty_direction'} = {
           'type' => 'line_arg'
         },
         {
-          'contents' => [],
           'extra' => {
             'spaces_after_argument' => ' '
           },
@@ -34,7 +32,6 @@ $result_trees{'node_empty_direction'} = {
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
@@ -51,12 +48,12 @@ $result_trees{'node_empty_direction'} = {
         'normalized' => 'name',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -74,21 +71,17 @@ $result_texis{'node_empty_direction'} = '@node name, ';
 
 $result_texts{'node_empty_direction'} = '';
 
-$result_sectioning{'node_empty_direction'} = {};
-
 $result_nodes{'node_empty_direction'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'name',
-    'spaces_before_argument' => ' '
+    'normalized' => 'name'
   }
 };
 
 $result_menus{'node_empty_direction'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'name',
-    'spaces_before_argument' => ' '
+    'normalized' => 'name'
   }
 };
 
