@@ -1,16 +1,15 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'one_node_explicit_directions_anchor'} = {
   'contents' => [
     {
-      'contents' => [],
       'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
@@ -25,12 +24,10 @@ $result_trees{'one_node_explicit_directions_anchor'} = {
           'type' => 'line_arg'
         },
         {
-          'contents' => [],
           'parent' => {},
           'type' => 'line_arg'
         },
         {
-          'contents' => [],
           'parent' => {},
           'type' => 'line_arg'
         },
@@ -96,19 +93,18 @@ $result_trees{'one_node_explicit_directions_anchor'} = {
                 }
               ],
               'cmdname' => 'anchor',
-              'contents' => [],
               'extra' => {
                 'node_content' => [
                   {}
                 ],
                 'normalized' => 'ref'
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 4,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -145,7 +141,6 @@ $result_trees{'one_node_explicit_directions_anchor'} = {
                 }
               ],
               'cmdname' => 'ref',
-              'contents' => [],
               'extra' => {
                 'label' => {},
                 'node_argument' => {
@@ -155,12 +150,12 @@ $result_trees{'one_node_explicit_directions_anchor'} = {
                   'normalized' => 'ref'
                 }
               },
-              'line_nr' => {
+              'parent' => {},
+              'source_info' => {
                 'file_name' => '',
                 'line_nr' => 6,
                 'macro' => ''
-              },
-              'parent' => {}
+              }
             },
             {
               'parent' => {},
@@ -178,7 +173,9 @@ $result_trees{'one_node_explicit_directions_anchor'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'one-node'
           },
           undef,
@@ -192,12 +189,12 @@ $result_trees{'one_node_explicit_directions_anchor'} = {
         'normalized' => 'one-node',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'parent' => {},
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
@@ -231,7 +228,7 @@ $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'contents'}[
 $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'contents'}[4]{'contents'}[2]{'parent'} = $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'contents'}[4];
 $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1];
 $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'extra'}{'nodes_manuals'}[3]{'manual_content'}[0] = $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'args'}[3]{'contents'}[1];
 $result_trees{'one_node_explicit_directions_anchor'}{'contents'}[1]{'parent'} = $result_trees{'one_node_explicit_directions_anchor'};
 
@@ -251,21 +248,20 @@ anchor ref .
 ref to ref ref.
 ';
 
-$result_sectioning{'one_node_explicit_directions_anchor'} = {};
-
 $result_nodes{'one_node_explicit_directions_anchor'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'one-node',
-    'spaces_before_argument' => ' '
+    'normalized' => 'one-node'
   },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ]
+  'structure' => {
+    'node_up' => {
+      'extra' => {
+        'manual_content' => [
+          {
+            'text' => 'dir'
+          }
+        ]
+      }
     }
   }
 };
@@ -273,14 +269,17 @@ $result_nodes{'one_node_explicit_directions_anchor'} = {
 $result_menus{'one_node_explicit_directions_anchor'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'one-node',
-    'spaces_before_argument' => ' '
-  }
+    'normalized' => 'one-node'
+  },
+  'structure' => {}
 };
 
 $result_errors{'one_node_explicit_directions_anchor'} = [];
 
 
+$result_floats{'one_node_explicit_directions_anchor'} = {};
+
+
 
 $result_converted{'info'}->{'one_node_explicit_directions_anchor'} = 'This is , produced from .
 
@@ -299,6 +298,11 @@ Node: one node27
 Ref: ref89
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 $result_converted_errors{'info'}->{'one_node_explicit_directions_anchor'} = [
@@ -312,7 +316,7 @@ $result_converted_errors{'info'}->{'one_node_explicit_directions_anchor'} = [
 
 
 
-$result_converted{'html'}->{'one_node_explicit_directions_anchor'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+$result_converted{'html'}->{'one_node_explicit_directions_anchor'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -323,47 +327,21 @@ $result_converted{'html'}->{'one_node_explicit_directions_anchor'} = '<!DOCTYPE
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#one-node" rel="start" title="one node">
-<style type="text/css">
-<!--
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-ul.no-bullet {list-style: none}
--->
-</style>
 
 
 </head>
 
 <body lang="en">
-<span id="one-node"></span><h4 class="node-heading">one node</h4>
+<h4 class="node" id="one-node">one node</h4>
 <p>Top node
 </p>
-<p>anchor ref <span id="ref"></span>.
+<p>anchor ref <a class="anchor" id="ref"></a>.
+</p>
+<p>ref to ref <a class="ref" href="#ref">ref</a>.
 </p>
-<p>ref to ref <a href="#ref">ref</a>.
-</p><hr>
-
 
 
 </body>
