@@ -7,6 +7,16 @@
 # are permitted in any medium without royalty provided the copyright
 # notice and this notice are preserved.
 
+check_need_recoded_file_names ()
+{
+   if echo "$remaining" | grep 'Need recoded file names' >/dev/null; then
+     if [ "$no_recoded_file_names" = 'yes' ]; then
+       echo "S: (no recoded file names) $current"
+       return 1
+     fi
+   fi
+   return 0
+}
 
 check_latex2html_and_tex4ht ()
 {
@@ -17,7 +27,7 @@ check_latex2html_and_tex4ht ()
     if echo "$remaining" | grep '[-]l2h' >/dev/null; then
       maybe_use_latex2html=yes
     fi
-    if echo "$remaining" | grep 'L2H 1' >/dev/null; then
+    if echo "$remaining" | grep 'HTML_MATH l2h' >/dev/null; then
       maybe_use_latex2html=yes
     fi
     if [ $maybe_use_latex2html = 'yes' ]; then
@@ -33,14 +43,22 @@ check_latex2html_and_tex4ht ()
            exit 1
          fi
       fi
-      l2h_tmp_dir="-c 'L2H_TMP $tmp_dir'"
       l2h_flags="-c L2H_CLEAN=0 -c 'L2H_TMP $tmp_dir' -c L2H_FILE=$srcdir/../t/init/l2h.init"
-    elif echo "$remaining" | grep '[-]init tex4ht.pm' >/dev/null; then
-      if test "$no_tex4ht" = 'yes' ; then
-        echo "S: (no tex4ht) $current"
-        return 1
+    else
+      maybe_use_tex4ht=no
+      if echo "$remaining" | grep '[-]init tex4ht.pm' >/dev/null; then
+        maybe_use_tex4ht=yes
+      fi
+      if echo "$remaining" | grep 'HTML_MATH t4h' >/dev/null; then
+        maybe_use_tex4ht=yes
+      fi
+      if [ $maybe_use_tex4ht = 'yes' ]; then
+        if test "$no_tex4ht" = 'yes' ; then
+          echo "S: (no tex4ht) $current"
+          return 1
+        fi
+        use_tex4ht=yes
       fi
-      use_tex4ht=yes
     fi
     if test $use_tex4ht = 'yes' || test $use_latex2html = 'yes' ; then
       if echo "$remaining" | grep '[-]init mediawiki.pm' >/dev/null; then
@@ -118,6 +136,7 @@ post_process_output ()
 }
 
 LC_ALL=C; export LC_ALL
+LANGUAGE=en; export LANGUAGE
 
 prepended_command=
 #prepended_command=time
@@ -185,6 +204,11 @@ if which html2wiki > /dev/null 2>&1; then
   no_html2wiki=no
 fi
 
+no_recoded_file_names=yes
+if sed 1q input_file_names_recoded_stamp.txt | grep 'OK' >/dev/null; then
+  no_recoded_file_names=no
+fi
+
 one_test=no
 if test -n "$1"; then
   one_test=yes
@@ -211,7 +235,7 @@ fi
 first_line=`head -1 "$driving_file"`
 if echo $first_line |grep '^# formats' >/dev/null; then
   formats=`echo $first_line |sed 's/^# formats //'`
-  commands="$commands $formats"
+  commands="$formats"
   echo "found special first line, commands now: $commands" >>$logfile
 fi
 
@@ -229,7 +253,8 @@ if [ "z$clean" = 'zyes' -o "z$copy" = 'zyes' ]; then
 # there are better ways
     dir=`echo $line | awk '{print $1}'`
     file=`echo $line | awk '{print $2}'`
-    remaining=`echo $line | sed 's/[a-zA-Z0-9_./-]*  *[a-zA-Z0-9_./-]* *//'`
+    #remaining=`echo $line | sed 's/[a-zA-Z0-9_./-]*  *[a-zA-Z0-9_./-]* *//'`
+    remaining=`echo $line | sed 's/[a-zA-Z0-9_é./-]*  *[a-zA-Z0-9_é./-]* *//'`
     [ "z$dir" = 'z' -o "z$file" = 'z' ] && continue
     if [ "z$clean" = 'zyes' ]; then
       for command_dir in $commands; do
@@ -285,7 +310,8 @@ while read line; do
   fi
 
   basename=`basename $file .texi`
-  remaining=`echo $line | sed 's/[a-zA-Z0-9_./-]*  *[a-zA-Z0-9_./-]* *//'`
+  #remaining=`echo $line | sed 's/[a-zA-Z0-9_./-]*  *[a-zA-Z0-9_./-]* *//'`
+  remaining=`echo $line | sed 's/[a-zA-Z0-9_é./-]*  *[a-zA-Z0-9_é./-]* *//'`
   src_file="$srcdir/$testdir/$file"
   
   for command_dir in $commands; do
@@ -323,14 +349,22 @@ while read line; do
     results_dir="$srcdir/$testdir/${res_dir}${dir_suffix}"
     one_test_done=yes
 
-    check_latex2html_and_tex4ht || continue 2
+    skipped_test=no
+    check_need_recoded_file_names || skipped_test=yes
+    check_latex2html_and_tex4ht || skipped_test=yes
+    if [ "$skipped_test" = 'yes' ] ; then
+      if test $one_test = 'yes' ; then
+        return_code=77
+      fi
+      continue 2
+    fi
 
     dir=$current
     test -d "${outdir}$dir" && rm -rf "${outdir}$dir"
     mkdir "${outdir}$dir"
     remaining_out_dir=`echo $remaining | sed 's,@OUT_DIR@,'"${outdir}$dir/"',g'`
     echo "$command $dir -> ${outdir}$dir" >> $logfile
-    cmd="$prepended_command $PERL -w $command_run $format_option --force --conf-dir $srcdir/../t/init/ --conf-dir $srcdir/../init -I $srcdir/$testdir -I $testdir/ -I $srcdir/ -I .  --error-limit=1000 -c TEST=1 $l2h_flags --output ${outdir}$dir/ $remaining_out_dir $src_file > ${outdir}$dir/$basename.1 2>${outdir}$dir/$basename.2"
+    cmd="$prepended_command $PERL -w $command_run $format_option --force --conf-dir $srcdir/../t/init/ --conf-dir $srcdir/../init --conf-dir $srcdir/../ext -I $srcdir/$testdir -I $testdir/ -I $srcdir/ -I .  --error-limit=1000 -c TEST=1 $l2h_flags --output ${outdir}$dir/ $remaining_out_dir $src_file > ${outdir}$dir/$basename.1 2>${outdir}$dir/$basename.2"
     echo "$cmd" >>$logfile
     eval $cmd
     ret=$?
